@@ -23,7 +23,7 @@ function erlangRepl(hljs) {
       hljs.COMMENT('%', '$'),
       {
         className: 'number',
-        begin: '\\b(\\d+#[a-fA-F0-9]+|\\d+(\\.\\d+)?([eE][-+]?\\d+)?)',
+        begin: '\\b(\\d+(_\\d+)*#[a-fA-F0-9]+(_[a-fA-F0-9]+)*|\\d+(_\\d+)*(\\.\\d+(_\\d+)*)?([eE][-+]?\\d+)?)',
         relevance: 0
       },
       hljs.APOS_STRING_MODE,
