@@ -1,15 +1,19 @@
-// notebook.js 0.4.2
+// notebook.js 0.5.1
 // http://github.com/jsvine/notebookjs
 // notebook.js may be freely distributed under the MIT license.
 (function () {
+    var VERSION = "0.5.1";
     var root = this;
-    var VERSION = "0.4.2";
+    var isBrowser = root.window !== undefined;
+    var doc;
 
     // Get browser or JSDOM document
-    var doc = root.document;
-    if (!doc) {
+    if (isBrowser) {
+        doc = root.document;
+    } else {
         var jsdom = require("jsdom");
-        doc = new jsdom.JSDOM().window.document;
+        var dom = new jsdom.JSDOM();
+        doc = dom.window.document;
     }
 
     // Helper functions
@@ -52,11 +56,22 @@
         return lib && lib.ansi_to_html;
     };
 
+    var getSanitizer = function () {
+        if (isBrowser) {
+            var lib = root.DOMPurify || condRequire("dompurify");
+            return lib && lib.sanitize;
+        } else {
+            var createDOMPurify = condRequire("dompurify");
+            return createDOMPurify(dom.window).sanitize;
+        }
+    };
+
     // Set up `nb` namespace
     var nb = {
         prefix: "nb-",
         markdown: getMarkdown() || ident,
         ansi: getAnsi() || ident,
+        sanitizer: getSanitizer() || ident,
         highlighter: ident,
         VERSION: VERSION
     };
@@ -107,7 +122,7 @@
 
     nb.display.html = function (html) {
         var el = makeElement("div", [ "html-output" ]);
-        el.innerHTML = joinText(html);
+        el.innerHTML = nb.sanitizer(joinText(html));
         return el;
     };
     nb.display["text/html"] = nb.display.html;
