@@ -3,19 +3,17 @@
 # License: GNU Affero General Public License version 3, or any later version
 # See top-level LICENSE file for more information
 
-import json
 import requests
-
-from django.core.cache import cache
-from django.conf import settings
-from django.contrib.admin.views.decorators import staff_member_required
-from django.core.paginator import Paginator
-from django.http import HttpResponse
-from django.shortcuts import render
-
 from requests.auth import HTTPBasicAuth
 import sentry_sdk
 
+from django.conf import settings
+from django.contrib.admin.views.decorators import staff_member_required
+from django.core.cache import cache
+from django.core.paginator import Paginator
+from django.http import JsonResponse
+from django.shortcuts import render
+
 from swh.web.admin.adminurls import admin_route
 from swh.web.config import get_config
 
@@ -96,8 +94,8 @@ def _admin_deposit_list(request):
                 "reception_date": d["reception_date"],
                 "status": d["status"],
                 "status_detail": d["status_detail"],
-                "swh_id": d["swh_id"],
-                "swh_id_context": d["swh_id_context"],
+                "swhid": d["swhid"],
+                "swhid_context": d["swhid_context"],
             }
             for d in data
         ]
@@ -108,4 +106,4 @@ def _admin_deposit_list(request):
             "An error occurred while retrieving " "the list of deposits !"
         )
 
-    return HttpResponse(json.dumps(table_data), content_type="application/json")
+    return JsonResponse(table_data)
