@@ -6,15 +6,14 @@
 from distutils.util import strtobool
 from functools import partial
 
-from swh.web.common import service
-from swh.web.common.exc import BadInputExc
-from swh.web.common.origin_visits import get_origin_visits
-from swh.web.common.utils import reverse
 from swh.web.api.apidoc import api_doc, format_docstring
 from swh.web.api.apiurls import api_route
 from swh.web.api.utils import enrich_origin, enrich_origin_visit
 from swh.web.api.views.utils import api_lookup
-
+from swh.web.common import archive
+from swh.web.common.exc import BadInputExc
+from swh.web.common.origin_visits import get_origin_visits
+from swh.web.common.utils import reverse
 
 DOC_RETURN_ORIGIN = """
         :>json string origin_visits_url: link to in order to get information
@@ -80,28 +79,27 @@ def api_origins(request):
         .. parsed-literal::
 
             :swh_web_api:`origins?origin_count=500`
+
     """
-    origin_from = int(request.query_params.get("origin_from", "1"))
-    origin_count = int(request.query_params.get("origin_count", "100"))
-    origin_count = min(origin_count, 10000)
-    results = api_lookup(
-        service.lookup_origins,
-        origin_from,
-        origin_count + 1,
-        enrich_fn=enrich_origin,
-        request=request,
-    )
-    response = {"results": results, "headers": {}}
-    if len(results) > origin_count:
-        origin_from = results.pop()["id"]
+    old_param_origin_from = request.query_params.get("origin_from")
+
+    if old_param_origin_from:
+        raise BadInputExc("Please use the Link header to browse through result")
+
+    page_token = request.query_params.get("page_token", None)
+    limit = min(int(request.query_params.get("origin_count", "100")), 10000)
+
+    page_result = archive.lookup_origins(page_token, limit)
+    origins = [enrich_origin(o, request=request) for o in page_result.results]
+    next_page_token = page_result.next_page_token
+
+    response = {"results": origins, "headers": {}}
+    if next_page_token is not None:
         response["headers"]["link-next"] = reverse(
             "api-1-origins",
-            query_params={"origin_from": origin_from, "origin_count": origin_count},
+            query_params={"page_token": next_page_token, "origin_count": limit},
             request=request,
         )
-    for result in results:
-        if "id" in result:
-            del result["id"]
     return response
 
 
@@ -135,7 +133,7 @@ def api_origin(request, origin_url):
     error_msg = "Origin with url %s not found." % ori_dict["url"]
 
     return api_lookup(
-        service.lookup_origin,
+        archive.lookup_origin,
         ori_dict,
         notfound_msg=error_msg,
         enrich_fn=enrich_origin,
@@ -190,7 +188,7 @@ def api_origin_search(request, url_pattern):
     with_visit = request.query_params.get("with_visit", "false")
 
     (results, page_token) = api_lookup(
-        service.search_origin,
+        archive.search_origin,
         url_pattern,
         limit,
         bool(strtobool(with_visit)),
@@ -219,7 +217,7 @@ def api_origin_search(request, url_pattern):
 
 
 @api_route(r"/origin/metadata-search/", "api-1-origin-metadata-search")
-@api_doc("/origin/metadata-search/", noargs=True, need_params=True)
+@api_doc("/origin/metadata-search/", noargs=True)
 @format_docstring(return_origin_array=DOC_RETURN_ORIGIN_ARRAY)
 def api_origin_metadata_search(request):
     """
@@ -249,13 +247,12 @@ def api_origin_metadata_search(request):
     """
     fulltext = request.query_params.get("fulltext", None)
     limit = min(int(request.query_params.get("limit", "70")), 100)
-
     if not fulltext:
         content = '"fulltext" must be provided and non-empty.'
         raise BadInputExc(content)
 
     results = api_lookup(
-        service.search_origin_metadata, fulltext, limit, request=request
+        archive.search_origin_metadata, fulltext, limit, request=request
     )
 
     return {
@@ -385,7 +382,7 @@ def api_origin_visit_latest(request, origin_url=None):
     """
     require_snapshot = request.query_params.get("require_snapshot", "false")
     return api_lookup(
-        service.lookup_origin_visit_latest,
+        archive.lookup_origin_visit_latest,
         origin_url,
         bool(strtobool(require_snapshot)),
         notfound_msg=("No visit for origin {} found".format(origin_url)),
@@ -425,7 +422,7 @@ def api_origin_visit(request, visit_id, origin_url):
             :swh_web_api:`origin/https://github.com/hylang/hy/visit/1/`
     """
     return api_lookup(
-        service.lookup_origin_visit,
+        archive.lookup_origin_visit,
         origin_url,
         int(visit_id),
         notfound_msg=("No visit {} for origin {} found".format(visit_id, origin_url)),
@@ -462,14 +459,10 @@ def api_origin_intrinsic_metadata(request, origin_url):
 
             :swh_web_api:`origin/https://github.com/python/cpython/intrinsic-metadata`
     """
-    ori_dict = {"url": origin_url}
-
-    error_msg = "Origin with url %s not found" % ori_dict["url"]
-
     return api_lookup(
-        service.lookup_origin_intrinsic_metadata,
-        ori_dict,
-        notfound_msg=error_msg,
+        archive.lookup_origin_intrinsic_metadata,
+        origin_url,
+        notfound_msg=f"Origin with url {origin_url} not found",
         enrich_fn=enrich_origin,
         request=request,
     )
