@@ -54,29 +54,30 @@ let cssLoaders = [
   {
     loader: 'postcss-loader',
     options: {
-      ident: 'postcss',
       sourceMap: !isDevServer,
-      plugins: [
-        // lint swh-web stylesheets
-        require('stylelint')({
-          'config': {
-            'extends': 'stylelint-config-standard',
-            'rules': {
-              'indentation': 4,
-              'font-family-no-missing-generic-family-keyword': null,
-              'no-descending-specificity': null
-            },
-            'ignoreFiles': ['node_modules/**/*.css',
-                            'swh/web/assets/src/thirdparty/**/*.css']
-          }
-        }),
-        // automatically add vendor prefixes to css rules
-        require('autoprefixer')(),
-        require('postcss-normalize')(),
-        require('postcss-reporter')({
-          clearReportedMessages: true
-        })
-      ]
+      postcssOptions: {
+        plugins: [
+          // lint swh-web stylesheets
+          ['stylelint', {
+            'config': {
+              'extends': 'stylelint-config-standard',
+              'rules': {
+                'indentation': 4,
+                'font-family-no-missing-generic-family-keyword': null,
+                'no-descending-specificity': null
+              },
+              'ignoreFiles': ['node_modules/**/*.css',
+                              'swh/web/assets/src/thirdparty/**/*.css']
+            }
+          }],
+          // automatically add vendor prefixes to css rules
+          'autoprefixer',
+          'postcss-normalize',
+          ['postcss-reporter', {
+            clearReportedMessages: true
+          }]
+        ]
+      }
     }
   }
 ];
@@ -197,6 +198,18 @@ module.exports = {
             }
           }]
       },
+      {
+        test: /\.ejs$/,
+        use: [{
+          loader: 'ejs-compiled-loader',
+          options: {
+            htmlmin: true,
+            htmlminOptions: {
+              removeComments: true
+            }
+          }
+        }]
+      },
       // expose jquery to the global context as $ and jQuery when importing it
       {
         test: require.resolve('jquery'),
@@ -418,6 +431,14 @@ module.exports = {
               'spdxLicenseExpression': 'AGPL-3.0-or-later',
               'licenseFilePath': './LICENSE'
             }
+          ],
+          'https://piwik.inria.fr/matomo.js': [
+            {
+              'id': 'matomo.js',
+              'path': 'https://github.com/matomo-org/matomo/blob/master/js/piwik.js',
+              'spdxLicenseExpression': 'BSD-3-Clause',
+              'licenseFilePath': 'https://github.com/matomo-org/matomo/blob/master/js/LICENSE.txt'
+            }
           ]
         }
       )
