@@ -13,9 +13,9 @@ export * from 'd3-array';
 export * from 'd3-axis';
 // export * from 'd3-brush';
 // export * from 'd3-chord';
-export * from 'd3-collection';
 // export * from 'd3-color';
 // export * from 'd3-contour';
+// export * from 'd3-delaunay';
 // export * from 'd3-dispatch';
 // export * from 'd3-drag';
 // export * from 'd3-dsv';
@@ -38,5 +38,4 @@ export * from 'd3-time';
 export * from 'd3-time-format';
 // export * from 'd3-timer';
 export * from 'd3-transition';
-// export * from 'd3-voronoi';
 // export * from 'd3-zoom';
