@@ -6,65 +6,52 @@
 # Utility module for browsing the archive in a snapshot context.
 
 from collections import defaultdict
-from copy import copy
-from typing import Any, Dict, List, Optional, Union, Tuple
-
+from typing import Any, Dict, List, Optional, Tuple
 
 from django.core.cache import cache
 from django.shortcuts import render
 from django.template.defaultfilters import filesizeformat
 from django.utils.html import escape
-import sentry_sdk
-
-from swh.model.identifiers import (
-    persistent_identifier,
-    snapshot_identifier,
-    CONTENT,
-    DIRECTORY,
-    REVISION,
-    RELEASE,
-    SNAPSHOT,
-)
 
+from swh.model.identifiers import CONTENT, DIRECTORY, RELEASE, REVISION, SNAPSHOT, swhid
+from swh.model.model import Snapshot
 from swh.web.browse.utils import (
-    get_directory_entries,
-    gen_directory_link,
-    gen_revision_link,
-    gen_revision_url,
-    request_content,
-    gen_content_link,
-    prepare_content_for_display,
     content_display_max_size,
     format_log_entries,
-    gen_revision_log_link,
+    gen_content_link,
+    gen_directory_link,
     gen_release_link,
-    get_readme_to_display,
+    gen_revision_link,
+    gen_revision_log_link,
+    gen_revision_url,
     gen_snapshot_link,
+    get_directory_entries,
+    get_readme_to_display,
+    prepare_content_for_display,
+    request_content,
 )
-
-from swh.web.common import service, highlightjs
-from swh.web.common.exc import handle_view_exception, NotFoundExc, BadInputExc
+from swh.web.common import archive, highlightjs
+from swh.web.common.exc import BadInputExc, NotFoundExc
 from swh.web.common.identifiers import get_swhids_info
 from swh.web.common.origin_visits import get_origin_visit
 from swh.web.common.typing import (
-    OriginInfo,
-    SnapshotBranchInfo,
-    SnapshotReleaseInfo,
-    SnapshotContext,
     ContentMetadata,
     DirectoryMetadata,
+    OriginInfo,
+    SnapshotBranchInfo,
+    SnapshotContext,
+    SnapshotReleaseInfo,
     SWHObjectInfo,
 )
 from swh.web.common.utils import (
-    reverse,
-    gen_path_info,
     format_utc_iso_date,
+    gen_path_info,
+    reverse,
     swh_object_icons,
 )
 from swh.web.config import get_config
 
-
-_empty_snapshot_id = snapshot_identifier({"branches": {}})
+_empty_snapshot_id = Snapshot(branches={}).id.hex()
 
 
 def _get_branch(branches, branch_name, snapshot_id):
@@ -85,13 +72,13 @@ def _get_branch(branches, branch_name, snapshot_id):
             return branches[0]
     else:
         # case where a large branches list has been truncated
-        snp = service.lookup_snapshot(
+        snp = archive.lookup_snapshot(
             snapshot_id,
             branches_from=branch_name,
             branches_count=1,
             target_types=["revision", "alias"],
         )
-        snp_branch, _ = process_snapshot_branches(snp)
+        snp_branch, _, _ = process_snapshot_branches(snp)
         if snp_branch and snp_branch[0]["name"] == branch_name:
             branches.append(snp_branch[0])
             return snp_branch[0]
@@ -109,20 +96,20 @@ def _get_release(releases, release_name, snapshot_id):
         # case where a large branches list has been truncated
         try:
             # git origins have specific branches for releases
-            snp = service.lookup_snapshot(
+            snp = archive.lookup_snapshot(
                 snapshot_id,
                 branches_from=f"refs/tags/{release_name}",
                 branches_count=1,
                 target_types=["release"],
             )
         except NotFoundExc:
-            snp = service.lookup_snapshot(
+            snp = archive.lookup_snapshot(
                 snapshot_id,
                 branches_from=release_name,
                 branches_count=1,
                 target_types=["release"],
             )
-        _, snp_release = process_snapshot_branches(snp)
+        _, snp_release, _ = process_snapshot_branches(snp)
         if snp_release and snp_release[0]["name"] == release_name:
             releases.append(snp_release[0])
             return snp_release[0]
@@ -184,7 +171,7 @@ def _branch_not_found(
 
 def process_snapshot_branches(
     snapshot: Dict[str, Any]
-) -> Tuple[List[SnapshotBranchInfo], List[SnapshotReleaseInfo]]:
+) -> Tuple[List[SnapshotBranchInfo], List[SnapshotReleaseInfo], Dict[str, Any]]:
     """
     Process a dictionary describing snapshot branches: extract those
     targeting revisions and releases, put them in two different lists,
@@ -192,12 +179,13 @@ def process_snapshot_branches(
 
     Args:
         snapshot: A dict describing a snapshot as returned for instance by
-            :func:`swh.web.common.service.lookup_snapshot`
+            :func:`swh.web.common.archive.lookup_snapshot`
 
     Returns:
         A tuple whose first member is the sorted list of branches
-        targeting revisions and second member the sorted list of branches
-        targeting releases
+        targeting revisions, second member the sorted list of branches
+        targeting releases and third member a dict mapping resolved branch
+        aliases to their real target.
     """
     snapshot_branches = snapshot["branches"]
     branches: Dict[str, SnapshotBranchInfo] = {}
@@ -215,6 +203,7 @@ def process_snapshot_branches(
         if target_type == "revision":
             branches[branch_name] = SnapshotBranchInfo(
                 name=branch_name,
+                alias=False,
                 revision=target_id,
                 date=None,
                 directory=None,
@@ -228,9 +217,10 @@ def process_snapshot_branches(
             branch_aliases[branch_name] = target_id
         # FIXME: handle pointers to other object types
 
-    def _add_release_info(branch, release):
+    def _add_release_info(branch, release, alias=False):
         releases[branch] = SnapshotReleaseInfo(
             name=release["name"],
+            alias=alias,
             branch_name=branch,
             date=format_utc_iso_date(release["date"]),
             directory=None,
@@ -241,9 +231,10 @@ def process_snapshot_branches(
             url=None,
         )
 
-    def _add_branch_info(branch, revision):
+    def _add_branch_info(branch, revision, alias=False):
         branches[branch] = SnapshotBranchInfo(
             name=branch,
+            alias=alias,
             revision=revision["id"],
             directory=revision["directory"],
             date=format_utc_iso_date(revision["date"]),
@@ -251,15 +242,17 @@ def process_snapshot_branches(
             url=None,
         )
 
-    releases_info = service.lookup_release_multiple(release_to_branch.keys())
+    releases_info = archive.lookup_release_multiple(release_to_branch.keys())
     for release in releases_info:
+        if release is None:
+            continue
         branches_to_update = release_to_branch[release["id"]]
         for branch in branches_to_update:
             _add_release_info(branch, release)
         if release["target_type"] == "revision":
             revision_to_release[release["target"]].update(branches_to_update)
 
-    revisions = service.lookup_revision_multiple(
+    revisions = archive.lookup_revision_multiple(
         set(revision_to_branch.keys()) | set(revision_to_release.keys())
     )
 
@@ -268,30 +261,26 @@ def process_snapshot_branches(
             continue
         for branch in revision_to_branch[revision["id"]]:
             _add_branch_info(branch, revision)
-        for release in revision_to_release[revision["id"]]:
-            releases[release]["directory"] = revision["directory"]
+        for release_id in revision_to_release[revision["id"]]:
+            releases[release_id]["directory"] = revision["directory"]
+
+    resolved_aliases = {}
 
     for branch_alias, branch_target in branch_aliases.items():
-        if branch_target in branches:
-            branches[branch_alias] = copy(branches[branch_target])
-        else:
-            snp = service.lookup_snapshot(
-                snapshot["id"], branches_from=branch_target, branches_count=1
-            )
-            if snp and branch_target in snp["branches"]:
+        resolved_alias = archive.lookup_snapshot_alias(snapshot["id"], branch_alias)
+        resolved_aliases[branch_alias] = resolved_alias
+        if resolved_alias is None:
+            continue
 
-                if snp["branches"][branch_target] is None:
-                    continue
+        target_type = resolved_alias["target_type"]
+        target = resolved_alias["target"]
 
-                target_type = snp["branches"][branch_target]["target_type"]
-                target = snp["branches"][branch_target]["target"]
-                if target_type == "revision":
-                    branches[branch_alias] = snp["branches"][branch_target]
-                    revision = service.lookup_revision(target)
-                    _add_branch_info(branch_alias, revision)
-                elif target_type == "release":
-                    release = service.lookup_release(target)
-                    _add_release_info(branch_alias, release)
+        if target_type == "revision":
+            revision = archive.lookup_revision(target)
+            _add_branch_info(branch_alias, revision, alias=True)
+        elif target_type == "release":
+            release = archive.lookup_release(target)
+            _add_release_info(branch_alias, release, alias=True)
 
         if branch_alias in branches:
             branches[branch_alias]["name"] = branch_alias
@@ -299,12 +288,12 @@ def process_snapshot_branches(
     ret_branches = list(sorted(branches.values(), key=lambda b: b["name"]))
     ret_releases = list(sorted(releases.values(), key=lambda b: b["name"]))
 
-    return ret_branches, ret_releases
+    return ret_branches, ret_releases, resolved_aliases
 
 
 def get_snapshot_content(
     snapshot_id: str,
-) -> Tuple[List[SnapshotBranchInfo], List[SnapshotReleaseInfo]]:
+) -> Tuple[List[SnapshotBranchInfo], List[SnapshotReleaseInfo], Dict[str, Any]]:
     """Returns the lists of branches and releases
     associated to a swh snapshot.
     That list is put in  cache in order to speedup the navigation
@@ -317,9 +306,10 @@ def get_snapshot_content(
         snapshot_id: hexadecimal representation of the snapshot identifier
 
     Returns:
-        A tuple with two members. The first one is a list of dict describing
+        A tuple with three members. The first one is a list of dict describing
         the snapshot branches. The second one is a list of dict describing the
-        snapshot releases.
+        snapshot releases. The third one is a dict mapping resolved branch
+        aliases to their real target.
 
     Raises:
         NotFoundExc if the snapshot does not exist
@@ -328,30 +318,37 @@ def get_snapshot_content(
     cache_entry = cache.get(cache_entry_id)
 
     if cache_entry:
-        return cache_entry["branches"], cache_entry["releases"]
+        return (
+            cache_entry["branches"],
+            cache_entry["releases"],
+            cache_entry.get("aliases", {}),
+        )
 
     branches: List[SnapshotBranchInfo] = []
     releases: List[SnapshotReleaseInfo] = []
+    aliases: Dict[str, Any] = {}
 
     snapshot_content_max_size = get_config()["snapshot_content_max_size"]
 
     if snapshot_id:
-        snapshot = service.lookup_snapshot(
+        snapshot = archive.lookup_snapshot(
             snapshot_id, branches_count=snapshot_content_max_size
         )
-        branches, releases = process_snapshot_branches(snapshot)
+        branches, releases, aliases = process_snapshot_branches(snapshot)
 
-    cache.set(cache_entry_id, {"branches": branches, "releases": releases,})
+    cache.set(
+        cache_entry_id, {"branches": branches, "releases": releases, "aliases": aliases}
+    )
 
-    return branches, releases
+    return branches, releases, aliases
 
 
 def get_origin_visit_snapshot(
     origin_info: OriginInfo,
-    visit_ts: Optional[Union[int, str]] = None,
+    visit_ts: Optional[str] = None,
     visit_id: Optional[int] = None,
     snapshot_id: Optional[str] = None,
-) -> Tuple[List[SnapshotBranchInfo], List[SnapshotReleaseInfo]]:
+) -> Tuple[List[SnapshotBranchInfo], List[SnapshotReleaseInfo], Dict[str, Any]]:
     """Returns the lists of branches and releases associated to an origin for
     a given visit.
 
@@ -372,16 +369,17 @@ def get_origin_visit_snapshot(
 
     Args:
         origin_info: a dict filled with origin information
-        visit_ts: an ISO date string or Unix timestamp to parse
+        visit_ts: an ISO 8601 datetime string to parse
         visit_id: visit id for disambiguation in case several visits have
             the same timestamp
         snapshot_id: if provided, visit associated to the snapshot will be processed
 
     Returns:
-        A tuple with two members. The first one is a list of dict describing
+        A tuple with three members. The first one is a list of dict describing
         the origin branches for the given visit.
         The second one is a list of dict describing the origin releases
-        for the given visit.
+        for the given visit. The third one is a dict mapping resolved branch
+        aliases to their real target.
 
     Raises:
         NotFoundExc if the origin or its visit are not found
@@ -445,7 +443,7 @@ def get_snapshot_context(
         elif snapshot_id is not None:
             query_params["snapshot"] = snapshot_id
 
-        origin_info = service.lookup_origin({"url": origin_url})
+        origin_info = archive.lookup_origin({"url": origin_url})
 
         visit_info = get_origin_visit(origin_info, timestamp, visit_id, snapshot_id)
         formatted_date = format_utc_iso_date(visit_info["date"])
@@ -464,7 +462,7 @@ def get_snapshot_context(
         if timestamp:
             timestamp = visit_info["date"]
 
-        branches, releases = get_origin_visit_snapshot(
+        branches, releases, aliases = get_origin_visit_snapshot(
             origin_info, timestamp, visit_id, snapshot_id
         )
 
@@ -487,7 +485,7 @@ def get_snapshot_context(
         releases_url = reverse("browse-origin-releases", query_params=query_params)
     else:
         assert snapshot_id is not None
-        branches, releases = get_snapshot_content(snapshot_id)
+        branches, releases, aliases = get_snapshot_content(snapshot_id)
         url_args = {"snapshot_id": snapshot_id}
         branches_url = reverse("browse-snapshot-branches", url_args=url_args)
 
@@ -495,11 +493,15 @@ def get_snapshot_context(
 
     releases = list(reversed(releases))
 
-    snapshot_sizes = service.lookup_snapshot_sizes(snapshot_id)
+    snapshot_sizes_cache_id = f"swh_snapshot_{snapshot_id}_sizes"
+    snapshot_sizes = cache.get(snapshot_sizes_cache_id)
+    if snapshot_sizes is None:
+        snapshot_sizes = archive.lookup_snapshot_sizes(snapshot_id)
+        cache.set(snapshot_sizes_cache_id, snapshot_sizes)
 
-    is_empty = sum(snapshot_sizes.values()) == 0
+    is_empty = (snapshot_sizes["release"] + snapshot_sizes["revision"]) == 0
 
-    swh_snp_id = persistent_identifier("snapshot", snapshot_id)
+    swh_snp_id = swhid("snapshot", snapshot_id)
 
     if visit_info:
         timestamp = format_utc_iso_date(visit_info["date"])
@@ -512,17 +514,18 @@ def get_snapshot_context(
     release_id = None
     root_directory = None
 
-    snapshot_total_size = sum(snapshot_sizes.values())
+    snapshot_total_size = snapshot_sizes["release"] + snapshot_sizes["revision"]
 
     if path is not None:
         query_params["path"] = path
 
     if snapshot_total_size and revision_id is not None:
-        revision = service.lookup_revision(revision_id)
+        revision = archive.lookup_revision(revision_id)
         root_directory = revision["directory"]
         branches.append(
             SnapshotBranchInfo(
                 name=revision_id,
+                alias=False,
                 revision=revision_id,
                 directory=root_directory,
                 date=revision["date"],
@@ -534,13 +537,7 @@ def get_snapshot_context(
         query_params["revision"] = revision_id
     elif snapshot_total_size and release_name:
         release = _get_release(releases, release_name, snapshot_id)
-        try:
-            root_directory = release["directory"]
-            revision_id = release["target"]
-            release_id = release["id"]
-            query_params["release"] = release_name
-        except Exception as exc:
-            sentry_sdk.capture_exception(exc)
+        if release is None:
             _branch_not_found(
                 "release",
                 release_name,
@@ -550,16 +547,16 @@ def get_snapshot_context(
                 timestamp,
                 visit_id,
             )
+        else:
+            root_directory = release["directory"]
+            revision_id = release["target"]
+            release_id = release["id"]
+            query_params["release"] = release_name
     elif snapshot_total_size:
         if branch_name:
             query_params["branch"] = branch_name
         branch = _get_branch(branches, branch_name or "HEAD", snapshot_id)
-        try:
-            branch_name = branch["name"]
-            revision_id = branch["revision"]
-            root_directory = branch["directory"]
-        except Exception as exc:
-            sentry_sdk.capture_exception(exc)
+        if branch is None:
             _branch_not_found(
                 "branch",
                 branch_name,
@@ -569,6 +566,10 @@ def get_snapshot_context(
                 timestamp,
                 visit_id,
             )
+        else:
+            branch_name = branch["name"]
+            revision_id = branch["revision"]
+            root_directory = branch["directory"]
 
     for b in branches:
         branch_query_params = dict(query_params)
@@ -592,7 +593,7 @@ def get_snapshot_context(
     revision_info = None
     if revision_id:
         try:
-            revision_info = service.lookup_revision(revision_id)
+            revision_info = archive.lookup_revision(revision_id)
         except NotFoundExc:
             pass
         else:
@@ -608,12 +609,14 @@ def get_snapshot_context(
 
     snapshot_context = SnapshotContext(
         branch=branch_name,
+        branch_alias=branch_name in aliases,
         branches=branches,
         branches_url=branches_url,
         is_empty=is_empty,
         origin_info=origin_info,
         origin_visits_url=origin_visits_url,
         release=release_name,
+        release_alias=release_name in aliases,
         release_id=release_id,
         query_params=query_params,
         releases=releases,
@@ -682,35 +685,30 @@ def browse_snapshot_directory(
     """
     Django view implementation for browsing a directory in a snapshot context.
     """
-    try:
+    _check_origin_url(snapshot_id, origin_url)
 
-        _check_origin_url(snapshot_id, origin_url)
+    snapshot_context = get_snapshot_context(
+        snapshot_id=snapshot_id,
+        origin_url=origin_url,
+        timestamp=timestamp,
+        visit_id=request.GET.get("visit_id"),
+        path=path,
+        browse_context="directory",
+        branch_name=request.GET.get("branch"),
+        release_name=request.GET.get("release"),
+        revision_id=request.GET.get("revision"),
+    )
 
-        snapshot_context = get_snapshot_context(
-            snapshot_id=snapshot_id,
-            origin_url=origin_url,
-            timestamp=timestamp,
-            visit_id=request.GET.get("visit_id"),
-            path=path,
-            browse_context="directory",
-            branch_name=request.GET.get("branch"),
-            release_name=request.GET.get("release"),
-            revision_id=request.GET.get("revision"),
-        )
+    root_directory = snapshot_context["root_directory"]
+    sha1_git = root_directory
+    if root_directory and path:
+        dir_info = archive.lookup_directory_with_path(root_directory, path)
+        sha1_git = dir_info["target"]
 
-        root_directory = snapshot_context["root_directory"]
-        sha1_git = root_directory
-        if root_directory and path:
-            dir_info = service.lookup_directory_with_path(root_directory, path)
-            sha1_git = dir_info["target"]
-
-        dirs = []
-        files = []
-        if sha1_git:
-            dirs, files = get_directory_entries(sha1_git)
-
-    except Exception as exc:
-        return handle_view_exception(request, exc)
+    dirs = []
+    files = []
+    if sha1_git:
+        dirs, files = get_directory_entries(sha1_git)
 
     origin_info = snapshot_context["origin_info"]
     visit_info = snapshot_context["visit_info"]
@@ -788,7 +786,7 @@ def browse_snapshot_directory(
     revision_found = True
     if sha1_git is None and revision_id is not None:
         try:
-            service.lookup_revision(revision_id)
+            archive.lookup_revision(revision_id)
         except NotFoundExc:
             revision_found = False
 
@@ -892,47 +890,42 @@ def browse_snapshot_content(
     """
     Django view implementation for browsing a content in a snapshot context.
     """
-    try:
+    _check_origin_url(snapshot_id, origin_url)
 
-        _check_origin_url(snapshot_id, origin_url)
+    if path is None:
+        raise BadInputExc("The path of a content must be given as query parameter.")
 
-        if path is None:
-            raise BadInputExc("The path of a content must be given as query parameter.")
+    snapshot_context = get_snapshot_context(
+        snapshot_id=snapshot_id,
+        origin_url=origin_url,
+        timestamp=timestamp,
+        visit_id=request.GET.get("visit_id"),
+        path=path,
+        browse_context="content",
+        branch_name=request.GET.get("branch"),
+        release_name=request.GET.get("release"),
+        revision_id=request.GET.get("revision"),
+    )
 
-        snapshot_context = get_snapshot_context(
-            snapshot_id=snapshot_id,
-            origin_url=origin_url,
-            timestamp=timestamp,
-            visit_id=request.GET.get("visit_id"),
-            path=path,
-            browse_context="content",
-            branch_name=request.GET.get("branch"),
-            release_name=request.GET.get("release"),
-            revision_id=request.GET.get("revision"),
-        )
+    root_directory = snapshot_context["root_directory"]
+    sha1_git = None
+    query_string = None
+    content_data = {}
+    directory_id = None
+    split_path = path.split("/")
+    filename = split_path[-1]
+    filepath = path[: -len(filename)]
+    if root_directory:
+        content_info = archive.lookup_directory_with_path(root_directory, path)
+        sha1_git = content_info["target"]
+        query_string = "sha1_git:" + sha1_git
+        content_data = request_content(query_string, raise_if_unavailable=False)
 
-        root_directory = snapshot_context["root_directory"]
-        sha1_git = None
-        query_string = None
-        content_data = {}
-        directory_id = None
-        split_path = path.split("/")
-        filename = split_path[-1]
-        filepath = path[: -len(filename)]
-        if root_directory:
-            content_info = service.lookup_directory_with_path(root_directory, path)
-            sha1_git = content_info["target"]
-            query_string = "sha1_git:" + sha1_git
-            content_data = request_content(query_string, raise_if_unavailable=False)
-
-            if filepath:
-                dir_info = service.lookup_directory_with_path(root_directory, filepath)
-                directory_id = dir_info["target"]
-            else:
-                directory_id = root_directory
-
-    except Exception as exc:
-        return handle_view_exception(request, exc)
+        if filepath:
+            dir_info = archive.lookup_directory_with_path(root_directory, filepath)
+            directory_id = dir_info["target"]
+        else:
+            directory_id = root_directory
 
     revision_id = snapshot_context["revision_id"]
     origin_info = snapshot_context["origin_info"]
@@ -1005,7 +998,6 @@ def browse_snapshot_content(
         encoding=content_data.get("encoding"),
         size=filesizeformat(content_data.get("length", 0)),
         language=content_data.get("language"),
-        licenses=content_data.get("licenses"),
         root_directory=root_directory,
         path=f"/{filepath}",
         filename=filename,
@@ -1079,54 +1071,49 @@ def browse_snapshot_log(request, snapshot_id=None, origin_url=None, timestamp=No
     Django view implementation for browsing a revision history in a
     snapshot context.
     """
-    try:
+    _check_origin_url(snapshot_id, origin_url)
 
-        _check_origin_url(snapshot_id, origin_url)
+    snapshot_context = get_snapshot_context(
+        snapshot_id=snapshot_id,
+        origin_url=origin_url,
+        timestamp=timestamp,
+        visit_id=request.GET.get("visit_id"),
+        browse_context="log",
+        branch_name=request.GET.get("branch"),
+        release_name=request.GET.get("release"),
+        revision_id=request.GET.get("revision"),
+    )
 
-        snapshot_context = get_snapshot_context(
-            snapshot_id=snapshot_id,
-            origin_url=origin_url,
-            timestamp=timestamp,
-            visit_id=request.GET.get("visit_id"),
-            browse_context="log",
-            branch_name=request.GET.get("branch"),
-            release_name=request.GET.get("release"),
-            revision_id=request.GET.get("revision"),
+    revision_id = snapshot_context["revision_id"]
+
+    per_page = int(request.GET.get("per_page", PER_PAGE))
+    offset = int(request.GET.get("offset", 0))
+    revs_ordering = request.GET.get("revs_ordering", "committer_date")
+    session_key = "rev_%s_log_ordering_%s" % (revision_id, revs_ordering)
+    rev_log_session = request.session.get(session_key, None)
+    rev_log = []
+    revs_walker_state = None
+    if rev_log_session:
+        rev_log = rev_log_session["rev_log"]
+        revs_walker_state = rev_log_session["revs_walker_state"]
+
+    if len(rev_log) < offset + per_page:
+        revs_walker = archive.get_revisions_walker(
+            revs_ordering,
+            revision_id,
+            max_revs=offset + per_page + 1,
+            state=revs_walker_state,
         )
+        rev_log += [rev["id"] for rev in revs_walker]
+        revs_walker_state = revs_walker.export_state()
 
-        revision_id = snapshot_context["revision_id"]
+    revs = rev_log[offset : offset + per_page]
+    revision_log = archive.lookup_revision_multiple(revs)
 
-        per_page = int(request.GET.get("per_page", PER_PAGE))
-        offset = int(request.GET.get("offset", 0))
-        revs_ordering = request.GET.get("revs_ordering", "committer_date")
-        session_key = "rev_%s_log_ordering_%s" % (revision_id, revs_ordering)
-        rev_log_session = request.session.get(session_key, None)
-        rev_log = []
-        revs_walker_state = None
-        if rev_log_session:
-            rev_log = rev_log_session["rev_log"]
-            revs_walker_state = rev_log_session["revs_walker_state"]
-
-        if len(rev_log) < offset + per_page:
-            revs_walker = service.get_revisions_walker(
-                revs_ordering,
-                revision_id,
-                max_revs=offset + per_page + 1,
-                state=revs_walker_state,
-            )
-            rev_log += [rev["id"] for rev in revs_walker]
-            revs_walker_state = revs_walker.export_state()
-
-        revs = rev_log[offset : offset + per_page]
-        revision_log = service.lookup_revision_multiple(revs)
-
-        request.session[session_key] = {
-            "rev_log": rev_log,
-            "revs_walker_state": revs_walker_state,
-        }
-
-    except Exception as exc:
-        return handle_view_exception(request, exc)
+    request.session[session_key] = {
+        "rev_log": rev_log,
+        "revs_walker_state": revs_walker_state,
+    }
 
     origin_info = snapshot_context["origin_info"]
     visit_info = snapshot_context["visit_info"]
@@ -1136,7 +1123,7 @@ def browse_snapshot_log(request, snapshot_id=None, origin_url=None, timestamp=No
 
     query_params["per_page"] = per_page
     revs_ordering = request.GET.get("revs_ordering", "")
-    query_params["revs_ordering"] = revs_ordering
+    query_params["revs_ordering"] = revs_ordering or None
 
     if origin_info:
         browse_view_name = "browse-origin-log"
@@ -1224,41 +1211,36 @@ def browse_snapshot_branches(
     Django view implementation for browsing a list of branches in a snapshot
     context.
     """
-    try:
+    _check_origin_url(snapshot_id, origin_url)
 
-        _check_origin_url(snapshot_id, origin_url)
+    snapshot_context = get_snapshot_context(
+        snapshot_id=snapshot_id,
+        origin_url=origin_url,
+        timestamp=timestamp,
+        visit_id=request.GET.get("visit_id"),
+    )
 
-        snapshot_context = get_snapshot_context(
-            snapshot_id=snapshot_id,
-            origin_url=origin_url,
-            timestamp=timestamp,
-            visit_id=request.GET.get("visit_id"),
-        )
+    branches_bc = request.GET.get("branches_breadcrumbs", "")
+    branches_bc = branches_bc.split(",") if branches_bc else []
+    branches_from = branches_bc[-1] if branches_bc else ""
 
-        branches_bc = request.GET.get("branches_breadcrumbs", "")
-        branches_bc = branches_bc.split(",") if branches_bc else []
-        branches_from = branches_bc[-1] if branches_bc else ""
+    origin_info = snapshot_context["origin_info"]
+    url_args = snapshot_context["url_args"]
+    query_params = snapshot_context["query_params"]
 
-        origin_info = snapshot_context["origin_info"]
-        url_args = snapshot_context["url_args"]
-        query_params = snapshot_context["query_params"]
+    if origin_info:
+        browse_view_name = "browse-origin-directory"
+    else:
+        browse_view_name = "browse-snapshot-directory"
 
-        if origin_info:
-            browse_view_name = "browse-origin-directory"
-        else:
-            browse_view_name = "browse-snapshot-directory"
+    snapshot = archive.lookup_snapshot(
+        snapshot_context["snapshot_id"],
+        branches_from,
+        PER_PAGE + 1,
+        target_types=["revision", "alias"],
+    )
 
-        snapshot = service.lookup_snapshot(
-            snapshot_context["snapshot_id"],
-            branches_from,
-            PER_PAGE + 1,
-            target_types=["revision", "alias"],
-        )
-
-        displayed_branches, _ = process_snapshot_branches(snapshot)
-
-    except Exception as exc:
-        return handle_view_exception(request, exc)
+    displayed_branches, _, _ = process_snapshot_branches(snapshot)
 
     for branch in displayed_branches:
         rev_query_params = {}
@@ -1338,36 +1320,31 @@ def browse_snapshot_releases(
     Django view implementation for browsing a list of releases in a snapshot
     context.
     """
-    try:
+    _check_origin_url(snapshot_id, origin_url)
 
-        _check_origin_url(snapshot_id, origin_url)
+    snapshot_context = get_snapshot_context(
+        snapshot_id=snapshot_id,
+        origin_url=origin_url,
+        timestamp=timestamp,
+        visit_id=request.GET.get("visit_id"),
+    )
 
-        snapshot_context = get_snapshot_context(
-            snapshot_id=snapshot_id,
-            origin_url=origin_url,
-            timestamp=timestamp,
-            visit_id=request.GET.get("visit_id"),
-        )
+    rel_bc = request.GET.get("releases_breadcrumbs", "")
+    rel_bc = rel_bc.split(",") if rel_bc else []
+    rel_from = rel_bc[-1] if rel_bc else ""
 
-        rel_bc = request.GET.get("releases_breadcrumbs", "")
-        rel_bc = rel_bc.split(",") if rel_bc else []
-        rel_from = rel_bc[-1] if rel_bc else ""
+    origin_info = snapshot_context["origin_info"]
+    url_args = snapshot_context["url_args"]
+    query_params = snapshot_context["query_params"]
 
-        origin_info = snapshot_context["origin_info"]
-        url_args = snapshot_context["url_args"]
-        query_params = snapshot_context["query_params"]
+    snapshot = archive.lookup_snapshot(
+        snapshot_context["snapshot_id"],
+        rel_from,
+        PER_PAGE + 1,
+        target_types=["release", "alias"],
+    )
 
-        snapshot = service.lookup_snapshot(
-            snapshot_context["snapshot_id"],
-            rel_from,
-            PER_PAGE + 1,
-            target_types=["release", "alias"],
-        )
-
-        _, displayed_releases = process_snapshot_branches(snapshot)
-
-    except Exception as exc:
-        return handle_view_exception(request, exc)
+    _, displayed_releases, _ = process_snapshot_branches(snapshot)
 
     for release in displayed_releases:
         query_params_tgt = {"snapshot": snapshot_id}
