@@ -4,17 +4,16 @@
 # See top-level LICENSE file for more information
 
 from django.conf.urls import url
-from django.shortcuts import render, redirect
+from django.shortcuts import redirect, render
 
-import swh.web.browse.views.directory  # noqa
+from swh.web.browse.browseurls import BrowseUrls
+from swh.web.browse.identifiers import swhid_browse
 import swh.web.browse.views.content  # noqa
+import swh.web.browse.views.directory  # noqa
 import swh.web.browse.views.origin  # noqa
 import swh.web.browse.views.release  # noqa
 import swh.web.browse.views.revision  # noqa
 import swh.web.browse.views.snapshot  # noqa
-
-from swh.web.browse.browseurls import BrowseUrls
-from swh.web.browse.identifiers import swh_id_browse
 from swh.web.common.utils import reverse
 
 
@@ -49,7 +48,7 @@ urlpatterns = [
     url(r"^vault/$", _browse_vault_view, name="browse-vault"),
     # for backward compatibility
     url(r"^origin/save/$", _browse_origin_save_view, name="browse-origin-save"),
-    url(r"^(?P<swh_id>swh:[0-9]+:[a-z]+:[0-9a-f]+.*)/$", swh_id_browse),
+    url(r"^(?P<swhid>swh:[0-9]+:[a-z]+:[0-9a-f]+.*)/$", swhid_browse),
 ]
 
 urlpatterns += BrowseUrls.get_url_patterns()
