@@ -4,24 +4,24 @@
 # See top-level LICENSE file for more information
 
 import base64
-import magic
 import stat
 import textwrap
-
 from threading import Lock
 
-from django.core.cache import cache
-from django.utils.safestring import mark_safe
-from django.utils.html import escape
+import magic
 import sentry_sdk
 
-from swh.web.common import highlightjs, service
+from django.core.cache import cache
+from django.utils.html import escape
+from django.utils.safestring import mark_safe
+
+from swh.web.common import archive, highlightjs
 from swh.web.common.exc import http_status_code_message
 from swh.web.common.utils import (
-    reverse,
-    format_utc_iso_date,
-    rst_to_html,
     browsers_supported_image_mimes,
+    format_utc_iso_date,
+    reverse,
+    rst_to_html,
 )
 from swh.web.config import get_config
 
@@ -49,7 +49,7 @@ def get_directory_entries(sha1_git):
     if cache_entry:
         return cache_entry
 
-    entries = list(service.lookup_directory(sha1_git))
+    entries = list(archive.lookup_directory(sha1_git))
     for e in entries:
         e["perms"] = stat.filemode(e["perms"])
         if e["type"] == "rev":
@@ -83,27 +83,10 @@ def get_mimetype_and_encoding_for_content(content):
         associated to the provided content.
 
     """
-    # https://pypi.org/project/python-magic/
-    # packaged as python3-magic in debian buster
-    if hasattr(magic, "from_buffer"):
-        m = magic.Magic(mime=True, mime_encoding=True)
-        mime_encoding = m.from_buffer(content)
-        mime_type, encoding = mime_encoding.split(";")
-        encoding = encoding.replace(" charset=", "")
-    # https://pypi.org/project/file-magic/
-    # packaged as python3-magic in debian stretch
-    else:
-        # TODO: Remove that code when production environment is upgraded
-        #       to debian buster
-
-        # calls to the file-magic API are not thread-safe so they must
-        # be protected with a Lock to guarantee they will succeed
-        _lock.acquire()
-        magic_result = magic.detect_from_content(content)
-        _lock.release()
-        mime_type = magic_result.mime_type
-        encoding = magic_result.encoding
-
+    m = magic.Magic(mime=True, mime_encoding=True)
+    mime_encoding = m.from_buffer(content)
+    mime_type, encoding = mime_encoding.split(";")
+    encoding = encoding.replace(" charset=", "")
     return mime_type, encoding
 
 
@@ -166,16 +149,14 @@ def request_content(
     Raises:
         NotFoundExc if the content is not found
     """
-    content_data = service.lookup_content(query_string)
+    content_data = archive.lookup_content(query_string)
     filetype = None
     language = None
-    license = None
     # requests to the indexer db may fail so properly handle
     # those cases in order to avoid content display errors
     try:
-        filetype = service.lookup_content_filetype(query_string)
-        language = service.lookup_content_language(query_string)
-        license = service.lookup_content_license(query_string)
+        filetype = archive.lookup_content_filetype(query_string)
+        language = archive.lookup_content_language(query_string)
     except Exception as exc:
         sentry_sdk.capture_exception(exc)
     mimetype = "unknown"
@@ -195,7 +176,7 @@ def request_content(
 
     if not max_size or content_data["length"] < max_size:
         try:
-            content_raw = service.lookup_content_raw(query_string)
+            content_raw = archive.lookup_content_raw(query_string)
         except Exception as exc:
             if raise_if_unavailable:
                 raise exc
@@ -234,10 +215,6 @@ def request_content(
         content_data["language"] = language["lang"]
     else:
         content_data["language"] = "not detected"
-    if license:
-        content_data["licenses"] = ", ".join(license["facts"][0]["licenses"])
-    else:
-        content_data["licenses"] = "not detected"
 
     return content_data
 
