@@ -4,32 +4,30 @@
 # See top-level LICENSE file for more information
 
 import difflib
-import json
-
 from distutils.util import strtobool
 
-from django.http import HttpResponse
+import sentry_sdk
+
+from django.http import HttpResponse, JsonResponse
 from django.shortcuts import render
 from django.template.defaultfilters import filesizeformat
-import sentry_sdk
 
 from swh.model.hashutil import hash_to_hex
 from swh.model.identifiers import CONTENT, DIRECTORY, RELEASE, REVISION, SNAPSHOT
-
 from swh.web.browse.browseurls import browse_route
 from swh.web.browse.snapshot_context import get_snapshot_context
 from swh.web.browse.utils import (
-    request_content,
-    prepare_content_for_display,
     content_display_max_size,
-    gen_link,
     gen_directory_link,
+    gen_link,
+    prepare_content_for_display,
+    request_content,
 )
-from swh.web.common import query, service, highlightjs
-from swh.web.common.exc import NotFoundExc, handle_view_exception
+from swh.web.common import archive, highlightjs, query
+from swh.web.common.exc import NotFoundExc
 from swh.web.common.identifiers import get_swhids_info
 from swh.web.common.typing import ContentMetadata, SWHObjectInfo
-from swh.web.common.utils import reverse, gen_path_info, swh_object_icons
+from swh.web.common.utils import gen_path_info, reverse, swh_object_icons
 
 
 @browse_route(
@@ -44,13 +42,10 @@ def content_raw(request, query_string):
     The url that points to it is
     :http:get:`/browse/content/[(algo_hash):](hash)/raw/`
     """
-    try:
-        re_encode = bool(strtobool(request.GET.get("re_encode", "false")))
-        algo, checksum = query.parse_hash(query_string)
-        checksum = hash_to_hex(checksum)
-        content_data = request_content(query_string, max_size=None, re_encode=re_encode)
-    except Exception as exc:
-        return handle_view_exception(request, exc)
+    re_encode = bool(strtobool(request.GET.get("re_encode", "false")))
+    algo, checksum = query.parse_hash(query_string)
+    checksum = hash_to_hex(checksum)
+    content_data = request_content(query_string, max_size=None, re_encode=re_encode)
 
     filename = request.GET.get("filename", None)
     if not filename:
@@ -174,8 +169,7 @@ def _contents_diff(request, from_query_string, to_query_string):
 
     diff_data["diff_str"] = diff_str
     diff_data["language"] = language
-    diff_data_json = json.dumps(diff_data, separators=(",", ": "))
-    return HttpResponse(diff_data_json, content_type="application/json")
+    return JsonResponse(diff_data)
 
 
 @browse_route(
@@ -190,48 +184,44 @@ def content_display(request, query_string):
     The url that points to it is
     :http:get:`/browse/content/[(algo_hash):](hash)/`
     """
-    try:
-        algo, checksum = query.parse_hash(query_string)
-        checksum = hash_to_hex(checksum)
-        content_data = request_content(query_string, raise_if_unavailable=False)
-        origin_url = request.GET.get("origin_url")
-        selected_language = request.GET.get("language")
-        if not origin_url:
-            origin_url = request.GET.get("origin")
-        snapshot_id = request.GET.get("snapshot")
-        path = request.GET.get("path")
-        snapshot_context = None
-        if origin_url is not None or snapshot_id is not None:
-            try:
-                snapshot_context = get_snapshot_context(
-                    origin_url=origin_url,
-                    snapshot_id=snapshot_id,
-                    branch_name=request.GET.get("branch"),
-                    release_name=request.GET.get("release"),
-                    revision_id=request.GET.get("revision"),
-                    path=path,
-                    browse_context=CONTENT,
+    algo, checksum = query.parse_hash(query_string)
+    checksum = hash_to_hex(checksum)
+    content_data = request_content(query_string, raise_if_unavailable=False)
+    origin_url = request.GET.get("origin_url")
+    selected_language = request.GET.get("language")
+    if not origin_url:
+        origin_url = request.GET.get("origin")
+    snapshot_id = request.GET.get("snapshot")
+    path = request.GET.get("path")
+    snapshot_context = None
+    if origin_url is not None or snapshot_id is not None:
+        try:
+            snapshot_context = get_snapshot_context(
+                origin_url=origin_url,
+                snapshot_id=snapshot_id,
+                branch_name=request.GET.get("branch"),
+                release_name=request.GET.get("release"),
+                revision_id=request.GET.get("revision"),
+                path=path,
+                browse_context=CONTENT,
+            )
+        except NotFoundExc as e:
+            if str(e).startswith("Origin"):
+                raw_cnt_url = reverse(
+                    "browse-content", url_args={"query_string": query_string}
                 )
-            except NotFoundExc as e:
-                if str(e).startswith("Origin"):
-                    raw_cnt_url = reverse(
-                        "browse-content", url_args={"query_string": query_string}
-                    )
-                    error_message = (
-                        "The Software Heritage archive has a content "
-                        "with the hash you provided but the origin "
-                        "mentioned in your request appears broken: %s. "
-                        "Please check the URL and try again.\n\n"
-                        "Nevertheless, you can still browse the content "
-                        "without origin information: %s"
-                        % (gen_link(origin_url), gen_link(raw_cnt_url))
-                    )
-                    raise NotFoundExc(error_message)
-                else:
-                    raise e
-    except Exception as exc:
-        return handle_view_exception(request, exc)
-
+                error_message = (
+                    "The Software Heritage archive has a content "
+                    "with the hash you provided but the origin "
+                    "mentioned in your request appears broken: %s. "
+                    "Please check the URL and try again.\n\n"
+                    "Nevertheless, you can still browse the content "
+                    "without origin information: %s"
+                    % (gen_link(origin_url), gen_link(raw_cnt_url))
+                )
+                raise NotFoundExc(error_message)
+            else:
+                raise e
     content = None
     language = None
     mimetype = None
@@ -291,11 +281,8 @@ def content_display(request, query_string):
         breadcrumbs.append({"name": filename, "url": None})
 
     if path and root_dir != path:
-        try:
-            dir_info = service.lookup_directory_with_path(root_dir, path)
-            directory_id = dir_info["target"]
-        except Exception as exc:
-            return handle_view_exception(request, exc)
+        dir_info = archive.lookup_directory_with_path(root_dir, path)
+        directory_id = dir_info["target"]
     elif root_dir != path:
         directory_id = root_dir
     else:
@@ -331,9 +318,8 @@ def content_display(request, query_string):
         encoding=content_data["encoding"],
         size=filesizeformat(content_data["length"]),
         language=content_data["language"],
-        licenses=content_data["licenses"],
         root_directory=root_dir,
-        path=f"/{path}" if path else "",
+        path=f"/{path}" if path else None,
         filename=filename or "",
         directory=directory_id,
         directory_url=directory_url,
