@@ -5,69 +5,62 @@
 
 import os
 
-from django.http import HttpResponse
-from django.shortcuts import render, redirect
-from django.template.defaultfilters import filesizeformat
 import sentry_sdk
 
+from django.http import HttpResponse
+from django.shortcuts import redirect, render
+from django.template.defaultfilters import filesizeformat
 
 from swh.model.identifiers import DIRECTORY, RELEASE, REVISION, SNAPSHOT
 from swh.web.browse.browseurls import browse_route
 from swh.web.browse.snapshot_context import get_snapshot_context
-from swh.web.browse.utils import (
-    get_directory_entries,
-    get_readme_to_display,
-    gen_link,
-)
-from swh.web.common import service
-from swh.web.common.exc import handle_view_exception, NotFoundExc
+from swh.web.browse.utils import gen_link, get_directory_entries, get_readme_to_display
+from swh.web.common import archive
+from swh.web.common.exc import NotFoundExc
 from swh.web.common.identifiers import get_swhids_info
 from swh.web.common.typing import DirectoryMetadata, SWHObjectInfo
-from swh.web.common.utils import reverse, gen_path_info, swh_object_icons
+from swh.web.common.utils import gen_path_info, reverse, swh_object_icons
 
 
 def _directory_browse(request, sha1_git, path=None):
     root_sha1_git = sha1_git
-    try:
-        if path:
-            dir_info = service.lookup_directory_with_path(sha1_git, path)
-            sha1_git = dir_info["target"]
+    if path:
+        dir_info = archive.lookup_directory_with_path(sha1_git, path)
+        sha1_git = dir_info["target"]
 
-        dirs, files = get_directory_entries(sha1_git)
-        origin_url = request.GET.get("origin_url")
-        if not origin_url:
-            origin_url = request.GET.get("origin")
-        snapshot_id = request.GET.get("snapshot")
-        snapshot_context = None
-        if origin_url is not None or snapshot_id is not None:
-            try:
-                snapshot_context = get_snapshot_context(
-                    snapshot_id=snapshot_id,
-                    origin_url=origin_url,
-                    branch_name=request.GET.get("branch"),
-                    release_name=request.GET.get("release"),
-                    revision_id=request.GET.get("revision"),
-                    path=path,
+    dirs, files = get_directory_entries(sha1_git)
+    origin_url = request.GET.get("origin_url")
+    if not origin_url:
+        origin_url = request.GET.get("origin")
+    snapshot_id = request.GET.get("snapshot")
+    snapshot_context = None
+    if origin_url is not None or snapshot_id is not None:
+        try:
+            snapshot_context = get_snapshot_context(
+                snapshot_id=snapshot_id,
+                origin_url=origin_url,
+                branch_name=request.GET.get("branch"),
+                release_name=request.GET.get("release"),
+                revision_id=request.GET.get("revision"),
+                path=path,
+            )
+        except NotFoundExc as e:
+            if str(e).startswith("Origin"):
+                raw_dir_url = reverse(
+                    "browse-directory", url_args={"sha1_git": sha1_git}
                 )
-            except NotFoundExc as e:
-                if str(e).startswith("Origin"):
-                    raw_dir_url = reverse(
-                        "browse-directory", url_args={"sha1_git": sha1_git}
-                    )
-                    error_message = (
-                        "The Software Heritage archive has a directory "
-                        "with the hash you provided but the origin "
-                        "mentioned in your request appears broken: %s. "
-                        "Please check the URL and try again.\n\n"
-                        "Nevertheless, you can still browse the directory "
-                        "without origin information: %s"
-                        % (gen_link(origin_url), gen_link(raw_dir_url))
-                    )
-                    raise NotFoundExc(error_message)
-                else:
-                    raise e
-    except Exception as exc:
-        return handle_view_exception(request, exc)
+                error_message = (
+                    "The Software Heritage archive has a directory "
+                    "with the hash you provided but the origin "
+                    "mentioned in your request appears broken: %s. "
+                    "Please check the URL and try again.\n\n"
+                    "Nevertheless, you can still browse the directory "
+                    "without origin information: %s"
+                    % (gen_link(origin_url), gen_link(raw_dir_url))
+                )
+                raise NotFoundExc(error_message)
+            else:
+                raise e
 
     path_info = gen_path_info(path)
 
@@ -80,10 +73,11 @@ def _directory_browse(request, sha1_git, path=None):
             "url": reverse(
                 "browse-directory",
                 url_args={"sha1_git": root_sha1_git},
-                query_params=query_params,
+                query_params={**query_params, "path": None},
             ),
         }
     )
+
     for pi in path_info:
         breadcrumbs.append(
             {
@@ -91,7 +85,7 @@ def _directory_browse(request, sha1_git, path=None):
                 "url": reverse(
                     "browse-directory",
                     url_args={"sha1_git": root_sha1_git},
-                    query_params={"path": pi["path"], **query_params},
+                    query_params={**query_params, "path": pi["path"],},
                 ),
             }
         )
@@ -109,7 +103,7 @@ def _directory_browse(request, sha1_git, path=None):
             d["url"] = reverse(
                 "browse-directory",
                 url_args={"sha1_git": root_sha1_git},
-                query_params={"path": path + d["name"], **query_params},
+                query_params={**query_params, "path": path + d["name"],},
             )
 
     sum_file_sizes = 0
@@ -122,8 +116,8 @@ def _directory_browse(request, sha1_git, path=None):
             "browse-content",
             url_args={"query_string": query_string},
             query_params={
-                "path": root_sha1_git + "/" + path + f["name"],
                 **query_params,
+                "path": root_sha1_git + "/" + path + f["name"],
             },
         )
         if f["length"] is not None:
@@ -144,7 +138,7 @@ def _directory_browse(request, sha1_git, path=None):
         nb_dirs=len(dirs),
         sum_file_sizes=sum_file_sizes,
         root_directory=root_sha1_git,
-        path=f"/{path}" if path else "/",
+        path=f"/{path}" if path else None,
         revision=None,
         revision_found=None,
         release=None,
@@ -264,7 +258,7 @@ def _directory_resolve_content_path(request, sha1_git):
     try:
         path = os.path.normpath(request.GET.get("path"))
         if not path.startswith("../"):
-            dir_info = service.lookup_directory_with_path(sha1_git, path)
+            dir_info = archive.lookup_directory_with_path(sha1_git, path)
             if dir_info["type"] == "file":
                 sha1 = dir_info["checksums"]["sha1"]
                 data_url = reverse(
