@@ -3,11 +3,14 @@
 # License: GNU Affero General Public License version 3, or any later version
 # See top-level LICENSE file for more information
 
-from typing import Any, Dict, List, Optional, Union
+from typing import Any, Dict, List, Optional, TypeVar, Union
+
 from typing_extensions import TypedDict
 
 from django.http import QueryDict
 
+from swh.core.api.classes import PagedResult as CorePagedResult
+
 QueryParameters = Union[Dict[str, Any], QueryDict]
 
 
@@ -16,6 +19,13 @@ class OriginInfo(TypedDict):
     """URL of the origin"""
 
 
+class OriginMetadataInfo(TypedDict):
+    url: str
+    """URL of the origin"""
+    metadata: Dict[str, Any]
+    """Origin metadata associated to the origin"""
+
+
 class OriginVisitInfo(TypedDict):
     date: str
     """date of the visit in iso format"""
@@ -44,8 +54,10 @@ class SnapshotBranchInfo(TypedDict):
     """directory associated to branch heading revision"""
     message: Optional[str]
     """message of branch heading revision"""
-    name: Optional[str]
+    name: str
     """branch name"""
+    alias: bool
+    """define if the branch is an alias"""
     revision: str
     """branch heading revision"""
     url: Optional[str]
@@ -65,6 +77,8 @@ class SnapshotReleaseInfo(TypedDict):
     """release message"""
     name: str
     """release name"""
+    alias: bool
+    """define if the branch is an alias"""
     target: str
     """release target"""
     target_type: str
@@ -76,6 +90,8 @@ class SnapshotReleaseInfo(TypedDict):
 class SnapshotContext(TypedDict):
     branch: Optional[str]
     """optional branch name set when browsing snapshot in that scope"""
+    branch_alias: bool
+    """indicates if the focused branch is an alias"""
     branches: List[SnapshotBranchInfo]
     """list of snapshot branches (possibly truncated)"""
     branches_url: str
@@ -90,6 +106,8 @@ class SnapshotContext(TypedDict):
     """common query parameters when browsing snapshot content"""
     release: Optional[str]
     """optional release name set when browsing snapshot in that scope"""
+    release_alias: bool
+    """indicates if the focused release is an alias"""
     release_id: Optional[str]
     """optional release identifier set when browsing snapshot in that scope"""
     releases: List[SnapshotReleaseInfo]
@@ -155,7 +173,6 @@ class ContentMetadata(SWHObjectInfo, SWHObjectInfoMetadata):
     encoding: str
     size: str
     language: str
-    licenses: str
     path: Optional[str]
     filename: Optional[str]
     directory: Optional[str]
@@ -206,3 +223,9 @@ class RevisionMetadata(SWHObjectInfo, SWHObjectInfoMetadata):
     synthetic: bool
     type: str
     snapshot: Optional[str]
+
+
+TResult = TypeVar("TResult")
+
+
+PagedResult = CorePagedResult[TResult, str]
