@@ -3,37 +3,31 @@
 # License: GNU Affero General Public License version 3, or any later version
 # See top-level LICENSE file for more information
 
-import re
-
 from datetime import datetime, timezone
-from dateutil import parser as date_parser
-from dateutil import tz
-
-from typing import Optional, Dict, Any
-
-import docutils.parsers.rst
-import docutils.utils
+import os
+import re
+from typing import Any, Dict, Optional
 
 from bs4 import BeautifulSoup
-
 from docutils.core import publish_parts
-from docutils.writers.html5_polyglot import Writer, HTMLTranslator
-
-from django.urls import reverse as django_reverse
-from django.http import QueryDict, HttpRequest
-
+import docutils.parsers.rst
+import docutils.utils
+from docutils.writers.html5_polyglot import HTMLTranslator, Writer
+from iso8601 import ParseError, parse_date
 from prometheus_client.registry import CollectorRegistry
 
+from django.http import HttpRequest, QueryDict
+from django.urls import reverse as django_reverse
 from rest_framework.authentication import SessionAuthentication
 
 from swh.web.common.exc import BadInputExc
 from swh.web.common.typing import QueryParameters
 from swh.web.config import get_config
 
-
 SWH_WEB_METRICS_REGISTRY = CollectorRegistry(auto_describe=True)
 
 swh_object_icons = {
+    "alias": "mdi mdi-star",
     "branch": "mdi mdi-source-branch",
     "branches": "mdi mdi-source-branch",
     "content": "mdi mdi-file-document",
@@ -81,7 +75,7 @@ def reverse(
     )
 
     if query_params:
-        query_params = {k: v for k, v in query_params.items() if v}
+        query_params = {k: v for k, v in query_params.items() if v is not None}
 
     if query_params and len(query_params) > 0:
         query_dict = QueryDict("", mutable=True)
@@ -104,39 +98,32 @@ def datetime_to_utc(date):
     Returns:
         datetime.datetime: datetime in UTC without timezone info
     """
-    if date.tzinfo:
-        return date.astimezone(tz.gettz("UTC")).replace(tzinfo=timezone.utc)
+    if date.tzinfo and date.tzinfo != timezone.utc:
+        return date.astimezone(tz=timezone.utc)
     else:
         return date
 
 
-def parse_timestamp(timestamp):
-    """Given a time or timestamp (as string), parse the result as UTC datetime.
+def parse_iso8601_date_to_utc(iso_date: str) -> datetime:
+    """Given an ISO 8601 datetime string, parse the result as UTC datetime.
 
     Returns:
-        datetime.datetime: a timezone-aware datetime representing the
-            parsed value or None if the parsing fails.
+        a timezone-aware datetime representing the parsed date
+
+    Raises:
+        swh.web.common.exc.BadInputExc: provided date does not respect ISO 8601 format
 
     Samples:
         - 2016-01-12
         - 2016-01-12T09:19:12+0100
-        - Today is January 1, 2047 at 8:21:00AM
-        - 1452591542
+        - 2007-01-14T20:34:22Z
 
     """
-    if not timestamp:
-        return None
-
     try:
-        date = date_parser.parse(timestamp, ignoretz=False, fuzzy=True)
+        date = parse_date(iso_date)
         return datetime_to_utc(date)
-    except Exception:
-        try:
-            return datetime.utcfromtimestamp(float(timestamp)).replace(
-                tzinfo=timezone.utc
-            )
-        except (ValueError, OverflowError) as e:
-            raise BadInputExc(e)
+    except ParseError as e:
+        raise BadInputExc(e)
 
 
 def shorten_path(path):
@@ -151,7 +138,7 @@ def shorten_path(path):
 
 
 def format_utc_iso_date(iso_date, fmt="%d %B %Y, %H:%M UTC"):
-    """Turns a string representation of an ISO 8601 date string
+    """Turns a string representation of an ISO 8601 datetime string
     to UTC and format it into a more human readable one.
 
     For instance, from the following input
@@ -169,7 +156,7 @@ def format_utc_iso_date(iso_date, fmt="%d %B %Y, %H:%M UTC"):
     """
     if not iso_date:
         return iso_date
-    date = parse_timestamp(iso_date)
+    date = parse_iso8601_date_to_utc(iso_date)
     return date.strftime(fmt)
 
 
@@ -275,6 +262,9 @@ def context_processor(request):
         "swh_client_config": config["client_config"],
         "oidc_enabled": bool(config["keycloak"]["server_url"]),
         "browsers_supported_image_mimes": browsers_supported_image_mimes,
+        "keycloak": config["keycloak"],
+        "site_base_url": request.build_absolute_uri("/"),
+        "DJANGO_SETTINGS_MODULE": os.environ["DJANGO_SETTINGS_MODULE"],
     }
 
 
@@ -306,9 +296,9 @@ def resolve_branch_alias(
         if branch["target"] in snapshot["branches"]:
             branch = snapshot["branches"][branch["target"]]
         else:
-            from swh.web.common import service
+            from swh.web.common import archive
 
-            snp = service.lookup_snapshot(
+            snp = archive.lookup_snapshot(
                 snapshot["id"], branches_from=branch["target"], branches_count=1
             )
             if snp and branch["target"] in snp["branches"]:
