@@ -1,10 +1,9 @@
-# Copyright (C) 2017-2019  The Software Heritage developers
+# Copyright (C) 2017-2020  The Software Heritage developers
 # See the AUTHORS file at the top-level directory of this distribution
 # License: GNU Affero General Public License version 3, or any later version
 # See top-level LICENSE file for more information
 
 import os
-
 from typing import Any, Dict
 
 from swh.core import config
@@ -15,13 +14,15 @@ from swh.storage import get_storage
 from swh.vault import get_vault
 from swh.web import settings
 
+SWH_WEB_INTERNAL_SERVER_NAME = "archive.internal.softwareheritage.org"
+
 SETTINGS_DIR = os.path.dirname(settings.__file__)
 
 DEFAULT_CONFIG = {
     "allowed_hosts": ("list", []),
     "search": (
         "dict",
-        {"cls": "remote", "args": {"url": "http://127.0.0.1:5010/", "timeout": 10,},},
+        {"cls": "remote", "url": "http://127.0.0.1:5010/", "timeout": 10,},
     ),
     "storage": (
         "dict",
@@ -29,7 +30,7 @@ DEFAULT_CONFIG = {
     ),
     "indexer_storage": (
         "dict",
-        {"cls": "remote", "args": {"url": "http://127.0.0.1:5007/", "timeout": 1,}},
+        {"cls": "remote", "url": "http://127.0.0.1:5007/", "timeout": 1,},
     ),
     "log_dir": ("string", "/tmp/swh/log"),
     "debug": ("bool", False),
@@ -70,7 +71,7 @@ DEFAULT_CONFIG = {
         },
     ),
     "vault": ("dict", {"cls": "remote", "args": {"url": "http://127.0.0.1:5005/",}}),
-    "scheduler": ("dict", {"cls": "remote", "args": {"url": "http://127.0.0.1:5008/"}}),
+    "scheduler": ("dict", {"cls": "remote", "url": "http://127.0.0.1:5008/"}),
     "development_db": ("string", os.path.join(SETTINGS_DIR, "db.sqlite3")),
     "test_db": ("string", os.path.join(SETTINGS_DIR, "testdb.sqlite3")),
     "production_db": ("string", "/var/lib/swh/web.sqlite3"),
@@ -91,6 +92,10 @@ DEFAULT_CONFIG = {
     ),
     "client_config": ("dict", {}),
     "keycloak": ("dict", {"server_url": "", "realm_name": ""}),
+    "graph": (
+        "dict",
+        {"server_url": "http://graph.internal.softwareheritage.org:5009/graph/"},
+    ),
 }
 
 swhweb_config = {}  # type: Dict[str, Any]
