@@ -10,7 +10,6 @@ Django common settings for swh-web.
 
 import os
 import sys
-
 from typing import Any, Dict
 
 from swh.web.config import get_config
@@ -44,6 +43,7 @@ INSTALLED_APPS = [
     "rest_framework",
     "swh.web.common",
     "swh.web.api",
+    "swh.web.auth",
     "swh.web.browse",
     "webpack_loader",
     "django_js_reverse",
@@ -61,6 +61,7 @@ MIDDLEWARE = [
     "django.contrib.messages.middleware.MessageMiddleware",
     "django.middleware.clickjacking.XFrameOptionsMiddleware",
     "swh.web.common.middlewares.ThrottlingHeadersMiddleware",
+    "swh.web.common.middlewares.ExceptionMiddleware",
 ]
 
 # Compress all assets (static ones and dynamically generated html)
@@ -167,6 +168,7 @@ REST_FRAMEWORK: Dict[str, Any] = {
         "rest_framework.authentication.SessionAuthentication",
         "swh.web.auth.backends.OIDCBearerTokenAuthentication",
     ],
+    "EXCEPTION_HANDLER": "swh.web.api.apiresponse.error_response_handler",
 }
 
 LOGGING = {
@@ -267,16 +269,12 @@ SESSION_ENGINE = "django.contrib.sessions.backends.cache"
 
 CACHES = {
     "default": {"BACKEND": "django.core.cache.backends.locmem.LocMemCache"},
-    "db_cache": {
-        "BACKEND": "django.core.cache.backends.db.DatabaseCache",
-        "LOCATION": "swh_web_cache",
-    },
 }
 
 JS_REVERSE_JS_MINIFY = False
 
 CORS_ORIGIN_ALLOW_ALL = True
-CORS_URLS_REGEX = r"^/badge/.*$"
+CORS_URLS_REGEX = r"^/(badge|api)/.*$"
 
 AUTHENTICATION_BACKENDS = [
     "django.contrib.auth.backends.ModelBackend",
