@@ -10,7 +10,7 @@ Django tests settings for swh-web.
 import os
 import sys
 
-from swh.web.config import get_config
+from swh.web.config import SWH_WEB_INTERNAL_SERVER_NAME, get_config
 
 scope1_limiter_rate = 3
 scope1_limiter_rate_post = 1
@@ -24,7 +24,8 @@ swh_web_config = get_config()
 
 swh_web_config.update(
     {
-        "debug": False,
+        # disable django debug mode when running cypress tests
+        "debug": "pytest" in sys.argv[0] or "PYTEST_XDIST_WORKER" in os.environ,
         "secret_key": "test",
         "history_counters_url": "",
         "throttling": {
@@ -82,7 +83,8 @@ swh_web_config.update(
 
 
 from .common import *  # noqa
-from .common import ALLOWED_HOSTS, LOGGING  # noqa
+
+from .common import ALLOWED_HOSTS, LOGGING  # noqa, isort: skip
 
 DATABASES = {
     "default": {
@@ -101,7 +103,7 @@ if "pytest" not in sys.argv[0] and "PYTEST_XDIST_WORKER" not in os.environ:
         test_data["storage"], test_data["idx_storage"], test_data["search"]
     )
 else:
-    ALLOWED_HOSTS += ["testserver"]
+    ALLOWED_HOSTS += ["testserver", SWH_WEB_INTERNAL_SERVER_NAME]
 
     # Silent DEBUG output when running unit tests
     LOGGING["handlers"]["console"]["level"] = "INFO"  # type: ignore
