@@ -9,16 +9,23 @@ from hypothesis import given
 import pytest
 from requests.utils import parse_header_links
 
+from swh.indexer.storage.model import OriginIntrinsicMetadataRow
+from swh.model.hashutil import hash_to_bytes
 from swh.model.model import Origin, OriginVisit, OriginVisitStatus
-
-from swh.storage.exc import StorageDBError, StorageAPIError
+from swh.storage.exc import StorageAPIError, StorageDBError
 from swh.storage.utils import now
-
-from swh.web.api.utils import enrich_origin_visit, enrich_origin
+from swh.web.api.utils import enrich_origin, enrich_origin_visit
 from swh.web.common.exc import BadInputExc
-from swh.web.common.utils import reverse
 from swh.web.common.origin_visits import get_origin_visits
-from swh.web.tests.strategies import origin, new_origin, visit_dates, new_snapshots
+from swh.web.common.utils import reverse
+from swh.web.tests.data import (
+    INDEXER_TOOL,
+    ORIGIN_MASTER_REVISION,
+    ORIGIN_METADATA_KEY,
+    ORIGIN_METADATA_VALUE,
+)
+from swh.web.tests.strategies import new_origin, new_snapshots, origin, visit_dates
+from swh.web.tests.utils import check_api_get_responses
 
 
 def _scroll_results(api_client, url):
@@ -26,9 +33,7 @@ def _scroll_results(api_client, url):
     results = []
 
     while True:
-        rv = api_client.get(url)
-        assert rv.status_code == 200, rv.data
-        assert rv["Content-Type"] == "application/json"
+        rv = check_api_get_responses(api_client, url, status_code=200)
 
         results.extend(rv.data)
 
@@ -55,10 +60,7 @@ def test_api_lookup_origin_visits_raise_error(api_client, mocker):
     mock_get_origin_visits.side_effect = BadInputExc(err_msg)
 
     url = reverse("api-1-origin-visits", url_args={"origin_url": "http://foo"})
-    rv = api_client.get(url)
-
-    assert rv.status_code == 400, rv.data
-    assert rv["Content-Type"] == "application/json"
+    rv = check_api_get_responses(api_client, url, status_code=400)
     assert rv.data == {"exception": "BadInputExc", "reason": err_msg}
 
 
@@ -69,10 +71,7 @@ def test_api_lookup_origin_visits_raise_swh_storage_error_db(api_client, mocker)
     mock_get_origin_visits.side_effect = StorageDBError(err_msg)
 
     url = reverse("api-1-origin-visits", url_args={"origin_url": "http://foo"})
-    rv = api_client.get(url)
-
-    assert rv.status_code == 503, rv.data
-    assert rv["Content-Type"] == "application/json"
+    rv = check_api_get_responses(api_client, url, status_code=503)
     assert rv.data == {
         "exception": "StorageDBError",
         "reason": "An unexpected error occurred in the backend: %s" % err_msg,
@@ -86,10 +85,7 @@ def test_api_lookup_origin_visits_raise_swh_storage_error_api(api_client, mocker
     mock_get_origin_visits.side_effect = StorageAPIError(err_msg)
 
     url = reverse("api-1-origin-visits", url_args={"origin_url": "http://foo"})
-    rv = api_client.get(url)
-
-    assert rv.status_code == 503, rv.data
-    assert rv["Content-Type"] == "application/json"
+    rv = check_api_get_responses(api_client, url, status_code=503)
     assert rv.data == {
         "exception": "StorageAPIError",
         "reason": "An unexpected error occurred in the api backend: %s" % err_msg,
@@ -129,10 +125,7 @@ def test_api_lookup_origin_visits(
             query_params={"per_page": 2, "last_visit": last_visit},
         )
 
-        rv = api_client.get(url)
-
-        assert rv.status_code == 200, rv.data
-        assert rv["Content-Type"] == "application/json"
+        rv = check_api_get_responses(api_client, url, status_code=200)
 
         for i in range(len(expected_visits)):
             expected_visits[i] = enrich_origin_visit(
@@ -177,10 +170,7 @@ def test_api_lookup_origin_visits_by_id(
             query_params={"per_page": 2, "last_visit": last_visit},
         )
 
-        rv = api_client.get(url)
-
-        assert rv.status_code == 200, rv.data
-        assert rv["Content-Type"] == "application/json"
+        rv = check_api_get_responses(api_client, url, status_code=200)
 
         for i in range(len(expected_visits)):
             expected_visits[i] = enrich_origin_visit(
@@ -217,9 +207,7 @@ def test_api_lookup_origin_visit(
             url_args={"origin_url": new_origin.url, "visit_id": visit_id},
         )
 
-        rv = api_client.get(url)
-        assert rv.status_code == 200, rv.data
-        assert rv["Content-Type"] == "application/json"
+        rv = check_api_get_responses(api_client, url, status_code=200)
 
         expected_visit = archive_data.origin_visit_get_by(new_origin.url, visit_id)
 
@@ -239,8 +227,7 @@ def test_api_lookup_origin_visit_latest_no_visit(api_client, archive_data, new_o
 
     url = reverse("api-1-origin-visit-latest", url_args={"origin_url": new_origin.url})
 
-    rv = api_client.get(url)
-    assert rv.status_code == 404, rv.data
+    rv = check_api_get_responses(api_client, url, status_code=404)
     assert rv.data == {
         "exception": "NotFoundExc",
         "reason": "No visit for origin %s found" % new_origin.url,
@@ -273,10 +260,7 @@ def test_api_lookup_origin_visit_latest(
 
     url = reverse("api-1-origin-visit-latest", url_args={"origin_url": new_origin.url})
 
-    rv = api_client.get(url)
-
-    assert rv.status_code == 200, rv.data
-    assert rv["Content-Type"] == "application/json"
+    rv = check_api_get_responses(api_client, url, status_code=200)
 
     expected_visit = archive_data.origin_visit_get_by(new_origin.url, visit_ids[1])
 
@@ -322,10 +306,7 @@ def test_api_lookup_origin_visit_latest_with_snapshot(
         query_params={"require_snapshot": True},
     )
 
-    rv = api_client.get(url)
-
-    assert rv.status_code == 200, rv.data
-    assert rv["Content-Type"] == "application/json"
+    rv = check_api_get_responses(api_client, url, status_code=200)
 
     expected_visit = archive_data.origin_visit_status_get_latest(
         new_origin.url, type="git", require_snapshot=True
@@ -353,10 +334,7 @@ def test_api_lookup_origin_visit_not_found(api_client, origin):
         url_args={"origin_url": origin["url"], "visit_id": max_visit_id + 1},
     )
 
-    rv = api_client.get(url)
-
-    assert rv.status_code == 404, rv.data
-    assert rv["Content-Type"] == "application/json"
+    rv = check_api_get_responses(api_client, url, status_code=404)
     assert rv.data == {
         "exception": "NotFoundExc",
         "reason": "Origin %s or its visit with id %s not found!"
@@ -364,39 +342,49 @@ def test_api_lookup_origin_visit_not_found(api_client, origin):
     }
 
 
+def test_api_origins_wrong_input(api_client, archive_data):
+    """Should fail with 400 if the input is deprecated.
+
+    """
+    # fail if wrong input
+    url = reverse("api-1-origins", query_params={"origin_from": 1})
+    rv = check_api_get_responses(api_client, url, status_code=400)
+
+    assert rv.data == {
+        "exception": "BadInputExc",
+        "reason": "Please use the Link header to browse through result",
+    }
+
+
 def test_api_origins(api_client, archive_data):
-    origins = list(archive_data.origin_get_range(0, 10000))
-    origin_urls = {origin["url"] for origin in origins}
+    page_result = archive_data.origin_list(limit=10000)
+    origins = page_result.results
+    origin_urls = {origin.url for origin in origins}
 
     # Get only one
     url = reverse("api-1-origins", query_params={"origin_count": 1})
-    rv = api_client.get(url)
-    assert rv.status_code == 200, rv.data
-    assert rv["Content-Type"] == "application/json"
+    rv = check_api_get_responses(api_client, url, status_code=200)
     assert len(rv.data) == 1
     assert {origin["url"] for origin in rv.data} <= origin_urls
 
     # Get all
     url = reverse("api-1-origins", query_params={"origin_count": len(origins)})
-    rv = api_client.get(url)
-    assert rv.status_code == 200, rv.data
-    assert rv["Content-Type"] == "application/json"
+    rv = check_api_get_responses(api_client, url, status_code=200)
     assert len(rv.data) == len(origins)
     assert {origin["url"] for origin in rv.data} == origin_urls
 
     # Get "all + 10"
     url = reverse("api-1-origins", query_params={"origin_count": len(origins) + 10})
-    rv = api_client.get(url)
-    assert rv.status_code == 200, rv.data
-    assert rv["Content-Type"] == "application/json"
+    rv = check_api_get_responses(api_client, url, status_code=200)
     assert len(rv.data) == len(origins)
     assert {origin["url"] for origin in rv.data} == origin_urls
 
 
 @pytest.mark.parametrize("origin_count", [1, 2, 10, 100])
 def test_api_origins_scroll(api_client, archive_data, origin_count):
-    origins = list(archive_data.origin_get_range(0, 10000))
-    origin_urls = {origin["url"] for origin in origins}
+    page_result = archive_data.origin_list(limit=10000)
+    origins = page_result.results
+    origin_urls = {origin.url for origin in origins}
 
     url = reverse("api-1-origins", query_params={"origin_count": origin_count})
 
@@ -408,15 +396,12 @@ def test_api_origins_scroll(api_client, archive_data, origin_count):
 
 @given(origin())
 def test_api_origin_by_url(api_client, archive_data, origin):
-    url = reverse("api-1-origin", url_args={"origin_url": origin["url"]})
-    rv = api_client.get(url)
-
-    expected_origin = archive_data.origin_get(origin)
-
+    origin_url = origin["url"]
+    url = reverse("api-1-origin", url_args={"origin_url": origin_url})
+    rv = check_api_get_responses(api_client, url, status_code=200)
+    expected_origin = archive_data.origin_get([origin_url])[0]
     expected_origin = enrich_origin(expected_origin, rv.wsgi_request)
 
-    assert rv.status_code == 200, rv.data
-    assert rv["Content-Type"] == "application/json"
     assert rv.data == expected_origin
 
 
@@ -424,10 +409,7 @@ def test_api_origin_by_url(api_client, archive_data, origin):
 def test_api_origin_not_found(api_client, new_origin):
 
     url = reverse("api-1-origin", url_args={"origin_url": new_origin.url})
-    rv = api_client.get(url)
-
-    assert rv.status_code == 404, rv.data
-    assert rv["Content-Type"] == "application/json"
+    rv = check_api_get_responses(api_client, url, status_code=404)
     assert rv.data == {
         "exception": "NotFoundExc",
         "reason": "Origin with url %s not found!" % new_origin.url,
@@ -438,7 +420,7 @@ def test_api_origin_not_found(api_client, new_origin):
 def test_api_origin_search(api_client, mocker, backend):
     if backend != "swh-search":
         # equivalent to not configuring search in the config
-        mocker.patch("swh.web.common.service.search", None)
+        mocker.patch("swh.web.common.archive.search", None)
 
     expected_origins = {
         "https://github.com/wcoder/highlightjs-line-numbers.js",
@@ -451,9 +433,7 @@ def test_api_origin_search(api_client, mocker, backend):
         url_args={"url_pattern": "github.com"},
         query_params={"limit": 1},
     )
-    rv = api_client.get(url)
-    assert rv.status_code == 200, rv.data
-    assert rv["Content-Type"] == "application/json"
+    rv = check_api_get_responses(api_client, url, status_code=200)
     assert len(rv.data) == 1
     assert {origin["url"] for origin in rv.data} <= expected_origins
 
@@ -463,9 +443,7 @@ def test_api_origin_search(api_client, mocker, backend):
         url_args={"url_pattern": "github.com"},
         query_params={"limit": 2},
     )
-    rv = api_client.get(url)
-    assert rv.status_code == 200, rv.data
-    assert rv["Content-Type"] == "application/json"
+    rv = check_api_get_responses(api_client, url, status_code=200)
     assert {origin["url"] for origin in rv.data} == expected_origins
 
     # Search for 'github.com', get more than available
@@ -474,9 +452,7 @@ def test_api_origin_search(api_client, mocker, backend):
         url_args={"url_pattern": "github.com"},
         query_params={"limit": 10},
     )
-    rv = api_client.get(url)
-    assert rv.status_code == 200, rv.data
-    assert rv["Content-Type"] == "application/json"
+    rv = check_api_get_responses(api_client, url, status_code=200)
     assert {origin["url"] for origin in rv.data} == expected_origins
 
 
@@ -484,7 +460,7 @@ def test_api_origin_search(api_client, mocker, backend):
 def test_api_origin_search_words(api_client, mocker, backend):
     if backend != "swh-search":
         # equivalent to not configuring search in the config
-        mocker.patch("swh.web.common.service.search", None)
+        mocker.patch("swh.web.common.archive.search", None)
 
     expected_origins = {
         "https://github.com/wcoder/highlightjs-line-numbers.js",
@@ -496,9 +472,7 @@ def test_api_origin_search_words(api_client, mocker, backend):
         url_args={"url_pattern": "github com"},
         query_params={"limit": 2},
     )
-    rv = api_client.get(url)
-    assert rv.status_code == 200, rv.data
-    assert rv["Content-Type"] == "application/json"
+    rv = check_api_get_responses(api_client, url, status_code=200)
     assert {origin["url"] for origin in rv.data} == expected_origins
 
     url = reverse(
@@ -506,9 +480,7 @@ def test_api_origin_search_words(api_client, mocker, backend):
         url_args={"url_pattern": "com github"},
         query_params={"limit": 2},
     )
-    rv = api_client.get(url)
-    assert rv.status_code == 200, rv.data
-    assert rv["Content-Type"] == "application/json"
+    rv = check_api_get_responses(api_client, url, status_code=200)
     assert {origin["url"] for origin in rv.data} == expected_origins
 
     url = reverse(
@@ -516,9 +488,7 @@ def test_api_origin_search_words(api_client, mocker, backend):
         url_args={"url_pattern": "memononen libtess2"},
         query_params={"limit": 2},
     )
-    rv = api_client.get(url)
-    assert rv.status_code == 200, rv.data
-    assert rv["Content-Type"] == "application/json"
+    rv = check_api_get_responses(api_client, url, status_code=200)
     assert len(rv.data) == 1
     assert {origin["url"] for origin in rv.data} == {
         "https://github.com/memononen/libtess2"
@@ -529,9 +499,7 @@ def test_api_origin_search_words(api_client, mocker, backend):
         url_args={"url_pattern": "libtess2 memononen"},
         query_params={"limit": 2},
     )
-    rv = api_client.get(url)
-    assert rv.status_code == 200, rv.data
-    assert rv["Content-Type"] == "application/json"
+    rv = check_api_get_responses(api_client, url, status_code=200)
     assert len(rv.data) == 1
     assert {origin["url"] for origin in rv.data} == {
         "https://github.com/memononen/libtess2"
@@ -544,7 +512,7 @@ def test_api_origin_search_scroll(api_client, archive_data, mocker, limit, backe
 
     if backend != "swh-search":
         # equivalent to not configuring search in the config
-        mocker.patch("swh.web.common.service.search", None)
+        mocker.patch("swh.web.common.archive.search", None)
 
     expected_origins = {
         "https://github.com/wcoder/highlightjs-line-numbers.js",
@@ -570,7 +538,7 @@ def test_api_origin_search_limit(api_client, archive_data, tests_data, mocker, b
         )
     else:
         # equivalent to not configuring search in the config
-        mocker.patch("swh.web.common.service.search", None)
+        mocker.patch("swh.web.common.archive.search", None)
 
         archive_data.origin_add(
             [Origin(url="http://foobar/{}".format(i)) for i in range(2000)]
@@ -581,157 +549,91 @@ def test_api_origin_search_limit(api_client, archive_data, tests_data, mocker, b
         url_args={"url_pattern": "foobar"},
         query_params={"limit": 1050},
     )
-    rv = api_client.get(url)
-    assert rv.status_code == 200, rv.data
-    assert rv["Content-Type"] == "application/json"
+    rv = check_api_get_responses(api_client, url, status_code=200)
     assert len(rv.data) == 1000
 
 
-@given(origin())
-def test_api_origin_metadata_search(api_client, mocker, origin):
-    mock_idx_storage = mocker.patch("swh.web.common.service.idx_storage")
-    oimsft = mock_idx_storage.origin_intrinsic_metadata_search_fulltext
-    oimsft.side_effect = lambda conjunction, limit: [
-        {
-            "from_revision": (
-                b"p&\xb7\xc1\xa2\xafVR\x1e\x95\x1c\x01\xed " b"\xf2U\xfa\x05B8"
-            ),
-            "metadata": {"author": "Jane Doe"},
-            "id": origin["url"],
-            "tool": {
-                "configuration": {
-                    "context": ["NpmMapping", "CodemetaMapping"],
-                    "type": "local",
-                },
-                "id": 3,
-                "name": "swh-metadata-detector",
-                "version": "0.0.1",
-            },
-        }
-    ]
+def test_api_origin_metadata_search(api_client):
 
-    url = reverse("api-1-origin-metadata-search", query_params={"fulltext": "Jane Doe"})
-    rv = api_client.get(url)
+    url = reverse(
+        "api-1-origin-metadata-search", query_params={"fulltext": ORIGIN_METADATA_VALUE}
+    )
+    rv = check_api_get_responses(api_client, url, status_code=200)
 
-    assert rv.status_code == 200, rv.content
-    assert rv["Content-Type"] == "application/json"
     expected_data = [
         {
-            "url": origin["url"],
+            "url": origin_url,
             "metadata": {
-                "metadata": {"author": "Jane Doe"},
-                "from_revision": ("7026b7c1a2af56521e951c01ed20f255fa054238"),
+                "from_revision": master_rev,
                 "tool": {
-                    "configuration": {
-                        "context": ["NpmMapping", "CodemetaMapping"],
-                        "type": "local",
-                    },
-                    "id": 3,
-                    "name": "swh-metadata-detector",
-                    "version": "0.0.1",
+                    "name": INDEXER_TOOL["tool_name"],
+                    "version": INDEXER_TOOL["tool_version"],
+                    "configuration": INDEXER_TOOL["tool_configuration"],
+                    "id": INDEXER_TOOL["id"],
                 },
+                "metadata": {ORIGIN_METADATA_KEY: ORIGIN_METADATA_VALUE},
+                "mappings": [],
             },
         }
+        for origin_url, master_rev in ORIGIN_MASTER_REVISION.items()
     ]
 
     assert rv.data == expected_data
-    oimsft.assert_called_with(conjunction=["Jane Doe"], limit=70)
 
 
-@given(origin())
-def test_api_origin_metadata_search_limit(api_client, mocker, origin):
-    mock_idx_storage = mocker.patch("swh.web.common.service.idx_storage")
+def test_api_origin_metadata_search_limit(api_client, mocker):
+    mock_idx_storage = mocker.patch("swh.web.common.archive.idx_storage")
     oimsft = mock_idx_storage.origin_intrinsic_metadata_search_fulltext
 
     oimsft.side_effect = lambda conjunction, limit: [
-        {
-            "from_revision": (
-                b"p&\xb7\xc1\xa2\xafVR\x1e\x95\x1c\x01\xed " b"\xf2U\xfa\x05B8"
-            ),
-            "metadata": {"author": "Jane Doe"},
-            "id": origin["url"],
-            "tool": {
-                "configuration": {
-                    "context": ["NpmMapping", "CodemetaMapping"],
-                    "type": "local",
-                },
-                "id": 3,
-                "name": "swh-metadata-detector",
-                "version": "0.0.1",
-            },
-        }
+        OriginIntrinsicMetadataRow(
+            id=origin_url,
+            from_revision=hash_to_bytes(master_rev),
+            indexer_configuration_id=INDEXER_TOOL["id"],
+            metadata={ORIGIN_METADATA_KEY: ORIGIN_METADATA_VALUE},
+            mappings=[],
+        )
+        for origin_url, master_rev in ORIGIN_MASTER_REVISION.items()
     ]
 
-    url = reverse("api-1-origin-metadata-search", query_params={"fulltext": "Jane Doe"})
-    rv = api_client.get(url)
-
-    assert rv.status_code == 200, rv.content
-    assert rv["Content-Type"] == "application/json"
-    assert len(rv.data) == 1
-    oimsft.assert_called_with(conjunction=["Jane Doe"], limit=70)
+    url = reverse(
+        "api-1-origin-metadata-search", query_params={"fulltext": ORIGIN_METADATA_VALUE}
+    )
+    rv = check_api_get_responses(api_client, url, status_code=200)
+    assert len(rv.data) == len(ORIGIN_MASTER_REVISION)
+    oimsft.assert_called_with(conjunction=[ORIGIN_METADATA_VALUE], limit=70)
 
     url = reverse(
         "api-1-origin-metadata-search",
-        query_params={"fulltext": "Jane Doe", "limit": 10},
+        query_params={"fulltext": ORIGIN_METADATA_VALUE, "limit": 10},
     )
-    rv = api_client.get(url)
-
-    assert rv.status_code == 200, rv.content
-    assert rv["Content-Type"] == "application/json"
-    assert len(rv.data) == 1
-    oimsft.assert_called_with(conjunction=["Jane Doe"], limit=10)
+    rv = check_api_get_responses(api_client, url, status_code=200)
+    assert len(rv.data) == len(ORIGIN_MASTER_REVISION)
+    oimsft.assert_called_with(conjunction=[ORIGIN_METADATA_VALUE], limit=10)
 
     url = reverse(
         "api-1-origin-metadata-search",
-        query_params={"fulltext": "Jane Doe", "limit": 987},
+        query_params={"fulltext": ORIGIN_METADATA_VALUE, "limit": 987},
     )
-    rv = api_client.get(url)
-
-    assert rv.status_code == 200, rv.content
-    assert rv["Content-Type"] == "application/json"
-    assert len(rv.data) == 1
-    oimsft.assert_called_with(conjunction=["Jane Doe"], limit=100)
+    rv = check_api_get_responses(api_client, url, status_code=200)
+    assert len(rv.data) == len(ORIGIN_MASTER_REVISION)
+    oimsft.assert_called_with(conjunction=[ORIGIN_METADATA_VALUE], limit=100)
 
 
 @given(origin())
-def test_api_origin_intrinsic_metadata(api_client, mocker, origin):
-    mock_idx_storage = mocker.patch("swh.web.common.service.idx_storage")
-    oimg = mock_idx_storage.origin_intrinsic_metadata_get
-    oimg.side_effect = lambda origin_urls: [
-        {
-            "from_revision": (
-                b"p&\xb7\xc1\xa2\xafVR\x1e\x95\x1c\x01\xed " b"\xf2U\xfa\x05B8"
-            ),
-            "metadata": {"author": "Jane Doe"},
-            "id": origin["url"],
-            "tool": {
-                "configuration": {
-                    "context": ["NpmMapping", "CodemetaMapping"],
-                    "type": "local",
-                },
-                "id": 3,
-                "name": "swh-metadata-detector",
-                "version": "0.0.1",
-            },
-        }
-    ]
+def test_api_origin_intrinsic_metadata(api_client, origin):
 
     url = reverse(
         "api-origin-intrinsic-metadata", url_args={"origin_url": origin["url"]}
     )
-    rv = api_client.get(url)
+    rv = check_api_get_responses(api_client, url, status_code=200)
 
-    oimg.assert_called_once_with([origin["url"]])
-    assert rv.status_code == 200, rv.content
-    assert rv["Content-Type"] == "application/json"
-    expected_data = {"author": "Jane Doe"}
+    expected_data = {ORIGIN_METADATA_KEY: ORIGIN_METADATA_VALUE}
     assert rv.data == expected_data
 
 
 def test_api_origin_metadata_search_invalid(api_client, mocker):
-    mock_idx_storage = mocker.patch("swh.web.common.service.idx_storage")
+    mock_idx_storage = mocker.patch("swh.web.common.archive.idx_storage")
     url = reverse("api-1-origin-metadata-search")
-    rv = api_client.get(url)
-
-    assert rv.status_code == 400, rv.content
+    check_api_get_responses(api_client, url, status_code=400)
     mock_idx_storage.assert_not_called()
