@@ -14,11 +14,17 @@ from swh.web.tests.strategies import (
     unknown_directory,
     unknown_revision,
 )
+from swh.web.tests.utils import (
+    check_api_get_responses,
+    check_api_post_responses,
+    check_http_get_response,
+    check_http_post_response,
+)
 
 
 @given(directory(), revision())
 def test_api_vault_cook(api_client, mocker, directory, revision):
-    mock_service = mocker.patch("swh.web.api.views.vault.service")
+    mock_archive = mocker.patch("swh.web.api.views.vault.archive")
 
     for obj_type, obj_id in (
         ("directory", directory),
@@ -38,33 +44,31 @@ def test_api_vault_cook(api_client, mocker, directory, revision):
         }
         stub_fetch = b"content"
 
-        mock_service.vault_cook.return_value = stub_cook
-        mock_service.vault_fetch.return_value = stub_fetch
+        mock_archive.vault_cook.return_value = stub_cook
+        mock_archive.vault_fetch.return_value = stub_fetch
 
+        email = "test@test.mail"
         url = reverse(
-            f"api-1-vault-cook-{obj_type}", url_args={f"{obj_type[:3]}_id": obj_id}
+            f"api-1-vault-cook-{obj_type}",
+            url_args={f"{obj_type[:3]}_id": obj_id},
+            query_params={"email": email},
         )
 
-        rv = api_client.post(url, {"email": "test@test.mail"})
-
-        assert rv.status_code == 200, rv.data
-        assert rv["Content-Type"] == "application/json"
+        rv = check_api_post_responses(api_client, url, data=None, status_code=200)
 
         stub_cook["fetch_url"] = rv.wsgi_request.build_absolute_uri(
             stub_cook["fetch_url"]
         )
 
         assert rv.data == stub_cook
-        mock_service.vault_cook.assert_called_with(
-            obj_type, hashutil.hash_to_bytes(obj_id), "test@test.mail"
+        mock_archive.vault_cook.assert_called_with(
+            obj_type, hashutil.hash_to_bytes(obj_id), email
         )
 
-        rv = api_client.get(fetch_url)
-
-        assert rv.status_code == 200
+        rv = check_http_get_response(api_client, fetch_url, status_code=200)
         assert rv["Content-Type"] == "application/gzip"
         assert rv.content == stub_fetch
-        mock_service.vault_fetch.assert_called_with(
+        mock_archive.vault_fetch.assert_called_with(
             obj_type, hashutil.hash_to_bytes(obj_id)
         )
 
@@ -81,9 +85,9 @@ def test_api_vault_cook_uppercase_hash(api_client, directory, revision):
             f"api-1-vault-cook-{obj_type}-uppercase-checksum",
             url_args={f"{obj_type[:3]}_id": obj_id.upper()},
         )
-        rv = api_client.post(url, {"email": "test@test.mail"})
-
-        assert rv.status_code == 302
+        rv = check_http_post_response(
+            api_client, url, data={"email": "test@test.mail"}, status_code=302
+        )
 
         redirect_url = reverse(
             f"api-1-vault-cook-{obj_type}", url_args={f"{obj_type[:3]}_id": obj_id}
@@ -96,9 +100,7 @@ def test_api_vault_cook_uppercase_hash(api_client, directory, revision):
             url_args={f"{obj_type[:3]}_id": obj_id.upper()},
         )
 
-        rv = api_client.get(fetch_url)
-
-        assert rv.status_code == 302
+        rv = check_http_get_response(api_client, fetch_url, status_code=302)
 
         redirect_url = reverse(
             f"api-1-vault-fetch-{obj_type}", url_args={f"{obj_type[:3]}_id": obj_id},
@@ -111,7 +113,7 @@ def test_api_vault_cook_uppercase_hash(api_client, directory, revision):
 def test_api_vault_cook_notfound(
     api_client, mocker, directory, revision, unknown_directory, unknown_revision
 ):
-    mock_vault = mocker.patch("swh.web.common.service.vault")
+    mock_vault = mocker.patch("swh.web.common.archive.vault")
     mock_vault.cook.side_effect = NotFoundExc("object not found")
     mock_vault.fetch.side_effect = NotFoundExc("cooked archive not found")
     mock_vault.progress.side_effect = NotFoundExc("cooking request not found")
@@ -127,10 +129,8 @@ def test_api_vault_cook_notfound(
             f"api-1-vault-cook-{obj_type}", url_args={f"{obj_type[:3]}_id": obj_id},
         )
 
-        rv = api_client.get(url)
+        rv = check_api_get_responses(api_client, url, status_code=404)
 
-        assert rv.status_code == 404, rv.data
-        assert rv["Content-Type"] == "application/json"
         assert rv.data["exception"] == "NotFoundExc"
         assert (
             rv.data["reason"]
@@ -147,10 +147,7 @@ def test_api_vault_cook_notfound(
         url = reverse(
             f"api-1-vault-cook-{obj_type}", url_args={f"{obj_type[:3]}_id": obj_id}
         )
-        rv = api_client.post(url)
-
-        assert rv.status_code == 404, rv.data
-        assert rv["Content-Type"] == "application/json"
+        rv = check_api_post_responses(api_client, url, data=None, status_code=404)
 
         assert rv.data["exception"] == "NotFoundExc"
         assert rv.data["reason"] == f"{obj_name.title()} '{obj_id}' not found."
@@ -162,10 +159,7 @@ def test_api_vault_cook_notfound(
             f"api-1-vault-fetch-{obj_type}", url_args={f"{obj_type[:3]}_id": obj_id},
         )
 
-        rv = api_client.get(fetch_url)
-
-        assert rv.status_code == 404, rv.data
-        assert rv["Content-Type"] == "application/json"
+        rv = check_api_get_responses(api_client, fetch_url, status_code=404)
         assert rv.data["exception"] == "NotFoundExc"
         assert (
             rv.data["reason"] == f"Cooked archive for {obj_name} '{obj_id}' not found."
