@@ -6,6 +6,8 @@
 from copy import copy
 from unittest.mock import Mock
 
+from keycloak.exceptions import KeycloakError
+
 from django.utils import timezone
 
 from swh.web.auth.keycloak import KeycloakOpenIDConnect
@@ -62,18 +64,26 @@ class KeycloackOpenIDConnectMock(KeycloakOpenIDConnect):
             ),
         }
         self.authorization_code = Mock()
+        self.refresh_token = Mock()
         self.userinfo = Mock()
         self.logout = Mock()
+        self.offline_token = Mock()
         if auth_success:
             self.authorization_code.return_value = copy(oidc_profile)
+            self.refresh_token.return_value = copy(oidc_profile)
             self.userinfo.return_value = copy(userinfo)
+            self.offline_token.return_value = oidc_profile["refresh_token"]
         else:
             self.authorization_url = Mock()
-            exception = Exception("Authentication failed")
+            exception = KeycloakError(
+                error_message="Authentication failed", response_code=401
+            )
             self.authorization_code.side_effect = exception
             self.authorization_url.side_effect = exception
+            self.refresh_token.side_effect = exception
             self.userinfo.side_effect = exception
             self.logout.side_effect = exception
+            self.offline_token = exception
 
     def decode_token(self, token):
         options = {}
