@@ -5,37 +5,34 @@
 
 import random
 
-from django.utils.html import escape
-
 from hypothesis import given
 
+from django.utils.html import escape
+
 from swh.model.identifiers import CONTENT, DIRECTORY, RELEASE, REVISION, SNAPSHOT
 from swh.web.browse.snapshot_context import process_snapshot_branches
 from swh.web.browse.utils import (
+    _re_encode_content,
     get_mimetype_and_encoding_for_content,
     prepare_content_for_display,
-    _re_encode_content,
 )
 from swh.web.common.exc import NotFoundExc
-from swh.web.common.identifiers import get_swh_persistent_id
+from swh.web.common.identifiers import gen_swhid
 from swh.web.common.utils import gen_path_info, reverse
-from swh.web.tests.django_asserts import (
-    assert_contains,
-    assert_not_contains,
-    assert_template_used,
-)
+from swh.web.tests.django_asserts import assert_contains, assert_not_contains
 from swh.web.tests.strategies import (
     content,
-    content_text_non_utf8,
-    content_text_no_highlight,
     content_image_type,
-    content_unsupported_image_type_rendering,
     content_text,
-    invalid_sha1,
-    unknown_content,
+    content_text_no_highlight,
+    content_text_non_utf8,
+    content_unsupported_image_type_rendering,
     content_utf8_detected_as_binary,
+    invalid_sha1,
     origin_with_multiple_visits,
+    unknown_content,
 )
+from swh.web.tests.utils import check_html_get_response, check_http_get_response
 
 
 @given(content_text())
@@ -50,21 +47,20 @@ def test_content_view_text(client, archive_data, content):
 
     url_raw = reverse("browse-content-raw", url_args={"query_string": content["sha1"]})
 
-    resp = client.get(url)
+    resp = check_html_get_response(
+        client, url, status_code=200, template_used="browse/content.html"
+    )
 
     content_display = _process_content_for_display(archive_data, content)
     mimetype = content_display["mimetype"]
 
-    assert resp.status_code == 200
-    assert_template_used(resp, "browse/content.html")
-
     if mimetype.startswith("text/"):
         assert_contains(resp, '<code class="%s">' % content_display["language"])
         assert_contains(resp, escape(content_display["content_data"]))
     assert_contains(resp, url_raw)
 
-    swh_cnt_id = get_swh_persistent_id(CONTENT, sha1_git)
-    swh_cnt_id_url = reverse("browse-swh-id", url_args={"swh_id": swh_cnt_id})
+    swh_cnt_id = gen_swhid(CONTENT, sha1_git)
+    swh_cnt_id_url = reverse("browse-swhid", url_args={"swhid": swh_cnt_id})
     assert_contains(resp, swh_cnt_id)
     assert_contains(resp, swh_cnt_id_url)
 
@@ -77,19 +73,18 @@ def test_content_view_text_no_highlight(client, archive_data, content):
 
     url_raw = reverse("browse-content-raw", url_args={"query_string": content["sha1"]})
 
-    resp = client.get(url)
+    resp = check_html_get_response(
+        client, url, status_code=200, template_used="browse/content.html"
+    )
 
     content_display = _process_content_for_display(archive_data, content)
 
-    assert resp.status_code == 200
-    assert_template_used(resp, "browse/content.html")
-
     assert_contains(resp, '<code class="nohighlight">')
     assert_contains(resp, escape(content_display["content_data"]))
     assert_contains(resp, url_raw)
 
-    swh_cnt_id = get_swh_persistent_id(CONTENT, sha1_git)
-    swh_cnt_id_url = reverse("browse-swh-id", url_args={"swh_id": swh_cnt_id})
+    swh_cnt_id = gen_swhid(CONTENT, sha1_git)
+    swh_cnt_id_url = reverse("browse-swhid", url_args={"swhid": swh_cnt_id})
 
     assert_contains(resp, swh_cnt_id)
     assert_contains(resp, swh_cnt_id_url)
@@ -101,14 +96,14 @@ def test_content_view_no_utf8_text(client, archive_data, content):
 
     url = reverse("browse-content", url_args={"query_string": content["sha1"]})
 
-    resp = client.get(url)
+    resp = check_html_get_response(
+        client, url, status_code=200, template_used="browse/content.html"
+    )
 
     content_display = _process_content_for_display(archive_data, content)
 
-    assert resp.status_code == 200
-    assert_template_used(resp, "browse/content.html")
-    swh_cnt_id = get_swh_persistent_id(CONTENT, sha1_git)
-    swh_cnt_id_url = reverse("browse-swh-id", url_args={"swh_id": swh_cnt_id})
+    swh_cnt_id = gen_swhid(CONTENT, sha1_git)
+    swh_cnt_id_url = reverse("browse-swhid", url_args={"swhid": swh_cnt_id})
     assert_contains(resp, swh_cnt_id_url)
     assert_contains(resp, escape(content_display["content_data"]))
 
@@ -119,14 +114,13 @@ def test_content_view_image(client, archive_data, content):
 
     url_raw = reverse("browse-content-raw", url_args={"query_string": content["sha1"]})
 
-    resp = client.get(url)
+    resp = check_html_get_response(
+        client, url, status_code=200, template_used="browse/content.html"
+    )
 
     content_display = _process_content_for_display(archive_data, content)
     mimetype = content_display["mimetype"]
     content_data = content_display["content_data"]
-
-    assert resp.status_code == 200
-    assert_template_used(resp, "browse/content.html")
     assert_contains(resp, '<img src="data:%s;base64,%s"/>' % (mimetype, content_data))
     assert_contains(resp, url_raw)
 
@@ -135,13 +129,12 @@ def test_content_view_image(client, archive_data, content):
 def test_content_view_image_no_rendering(client, archive_data, content):
     url = reverse("browse-content", url_args={"query_string": content["sha1"]})
 
-    resp = client.get(url)
+    resp = check_html_get_response(
+        client, url, status_code=200, template_used="browse/content.html"
+    )
 
     mimetype = content["mimetype"]
     encoding = content["encoding"]
-
-    assert resp.status_code == 200
-    assert_template_used(resp, "browse/content.html")
     assert_contains(
         resp,
         (
@@ -161,9 +154,9 @@ def test_content_view_text_with_path(client, archive_data, content):
         query_params={"path": path},
     )
 
-    resp = client.get(url)
-    assert resp.status_code == 200
-    assert_template_used(resp, "browse/content.html")
+    resp = check_html_get_response(
+        client, url, status_code=200, template_used="browse/content.html"
+    )
 
     assert_contains(resp, '<nav class="bread-crumbs')
 
@@ -182,14 +175,12 @@ def test_content_view_text_with_path(client, archive_data, content):
     path = path.replace(root_dir_sha1 + "/", "").replace(filename, "")
 
     swhid_context = {
-        "anchor": get_swh_persistent_id(DIRECTORY, root_dir_sha1),
+        "anchor": gen_swhid(DIRECTORY, root_dir_sha1),
         "path": f"/{path}{filename}",
     }
 
-    swh_cnt_id = get_swh_persistent_id(
-        CONTENT, content["sha1_git"], metadata=swhid_context
-    )
-    swh_cnt_id_url = reverse("browse-swh-id", url_args={"swh_id": swh_cnt_id})
+    swh_cnt_id = gen_swhid(CONTENT, content["sha1_git"], metadata=swhid_context)
+    swh_cnt_id_url = reverse("browse-swhid", url_args={"swhid": swh_cnt_id})
     assert_contains(resp, swh_cnt_id)
     assert_contains(resp, swh_cnt_id_url)
 
@@ -226,9 +217,9 @@ def test_content_view_text_with_path(client, archive_data, content):
         query_params={"path": filename},
     )
 
-    resp = client.get(url)
-    assert resp.status_code == 200
-    assert_template_used(resp, "browse/content.html")
+    resp = check_html_get_response(
+        client, url, status_code=200, template_used="browse/content.html"
+    )
 
     assert_not_contains(resp, '<nav class="bread-crumbs')
 
@@ -238,19 +229,22 @@ def test_content_view_text_with_path(client, archive_data, content):
         url_args={"query_string": content["sha1"]},
         query_params={"path": invalid_path},
     )
-    resp = client.get(url)
-    assert resp.status_code == 404
+
+    resp = check_html_get_response(
+        client, url, status_code=404, template_used="error.html"
+    )
 
 
 @given(content_text())
 def test_content_raw_text(client, archive_data, content):
     url = reverse("browse-content-raw", url_args={"query_string": content["sha1"]})
 
-    resp = client.get(url)
+    resp = check_http_get_response(
+        client, url, status_code=200, content_type="text/plain"
+    )
 
-    content_data = archive_data.content_get(content["sha1"])["data"]
+    content_data = archive_data.content_get_data(content["sha1"])["data"]
 
-    assert resp.status_code == 200
     assert resp["Content-Type"] == "text/plain"
     assert resp["Content-disposition"] == ("filename=%s_%s" % ("sha1", content["sha1"]))
     assert resp.content == content_data
@@ -263,9 +257,10 @@ def test_content_raw_text(client, archive_data, content):
         query_params={"filename": filename},
     )
 
-    resp = client.get(url)
+    resp = check_http_get_response(
+        client, url, status_code=200, content_type="text/plain"
+    )
 
-    assert resp.status_code == 200
     assert resp["Content-Type"] == "text/plain"
     assert resp["Content-disposition"] == "filename=%s" % filename
     assert resp.content == content_data
@@ -275,8 +270,9 @@ def test_content_raw_text(client, archive_data, content):
 def test_content_raw_no_utf8_text(client, content):
     url = reverse("browse-content-raw", url_args={"query_string": content["sha1"]})
 
-    resp = client.get(url)
-    assert resp.status_code == 200
+    resp = check_http_get_response(
+        client, url, status_code=200, content_type="text/plain"
+    )
     _, encoding = get_mimetype_and_encoding_for_content(resp.content)
     assert encoding == content["encoding"]
 
@@ -285,12 +281,13 @@ def test_content_raw_no_utf8_text(client, content):
 def test_content_raw_bin(client, archive_data, content):
     url = reverse("browse-content-raw", url_args={"query_string": content["sha1"]})
 
-    resp = client.get(url)
+    resp = check_http_get_response(
+        client, url, status_code=200, content_type="application/octet-stream"
+    )
 
     filename = content["path"].split("/")[-1]
-    content_data = archive_data.content_get(content["sha1"])["data"]
+    content_data = archive_data.content_get_data(content["sha1"])["data"]
 
-    assert resp.status_code == 200
     assert resp["Content-Type"] == "application/octet-stream"
     assert resp["Content-disposition"] == "attachment; filename=%s_%s" % (
         "sha1",
@@ -304,9 +301,10 @@ def test_content_raw_bin(client, archive_data, content):
         query_params={"filename": filename},
     )
 
-    resp = client.get(url)
+    resp = check_http_get_response(
+        client, url, status_code=200, content_type="application/octet-stream"
+    )
 
-    assert resp.status_code == 200
     assert resp["Content-Type"] == "application/octet-stream"
     assert resp["Content-disposition"] == "attachment; filename=%s" % filename
     assert resp.content == content_data
@@ -315,34 +313,28 @@ def test_content_raw_bin(client, archive_data, content):
 @given(invalid_sha1(), unknown_content())
 def test_content_request_errors(client, invalid_sha1, unknown_content):
     url = reverse("browse-content", url_args={"query_string": invalid_sha1})
-    resp = client.get(url)
-    assert resp.status_code == 400
-    assert_template_used(resp, "error.html")
+    check_html_get_response(client, url, status_code=400, template_used="error.html")
 
     url = reverse("browse-content", url_args={"query_string": unknown_content["sha1"]})
-    resp = client.get(url)
-    assert resp.status_code == 404
-    assert_template_used(resp, "error.html")
+    check_html_get_response(client, url, status_code=404, template_used="error.html")
 
 
 @given(content())
 def test_content_bytes_missing(client, archive_data, mocker, content):
-    mock_service = mocker.patch("swh.web.browse.utils.service")
-    content_data = archive_data.content_get_metadata(content["sha1"])
-    content_data["data"] = None
+    mock_archive = mocker.patch("swh.web.browse.utils.archive")
+    content_data = archive_data.content_get(content["sha1"])
 
-    mock_service.lookup_content.return_value = content_data
-    mock_service.lookup_content_filetype.side_effect = Exception()
-    mock_service.lookup_content_raw.side_effect = NotFoundExc(
+    mock_archive.lookup_content.return_value = content_data
+    mock_archive.lookup_content_filetype.side_effect = Exception()
+    mock_archive.lookup_content_raw.side_effect = NotFoundExc(
         "Content bytes not available!"
     )
 
     url = reverse("browse-content", url_args={"query_string": content["sha1"]})
 
-    resp = client.get(url)
-
-    assert resp.status_code == 404
-    assert_template_used(resp, "browse/content.html")
+    check_html_get_response(
+        client, url, status_code=404, template_used="browse/content.html"
+    )
 
 
 def test_content_too_large(client, mocker):
@@ -377,10 +369,9 @@ def test_content_too_large(client, mocker):
 
     url_raw = reverse("browse-content-raw", url_args={"query_string": content_sha1})
 
-    resp = client.get(url)
-
-    assert resp.status_code == 200
-    assert_template_used(resp, "browse/content.html")
+    resp = check_html_get_response(
+        client, url, status_code=200, template_used="browse/content.html"
+    )
 
     assert_contains(resp, "Content is too large to be displayed")
     assert_contains(resp, url_raw)
@@ -392,8 +383,8 @@ def test_content_uppercase(client, content):
         "browse-content-uppercase-checksum",
         url_args={"query_string": content["sha1"].upper()},
     )
-    resp = client.get(url)
-    assert resp.status_code == 302
+
+    resp = check_html_get_response(client, url, status_code=302)
 
     redirect_url = reverse("browse-content", url_args={"query_string": content["sha1"]})
 
@@ -403,7 +394,10 @@ def test_content_uppercase(client, content):
 @given(content_utf8_detected_as_binary())
 def test_content_utf8_detected_as_binary_display(client, archive_data, content):
     url = reverse("browse-content", url_args={"query_string": content["sha1"]})
-    resp = client.get(url)
+
+    resp = check_html_get_response(
+        client, url, status_code=200, template_used="browse/content.html"
+    )
 
     content_display = _process_content_for_display(archive_data, content)
 
@@ -415,7 +409,8 @@ def test_content_origin_snapshot_branch_browse(client, archive_data, origin):
     visits = archive_data.origin_visit_get(origin["url"])
     visit = random.choice(visits)
     snapshot = archive_data.snapshot_get(visit["snapshot"])
-    branches, releases = process_snapshot_branches(snapshot)
+    snapshot_sizes = archive_data.snapshot_count_branches(visit["snapshot"])
+    branches, releases, _ = process_snapshot_branches(snapshot)
     branch_info = random.choice(branches)
 
     directory = archive_data.revision_get(branch_info["revision"])["directory"]
@@ -435,50 +430,47 @@ def test_content_origin_snapshot_branch_browse(client, archive_data, origin):
         },
     )
 
-    resp = client.get(url)
-    assert resp.status_code == 200
-    assert_template_used(resp, "browse/content.html")
-    _check_origin_snapshot_related_html(resp, origin, snapshot, branches, releases)
+    resp = check_html_get_response(
+        client, url, status_code=200, template_used="browse/content.html"
+    )
+
+    _check_origin_snapshot_related_html(
+        resp, origin, snapshot, snapshot_sizes, branches, releases
+    )
     assert_contains(resp, directory_file["name"])
     assert_contains(resp, f"Branch: <strong>{branch_info['name']}</strong>")
 
-    cnt_swhid = get_swh_persistent_id(
+    cnt_swhid = gen_swhid(
         CONTENT,
         directory_file["checksums"]["sha1_git"],
         metadata={
             "origin": origin["url"],
-            "visit": get_swh_persistent_id(SNAPSHOT, snapshot),
-            "anchor": get_swh_persistent_id(REVISION, branch_info["revision"]),
+            "visit": gen_swhid(SNAPSHOT, snapshot),
+            "anchor": gen_swhid(REVISION, branch_info["revision"]),
             "path": f"/{directory_file['name']}",
         },
     )
     assert_contains(resp, cnt_swhid)
 
-    dir_swhid = get_swh_persistent_id(
+    dir_swhid = gen_swhid(
         DIRECTORY,
         directory,
         metadata={
             "origin": origin["url"],
-            "visit": get_swh_persistent_id(SNAPSHOT, snapshot),
-            "anchor": get_swh_persistent_id(REVISION, branch_info["revision"]),
-            "path": "/",
+            "visit": gen_swhid(SNAPSHOT, snapshot),
+            "anchor": gen_swhid(REVISION, branch_info["revision"]),
         },
     )
     assert_contains(resp, dir_swhid)
 
-    rev_swhid = get_swh_persistent_id(
+    rev_swhid = gen_swhid(
         REVISION,
         branch_info["revision"],
-        metadata={
-            "origin": origin["url"],
-            "visit": get_swh_persistent_id(SNAPSHOT, snapshot),
-        },
+        metadata={"origin": origin["url"], "visit": gen_swhid(SNAPSHOT, snapshot),},
     )
     assert_contains(resp, rev_swhid)
 
-    snp_swhid = get_swh_persistent_id(
-        SNAPSHOT, snapshot, metadata={"origin": origin["url"],},
-    )
+    snp_swhid = gen_swhid(SNAPSHOT, snapshot, metadata={"origin": origin["url"],},)
     assert_contains(resp, snp_swhid)
 
 
@@ -487,7 +479,8 @@ def test_content_origin_snapshot_release_browse(client, archive_data, origin):
     visits = archive_data.origin_visit_get(origin["url"])
     visit = random.choice(visits)
     snapshot = archive_data.snapshot_get(visit["snapshot"])
-    branches, releases = process_snapshot_branches(snapshot)
+    snapshot_sizes = archive_data.snapshot_count_branches(visit["snapshot"])
+    branches, releases, _ = process_snapshot_branches(snapshot)
     release_info = random.choice(releases)
 
     directory_content = archive_data.directory_ls(release_info["directory"])
@@ -506,64 +499,60 @@ def test_content_origin_snapshot_release_browse(client, archive_data, origin):
         },
     )
 
-    resp = client.get(url)
-    assert resp.status_code == 200
-    assert_template_used(resp, "browse/content.html")
-    _check_origin_snapshot_related_html(resp, origin, snapshot, branches, releases)
+    resp = check_html_get_response(
+        client, url, status_code=200, template_used="browse/content.html"
+    )
+
+    _check_origin_snapshot_related_html(
+        resp, origin, snapshot, snapshot_sizes, branches, releases
+    )
     assert_contains(resp, directory_file["name"])
     assert_contains(resp, f"Release: <strong>{release_info['name']}</strong>")
 
-    cnt_swhid = get_swh_persistent_id(
+    cnt_swhid = gen_swhid(
         CONTENT,
         directory_file["checksums"]["sha1_git"],
         metadata={
             "origin": origin["url"],
-            "visit": get_swh_persistent_id(SNAPSHOT, snapshot),
-            "anchor": get_swh_persistent_id(RELEASE, release_info["id"]),
+            "visit": gen_swhid(SNAPSHOT, snapshot),
+            "anchor": gen_swhid(RELEASE, release_info["id"]),
             "path": f"/{directory_file['name']}",
         },
     )
     assert_contains(resp, cnt_swhid)
 
-    dir_swhid = get_swh_persistent_id(
+    dir_swhid = gen_swhid(
         DIRECTORY,
         release_info["directory"],
         metadata={
             "origin": origin["url"],
-            "visit": get_swh_persistent_id(SNAPSHOT, snapshot),
-            "anchor": get_swh_persistent_id(RELEASE, release_info["id"]),
-            "path": "/",
+            "visit": gen_swhid(SNAPSHOT, snapshot),
+            "anchor": gen_swhid(RELEASE, release_info["id"]),
         },
     )
     assert_contains(resp, dir_swhid)
 
-    rev_swhid = get_swh_persistent_id(
+    rev_swhid = gen_swhid(
         REVISION,
         release_info["target"],
-        metadata={
-            "origin": origin["url"],
-            "visit": get_swh_persistent_id(SNAPSHOT, snapshot),
-        },
+        metadata={"origin": origin["url"], "visit": gen_swhid(SNAPSHOT, snapshot),},
     )
     assert_contains(resp, rev_swhid)
 
-    rel_swhid = get_swh_persistent_id(
+    rel_swhid = gen_swhid(
         RELEASE,
         release_info["id"],
-        metadata={
-            "origin": origin["url"],
-            "visit": get_swh_persistent_id(SNAPSHOT, snapshot),
-        },
+        metadata={"origin": origin["url"], "visit": gen_swhid(SNAPSHOT, snapshot),},
     )
     assert_contains(resp, rel_swhid)
 
-    snp_swhid = get_swh_persistent_id(
-        SNAPSHOT, snapshot, metadata={"origin": origin["url"],},
-    )
+    snp_swhid = gen_swhid(SNAPSHOT, snapshot, metadata={"origin": origin["url"],},)
     assert_contains(resp, snp_swhid)
 
 
-def _check_origin_snapshot_related_html(resp, origin, snapshot, branches, releases):
+def _check_origin_snapshot_related_html(
+    resp, origin, snapshot, snapshot_sizes, branches, releases
+):
     browse_origin_url = reverse(
         "browse-origin", query_params={"origin_url": origin["url"]}
     )
@@ -575,7 +564,7 @@ def _check_origin_snapshot_related_html(resp, origin, snapshot, branches, releas
     )
 
     assert_contains(resp, f'href="{escape(origin_branches_url)}"')
-    assert_contains(resp, f"Branches ({len(branches)})")
+    assert_contains(resp, f"Branches ({snapshot_sizes['revision']})")
 
     origin_releases_url = reverse(
         "browse-origin-releases",
@@ -583,14 +572,14 @@ def _check_origin_snapshot_related_html(resp, origin, snapshot, branches, releas
     )
 
     assert_contains(resp, f'href="{escape(origin_releases_url)}"')
-    assert_contains(resp, f"Releases ({len(releases)})")
+    assert_contains(resp, f"Releases ({snapshot_sizes['release']})")
 
     assert_contains(resp, '<li class="swh-branch">', count=len(branches))
     assert_contains(resp, '<li class="swh-release">', count=len(releases))
 
 
 def _process_content_for_display(archive_data, content):
-    content_data = archive_data.content_get(content["sha1"])
+    content_data = archive_data.content_get_data(content["sha1"])
 
     mime_type, encoding = get_mimetype_and_encoding_for_content(content_data["data"])
 
