@@ -5,21 +5,42 @@
 
 import random
 
-from django.utils.html import escape
 from hypothesis import given
 
+from django.utils.html import escape
+
+from swh.model.from_disk import DentryPerms
+from swh.model.hashutil import hash_to_bytes, hash_to_hex
 from swh.model.identifiers import DIRECTORY, RELEASE, REVISION, SNAPSHOT
+from swh.model.model import (
+    Directory,
+    DirectoryEntry,
+    Origin,
+    OriginVisit,
+    OriginVisitStatus,
+    Revision,
+    RevisionType,
+    Snapshot,
+    SnapshotBranch,
+    TargetType,
+    TimestampWithTimezone,
+)
+from swh.storage.utils import now
 from swh.web.browse.snapshot_context import process_snapshot_branches
-from swh.web.common.identifiers import get_swh_persistent_id
+from swh.web.common.identifiers import gen_swhid
 from swh.web.common.utils import gen_path_info, reverse
-from swh.web.tests.django_asserts import assert_contains, assert_template_used
+from swh.web.tests.django_asserts import assert_contains
 from swh.web.tests.strategies import (
     directory,
     directory_with_subdirs,
+    empty_directory,
     invalid_sha1,
-    unknown_directory,
+    new_person,
+    new_swh_date,
     origin_with_multiple_visits,
+    unknown_directory,
 )
+from swh.web.tests.utils import check_html_get_response
 
 
 @given(directory())
@@ -35,19 +56,101 @@ def test_sub_directory_view(client, archive_data, directory):
     _directory_view_checks(client, directory, subdir_content, subdir["name"])
 
 
+@given(empty_directory(), new_person(), new_swh_date())
+def test_sub_directory_view_origin_context(
+    client, archive_data, empty_directory, person, date
+):
+    origin_url = "test_sub_directory_view_origin_context"
+    subdir = Directory(
+        entries=(
+            DirectoryEntry(
+                name=b"foo",
+                type="dir",
+                target=hash_to_bytes(empty_directory),
+                perms=DentryPerms.directory,
+            ),
+            DirectoryEntry(
+                name=b"bar",
+                type="dir",
+                target=hash_to_bytes(empty_directory),
+                perms=DentryPerms.directory,
+            ),
+        )
+    )
+
+    parentdir = Directory(
+        entries=(
+            DirectoryEntry(
+                name=b"baz", type="dir", target=subdir.id, perms=DentryPerms.directory,
+            ),
+        )
+    )
+    archive_data.directory_add([subdir, parentdir])
+
+    revision = Revision(
+        directory=parentdir.id,
+        author=person,
+        committer=person,
+        message=b"commit message",
+        date=TimestampWithTimezone.from_datetime(date),
+        committer_date=TimestampWithTimezone.from_datetime(date),
+        synthetic=False,
+        type=RevisionType.GIT,
+    )
+    archive_data.revision_add([revision])
+
+    snapshot = Snapshot(
+        branches={
+            b"HEAD": SnapshotBranch(
+                target="refs/head/master".encode(), target_type=TargetType.ALIAS,
+            ),
+            b"refs/head/master": SnapshotBranch(
+                target=revision.id, target_type=TargetType.REVISION,
+            ),
+        }
+    )
+    archive_data.snapshot_add([snapshot])
+
+    archive_data.origin_add([Origin(url=origin_url)])
+    date = now()
+    visit = OriginVisit(origin=origin_url, date=date, type="git")
+    visit = archive_data.origin_visit_add([visit])[0]
+    visit_status = OriginVisitStatus(
+        origin=origin_url,
+        visit=visit.visit,
+        date=date,
+        status="full",
+        snapshot=snapshot.id,
+    )
+    archive_data.origin_visit_status_add([visit_status])
+
+    dir_content = archive_data.directory_ls(hash_to_hex(parentdir.id))
+    subdir = dir_content[0]
+    subdir_content = archive_data.directory_ls(subdir["target"])
+    _directory_view_checks(
+        client,
+        hash_to_hex(parentdir.id),
+        subdir_content,
+        subdir["name"],
+        origin_url,
+        hash_to_hex(snapshot.id),
+        hash_to_hex(revision.id),
+    )
+
+
 @given(invalid_sha1(), unknown_directory())
 def test_directory_request_errors(client, invalid_sha1, unknown_directory):
     dir_url = reverse("browse-directory", url_args={"sha1_git": invalid_sha1})
 
-    resp = client.get(dir_url)
-    assert resp.status_code == 400
-    assert_template_used(resp, "error.html")
+    check_html_get_response(
+        client, dir_url, status_code=400, template_used="error.html"
+    )
 
     dir_url = reverse("browse-directory", url_args={"sha1_git": unknown_directory})
 
-    resp = client.get(dir_url)
-    assert resp.status_code == 404
-    assert_template_used(resp, "error.html")
+    check_html_get_response(
+        client, dir_url, status_code=404, template_used="error.html"
+    )
 
 
 @given(directory())
@@ -56,8 +159,7 @@ def test_directory_uppercase(client, directory):
         "browse-directory-uppercase-checksum", url_args={"sha1_git": directory.upper()}
     )
 
-    resp = client.get(url)
-    assert resp.status_code == 302
+    resp = check_html_get_response(client, url, status_code=302)
 
     redirect_url = reverse("browse-directory", url_args={"sha1_git": directory})
 
@@ -73,10 +175,10 @@ def test_permalink_box_context(client, tests_data, directory):
         query_params={"origin_url": origin_url},
     )
 
-    resp = client.get(url)
-
-    assert resp.status_code == 200
-    assert_contains(resp, 'id="swh-id-context-option-directory"')
+    resp = check_html_get_response(
+        client, url, status_code=200, template_used="browse/directory.html"
+    )
+    assert_contains(resp, 'id="swhid-context-option-directory"')
 
 
 @given(origin_with_multiple_visits())
@@ -84,7 +186,8 @@ def test_directory_origin_snapshot_branch_browse(client, archive_data, origin):
     visits = archive_data.origin_visit_get(origin["url"])
     visit = random.choice(visits)
     snapshot = archive_data.snapshot_get(visit["snapshot"])
-    branches, releases = process_snapshot_branches(snapshot)
+    snapshot_sizes = archive_data.snapshot_count_branches(visit["snapshot"])
+    branches, releases, _ = process_snapshot_branches(snapshot)
     branch_info = random.choice(branches)
 
     directory = archive_data.revision_get(branch_info["revision"])["directory"]
@@ -104,39 +207,36 @@ def test_directory_origin_snapshot_branch_browse(client, archive_data, origin):
         },
     )
 
-    resp = client.get(url)
+    resp = check_html_get_response(
+        client, url, status_code=200, template_used="browse/directory.html"
+    )
 
-    assert resp.status_code == 200
-    assert_template_used(resp, "browse/directory.html")
-    _check_origin_snapshot_related_html(resp, origin, snapshot, branches, releases)
+    _check_origin_snapshot_related_html(
+        resp, origin, snapshot, snapshot_sizes, branches, releases
+    )
     assert_contains(resp, directory_subdir["name"])
     assert_contains(resp, f"Branch: <strong>{branch_info['name']}</strong>")
 
-    dir_swhid = get_swh_persistent_id(
+    dir_swhid = gen_swhid(
         DIRECTORY,
         directory_subdir["target"],
         metadata={
             "origin": origin["url"],
-            "visit": get_swh_persistent_id(SNAPSHOT, snapshot),
-            "anchor": get_swh_persistent_id(REVISION, branch_info["revision"]),
+            "visit": gen_swhid(SNAPSHOT, snapshot),
+            "anchor": gen_swhid(REVISION, branch_info["revision"]),
             "path": "/",
         },
     )
     assert_contains(resp, dir_swhid)
 
-    rev_swhid = get_swh_persistent_id(
+    rev_swhid = gen_swhid(
         REVISION,
         branch_info["revision"],
-        metadata={
-            "origin": origin["url"],
-            "visit": get_swh_persistent_id(SNAPSHOT, snapshot),
-        },
+        metadata={"origin": origin["url"], "visit": gen_swhid(SNAPSHOT, snapshot),},
     )
     assert_contains(resp, rev_swhid)
 
-    snp_swhid = get_swh_persistent_id(
-        SNAPSHOT, snapshot, metadata={"origin": origin["url"],},
-    )
+    snp_swhid = gen_swhid(SNAPSHOT, snapshot, metadata={"origin": origin["url"],},)
     assert_contains(resp, snp_swhid)
 
 
@@ -145,7 +245,8 @@ def test_content_origin_snapshot_release_browse(client, archive_data, origin):
     visits = archive_data.origin_visit_get(origin["url"])
     visit = random.choice(visits)
     snapshot = archive_data.snapshot_get(visit["snapshot"])
-    branches, releases = process_snapshot_branches(snapshot)
+    snapshot_sizes = archive_data.snapshot_count_branches(visit["snapshot"])
+    branches, releases, _ = process_snapshot_branches(snapshot)
     release_info = random.choice(releases)
 
     directory = release_info["directory"]
@@ -165,52 +266,49 @@ def test_content_origin_snapshot_release_browse(client, archive_data, origin):
         },
     )
 
-    resp = client.get(url)
-    assert resp.status_code == 200
-    assert_template_used(resp, "browse/directory.html")
-    _check_origin_snapshot_related_html(resp, origin, snapshot, branches, releases)
+    resp = check_html_get_response(
+        client, url, status_code=200, template_used="browse/directory.html"
+    )
+
+    _check_origin_snapshot_related_html(
+        resp, origin, snapshot, snapshot_sizes, branches, releases
+    )
     assert_contains(resp, directory_subdir["name"])
     assert_contains(resp, f"Release: <strong>{release_info['name']}</strong>")
 
-    dir_swhid = get_swh_persistent_id(
+    dir_swhid = gen_swhid(
         DIRECTORY,
         directory_subdir["target"],
         metadata={
             "origin": origin["url"],
-            "visit": get_swh_persistent_id(SNAPSHOT, snapshot),
-            "anchor": get_swh_persistent_id(RELEASE, release_info["id"]),
+            "visit": gen_swhid(SNAPSHOT, snapshot),
+            "anchor": gen_swhid(RELEASE, release_info["id"]),
             "path": "/",
         },
     )
     assert_contains(resp, dir_swhid)
 
-    rev_swhid = get_swh_persistent_id(
+    rev_swhid = gen_swhid(
         REVISION,
         release_info["target"],
-        metadata={
-            "origin": origin["url"],
-            "visit": get_swh_persistent_id(SNAPSHOT, snapshot),
-        },
+        metadata={"origin": origin["url"], "visit": gen_swhid(SNAPSHOT, snapshot),},
     )
     assert_contains(resp, rev_swhid)
 
-    rel_swhid = get_swh_persistent_id(
+    rel_swhid = gen_swhid(
         RELEASE,
         release_info["id"],
-        metadata={
-            "origin": origin["url"],
-            "visit": get_swh_persistent_id(SNAPSHOT, snapshot),
-        },
+        metadata={"origin": origin["url"], "visit": gen_swhid(SNAPSHOT, snapshot),},
     )
     assert_contains(resp, rel_swhid)
 
-    snp_swhid = get_swh_persistent_id(
-        SNAPSHOT, snapshot, metadata={"origin": origin["url"],},
-    )
+    snp_swhid = gen_swhid(SNAPSHOT, snapshot, metadata={"origin": origin["url"],},)
     assert_contains(resp, snp_swhid)
 
 
-def _check_origin_snapshot_related_html(resp, origin, snapshot, branches, releases):
+def _check_origin_snapshot_related_html(
+    resp, origin, snapshot, snapshot_sizes, branches, releases
+):
     browse_origin_url = reverse(
         "browse-origin", query_params={"origin_url": origin["url"]}
     )
@@ -223,7 +321,7 @@ def _check_origin_snapshot_related_html(resp, origin, snapshot, branches, releas
     )
 
     assert_contains(resp, f'href="{escape(origin_branches_url)}"')
-    assert_contains(resp, f"Branches ({len(branches)})")
+    assert_contains(resp, f"Branches ({snapshot_sizes['revision']})")
 
     origin_releases_url = reverse(
         "browse-origin-releases",
@@ -231,7 +329,7 @@ def _check_origin_snapshot_related_html(resp, origin, snapshot, branches, releas
     )
 
     assert_contains(resp, f'href="{escape(origin_releases_url)}"')
-    assert_contains(resp, f"Releases ({len(releases)})")
+    assert_contains(resp, f"Releases ({snapshot_sizes['release']})")
 
     assert_contains(resp, '<li class="swh-branch">', count=len(branches))
     assert_contains(resp, '<li class="swh-release">', count=len(releases))
@@ -244,25 +342,30 @@ def _directory_view_checks(
     path=None,
     origin_url=None,
     snapshot_id=None,
+    revision_id=None,
 ):
     dirs = [e for e in directory_entries if e["type"] in ("dir", "rev")]
     files = [e for e in directory_entries if e["type"] == "file"]
 
     url_args = {"sha1_git": root_directory_sha1}
-    query_params = {"path": path, "origin_url": origin_url, "snapshot": snapshot_id}
+    query_params = {"origin_url": origin_url, "snapshot": snapshot_id}
 
-    url = reverse("browse-directory", url_args=url_args, query_params=query_params)
-
-    root_dir_url = reverse(
-        "browse-directory", url_args={"sha1_git": root_directory_sha1}
+    url = reverse(
+        "browse-directory",
+        url_args=url_args,
+        query_params={**query_params, "path": path},
     )
 
-    resp = client.get(url)
+    root_dir_url = reverse(
+        "browse-directory", url_args=url_args, query_params=query_params,
+    )
+
+    resp = check_html_get_response(
+        client, url, status_code=200, template_used="browse/directory.html"
+    )
 
-    assert resp.status_code == 200
-    assert_template_used(resp, "browse/directory.html")
     assert_contains(
-        resp, '<a href="' + root_dir_url + '">' + root_directory_sha1[:7] + "</a>"
+        resp, '<a href="' + root_dir_url + '">' + root_directory_sha1[:7] + "</a>",
     )
     assert_contains(resp, '<td class="swh-directory">', count=len(dirs))
     assert_contains(resp, '<td class="swh-content">', count=len(files))
@@ -277,7 +380,7 @@ def _directory_view_checks(
             dir_url = reverse(
                 "browse-directory",
                 url_args={"sha1_git": root_directory_sha1},
-                query_params={"path": dir_path},
+                query_params={**query_params, "path": dir_path},
             )
         assert_contains(resp, dir_url)
 
@@ -289,7 +392,7 @@ def _directory_view_checks(
         file_url = reverse(
             "browse-content",
             url_args={"query_string": query_string},
-            query_params={"path": file_path},
+            query_params={**query_params, "path": file_path},
         )
         assert_contains(resp, file_url)
 
@@ -304,27 +407,31 @@ def _directory_view_checks(
         dir_url = reverse(
             "browse-directory",
             url_args={"sha1_git": root_directory_sha1},
-            query_params={"path": p["path"]},
+            query_params={**query_params, "path": p["path"]},
         )
         assert_contains(resp, '<a href="%s">%s</a>' % (dir_url, p["name"]))
 
     assert_contains(resp, "vault-cook-directory")
 
-    swh_dir_id = get_swh_persistent_id(DIRECTORY, directory_entries[0]["dir_id"])
-    swh_dir_id_url = reverse("browse-swh-id", url_args={"swh_id": swh_dir_id})
+    swh_dir_id = gen_swhid(DIRECTORY, directory_entries[0]["dir_id"])
+    swh_dir_id_url = reverse("browse-swhid", url_args={"swhid": swh_dir_id})
 
     swhid_context = {}
+    if origin_url:
+        swhid_context["origin"] = origin_url
+    if snapshot_id:
+        swhid_context["visit"] = gen_swhid(SNAPSHOT, snapshot_id)
     if root_directory_sha1 != directory_entries[0]["dir_id"]:
-        swhid_context["anchor"] = get_swh_persistent_id(DIRECTORY, root_directory_sha1)
-
-    swhid_context["path"] = f"/{path}/" if path else "/"
-
+        swhid_context["anchor"] = gen_swhid(DIRECTORY, root_directory_sha1)
     if root_directory_sha1 != directory_entries[0]["dir_id"]:
-        swhid_context["anchor"] = get_swh_persistent_id(DIRECTORY, root_directory_sha1)
+        swhid_context["anchor"] = gen_swhid(DIRECTORY, root_directory_sha1)
+    if revision_id:
+        swhid_context["anchor"] = gen_swhid(REVISION, revision_id)
+    swhid_context["path"] = f"/{path}/" if path else None
 
-    swh_dir_id = get_swh_persistent_id(
+    swh_dir_id = gen_swhid(
         DIRECTORY, directory_entries[0]["dir_id"], metadata=swhid_context
     )
-    swh_dir_id_url = reverse("browse-swh-id", url_args={"swh_id": swh_dir_id})
+    swh_dir_id_url = reverse("browse-swhid", url_args={"swhid": swh_dir_id})
     assert_contains(resp, swh_dir_id)
     assert_contains(resp, swh_dir_id_url)
