@@ -7,58 +7,50 @@ import random
 import re
 import string
 
-from django.utils.html import escape
-
 from hypothesis import given
 
-from swh.storage.utils import now
+from django.utils.html import escape
 
 from swh.model.hashutil import hash_to_bytes
 from swh.model.identifiers import CONTENT, DIRECTORY, RELEASE, REVISION, SNAPSHOT
 from swh.model.model import (
+    OriginVisit,
+    OriginVisitStatus,
     Snapshot,
     SnapshotBranch,
     TargetType,
-    OriginVisit,
-    OriginVisitStatus,
 )
+from swh.storage.utils import now
 from swh.web.browse.snapshot_context import process_snapshot_branches
 from swh.web.common.exc import NotFoundExc
-from swh.web.common.identifiers import get_swh_persistent_id
+from swh.web.common.identifiers import gen_swhid
 from swh.web.common.utils import (
-    reverse,
-    gen_path_info,
     format_utc_iso_date,
-    parse_timestamp,
+    gen_path_info,
+    parse_iso8601_date_to_utc,
+    reverse,
 )
 from swh.web.tests.data import get_content, random_sha1
-from swh.web.tests.django_asserts import assert_contains, assert_template_used
+from swh.web.tests.django_asserts import assert_contains
 from swh.web.tests.strategies import (
-    origin,
-    origin_with_multiple_visits,
     new_origin,
     new_snapshot,
-    visit_dates,
-    revisions,
+    origin,
+    origin_with_multiple_visits,
     origin_with_releases,
-    release as existing_release,
-    unknown_revision,
 )
+from swh.web.tests.strategies import release as existing_release
+from swh.web.tests.strategies import revisions, unknown_revision, visit_dates
+from swh.web.tests.utils import check_html_get_response
 
 
 @given(origin_with_multiple_visits())
 def test_origin_visits_browse(client, archive_data, origin):
     url = reverse("browse-origin-visits", query_params={"origin_url": origin["url"]})
-    resp = client.get(url)
 
-    assert resp.status_code == 200
-    assert_template_used(resp, "browse/origin-visits.html")
-
-    url = reverse("browse-origin-visits", query_params={"origin_url": origin["url"]})
-    resp = client.get(url)
-
-    assert resp.status_code == 200
-    assert_template_used(resp, "browse/origin-visits.html")
+    resp = check_html_get_response(
+        client, url, status_code=200, template_used="browse/origin-visits.html"
+    )
 
     visits = archive_data.origin_visit_get(origin["url"])
 
@@ -84,13 +76,14 @@ def test_origin_content_view(client, archive_data, origin):
         dir_content = archive_data.directory_ls(head_rev["directory"])
         dir_files = [e for e in dir_content if e["type"] == "file"]
         dir_file = random.choice(dir_files)
-        branches, releases = process_snapshot_branches(snapshot)
+        branches, releases, _ = process_snapshot_branches(snapshot)
         return {
             "branches": branches,
             "releases": releases,
             "root_dir_sha1": head_rev["directory"],
             "content": get_content(dir_file["checksums"]["sha1"]),
             "visit": origin_visits[visit_idx],
+            "snapshot_sizes": archive_data.snapshot_count_branches(snapshot["id"]),
         }
 
     tdata = _get_archive_data(-1)
@@ -100,6 +93,7 @@ def test_origin_content_view(client, archive_data, origin):
         archive_data,
         origin,
         origin_visits[-1],
+        tdata["snapshot_sizes"],
         tdata["branches"],
         tdata["releases"],
         tdata["root_dir_sha1"],
@@ -111,6 +105,7 @@ def test_origin_content_view(client, archive_data, origin):
         archive_data,
         origin,
         origin_visits[-1],
+        tdata["snapshot_sizes"],
         tdata["branches"],
         tdata["releases"],
         tdata["root_dir_sha1"],
@@ -118,26 +113,12 @@ def test_origin_content_view(client, archive_data, origin):
         timestamp=tdata["visit"]["date"],
     )
 
-    visit_unix_ts = parse_timestamp(tdata["visit"]["date"]).timestamp()
-    visit_unix_ts = int(visit_unix_ts)
-
-    _origin_content_view_test_helper(
-        client,
-        archive_data,
-        origin,
-        origin_visits[-1],
-        tdata["branches"],
-        tdata["releases"],
-        tdata["root_dir_sha1"],
-        tdata["content"],
-        timestamp=visit_unix_ts,
-    )
-
     _origin_content_view_test_helper(
         client,
         archive_data,
         origin,
         origin_visits[-1],
+        tdata["snapshot_sizes"],
         tdata["branches"],
         tdata["releases"],
         tdata["root_dir_sha1"],
@@ -152,6 +133,7 @@ def test_origin_content_view(client, archive_data, origin):
         archive_data,
         origin,
         origin_visits[0],
+        tdata["snapshot_sizes"],
         tdata["branches"],
         tdata["releases"],
         tdata["root_dir_sha1"],
@@ -164,6 +146,7 @@ def test_origin_content_view(client, archive_data, origin):
         archive_data,
         origin,
         origin_visits[0],
+        tdata["snapshot_sizes"],
         tdata["branches"],
         tdata["releases"],
         tdata["root_dir_sha1"],
@@ -178,19 +161,19 @@ def test_origin_root_directory_view(client, archive_data, origin):
 
     visit = origin_visits[-1]
     snapshot = archive_data.snapshot_get(visit["snapshot"])
+    snapshot_sizes = archive_data.snapshot_count_branches(snapshot["id"])
     head_rev_id = archive_data.snapshot_get_head(snapshot)
     head_rev = archive_data.revision_get(head_rev_id)
     root_dir_sha1 = head_rev["directory"]
     dir_content = archive_data.directory_ls(root_dir_sha1)
-    branches, releases = process_snapshot_branches(snapshot)
-    visit_unix_ts = parse_timestamp(visit["date"]).timestamp()
-    visit_unix_ts = int(visit_unix_ts)
+    branches, releases, _ = process_snapshot_branches(snapshot)
 
     _origin_directory_view_test_helper(
         client,
         archive_data,
         origin,
         visit,
+        snapshot_sizes,
         branches,
         releases,
         root_dir_sha1,
@@ -202,6 +185,7 @@ def test_origin_root_directory_view(client, archive_data, origin):
         archive_data,
         origin,
         visit,
+        snapshot_sizes,
         branches,
         releases,
         root_dir_sha1,
@@ -214,18 +198,7 @@ def test_origin_root_directory_view(client, archive_data, origin):
         archive_data,
         origin,
         visit,
-        branches,
-        releases,
-        root_dir_sha1,
-        dir_content,
-        timestamp=visit_unix_ts,
-    )
-
-    _origin_directory_view_test_helper(
-        client,
-        archive_data,
-        origin,
-        visit,
+        snapshot_sizes,
         branches,
         releases,
         root_dir_sha1,
@@ -238,6 +211,7 @@ def test_origin_root_directory_view(client, archive_data, origin):
         archive_data,
         origin,
         visit,
+        snapshot_sizes,
         branches,
         releases,
         root_dir_sha1,
@@ -250,6 +224,7 @@ def test_origin_root_directory_view(client, archive_data, origin):
         archive_data,
         origin,
         visit,
+        snapshot_sizes,
         branches,
         releases,
         root_dir_sha1,
@@ -261,6 +236,7 @@ def test_origin_root_directory_view(client, archive_data, origin):
         archive_data,
         origin,
         visit,
+        snapshot_sizes,
         branches,
         releases,
         root_dir_sha1,
@@ -273,18 +249,7 @@ def test_origin_root_directory_view(client, archive_data, origin):
         archive_data,
         origin,
         visit,
-        branches,
-        releases,
-        root_dir_sha1,
-        dir_content,
-        timestamp=visit_unix_ts,
-    )
-
-    _origin_directory_view_test_helper(
-        client,
-        archive_data,
-        origin,
-        visit,
+        snapshot_sizes,
         branches,
         releases,
         root_dir_sha1,
@@ -297,6 +262,7 @@ def test_origin_root_directory_view(client, archive_data, origin):
         archive_data,
         origin,
         visit,
+        snapshot_sizes,
         branches,
         releases,
         root_dir_sha1,
@@ -311,15 +277,14 @@ def test_origin_sub_directory_view(client, archive_data, origin):
 
     visit = origin_visits[-1]
     snapshot = archive_data.snapshot_get(visit["snapshot"])
+    snapshot_sizes = archive_data.snapshot_count_branches(snapshot["id"])
     head_rev_id = archive_data.snapshot_get_head(snapshot)
     head_rev = archive_data.revision_get(head_rev_id)
     root_dir_sha1 = head_rev["directory"]
     subdirs = [
         e for e in archive_data.directory_ls(root_dir_sha1) if e["type"] == "dir"
     ]
-    branches, releases = process_snapshot_branches(snapshot)
-    visit_unix_ts = parse_timestamp(visit["date"]).timestamp()
-    visit_unix_ts = int(visit_unix_ts)
+    branches, releases, _ = process_snapshot_branches(snapshot)
 
     if len(subdirs) == 0:
         return
@@ -333,6 +298,7 @@ def test_origin_sub_directory_view(client, archive_data, origin):
         archive_data,
         origin,
         visit,
+        snapshot_sizes,
         branches,
         releases,
         root_dir_sha1,
@@ -345,6 +311,7 @@ def test_origin_sub_directory_view(client, archive_data, origin):
         archive_data,
         origin,
         visit,
+        snapshot_sizes,
         branches,
         releases,
         root_dir_sha1,
@@ -358,19 +325,7 @@ def test_origin_sub_directory_view(client, archive_data, origin):
         archive_data,
         origin,
         visit,
-        branches,
-        releases,
-        root_dir_sha1,
-        subdir_content,
-        path=subdir_path,
-        timestamp=visit_unix_ts,
-    )
-
-    _origin_directory_view_test_helper(
-        client,
-        archive_data,
-        origin,
-        visit,
+        snapshot_sizes,
         branches,
         releases,
         root_dir_sha1,
@@ -384,6 +339,7 @@ def test_origin_sub_directory_view(client, archive_data, origin):
         archive_data,
         origin,
         visit,
+        snapshot_sizes,
         branches,
         releases,
         root_dir_sha1,
@@ -397,6 +353,7 @@ def test_origin_sub_directory_view(client, archive_data, origin):
         archive_data,
         origin,
         visit,
+        snapshot_sizes,
         branches,
         releases,
         root_dir_sha1,
@@ -409,6 +366,7 @@ def test_origin_sub_directory_view(client, archive_data, origin):
         archive_data,
         origin,
         visit,
+        snapshot_sizes,
         branches,
         releases,
         root_dir_sha1,
@@ -422,19 +380,7 @@ def test_origin_sub_directory_view(client, archive_data, origin):
         archive_data,
         origin,
         visit,
-        branches,
-        releases,
-        root_dir_sha1,
-        subdir_content,
-        path=subdir_path,
-        timestamp=visit_unix_ts,
-    )
-
-    _origin_directory_view_test_helper(
-        client,
-        archive_data,
-        origin,
-        visit,
+        snapshot_sizes,
         branches,
         releases,
         root_dir_sha1,
@@ -448,6 +394,7 @@ def test_origin_sub_directory_view(client, archive_data, origin):
         archive_data,
         origin,
         visit,
+        snapshot_sizes,
         branches,
         releases,
         root_dir_sha1,
@@ -463,12 +410,13 @@ def test_origin_branches(client, archive_data, origin):
 
     visit = origin_visits[-1]
     snapshot = archive_data.snapshot_get(visit["snapshot"])
+    snapshot_sizes = archive_data.snapshot_count_branches(snapshot["id"])
     snapshot_content = process_snapshot_branches(snapshot)
 
-    _origin_branches_test_helper(client, origin, snapshot_content)
+    _origin_branches_test_helper(client, origin, snapshot_content, snapshot_sizes)
 
     _origin_branches_test_helper(
-        client, origin, snapshot_content, snapshot_id=visit["snapshot"]
+        client, origin, snapshot_content, snapshot_sizes, snapshot_id=visit["snapshot"]
     )
 
 
@@ -478,12 +426,13 @@ def test_origin_releases(client, archive_data, origin):
 
     visit = origin_visits[-1]
     snapshot = archive_data.snapshot_get(visit["snapshot"])
+    snapshot_sizes = archive_data.snapshot_count_branches(snapshot["id"])
     snapshot_content = process_snapshot_branches(snapshot)
 
-    _origin_releases_test_helper(client, origin, snapshot_content)
+    _origin_releases_test_helper(client, origin, snapshot_content, snapshot_sizes)
 
     _origin_releases_test_helper(
-        client, origin, snapshot_content, snapshot_id=visit["snapshot"]
+        client, origin, snapshot_content, snapshot_sizes, snapshot_id=visit["snapshot"]
     )
 
 
@@ -523,8 +472,10 @@ def test_origin_snapshot_null_branch(
     url = reverse(
         "browse-origin-directory", query_params={"origin_url": new_origin.url}
     )
-    rv = client.get(url)
-    assert rv.status_code == 200
+
+    check_html_get_response(
+        client, url, status_code=200, template_used="browse/directory.html"
+    )
 
 
 @given(
@@ -561,16 +512,17 @@ def test_origin_snapshot_invalid_branch(
         "browse-origin-directory",
         query_params={"origin_url": new_origin.url, "branch": "invalid_branch"},
     )
-    rv = client.get(url)
-    assert rv.status_code == 404
+
+    check_html_get_response(client, url, status_code=404, template_used="error.html")
 
 
 @given(new_origin())
 def test_browse_visits_origin_not_found(client, new_origin):
     url = reverse("browse-origin-visits", query_params={"origin_url": new_origin.url})
-    resp = client.get(url)
-    assert resp.status_code == 404
-    assert_template_used(resp, "error.html")
+
+    resp = check_html_get_response(
+        client, url, status_code=404, template_used="error.html"
+    )
     assert_contains(
         resp, f"Origin with url {new_origin.url} not found", status_code=404
     )
@@ -582,12 +534,15 @@ def test_browse_origin_directory_no_visit(client, mocker, origin):
         "swh.web.common.origin_visits.get_origin_visits"
     )
     mock_get_origin_visits.return_value = []
+    mock_archive = mocker.patch("swh.web.common.origin_visits.archive")
+    mock_archive.lookup_origin_visit_latest.return_value = None
     url = reverse("browse-origin-directory", query_params={"origin_url": origin["url"]})
-    resp = client.get(url)
-    assert resp.status_code == 404
-    assert_template_used(resp, "error.html")
-    assert_contains(resp, "No visit", status_code=404)
-    assert mock_get_origin_visits.called
+
+    resp = check_html_get_response(
+        client, url, status_code=404, template_used="error.html"
+    )
+    assert_contains(resp, "No valid visit", status_code=404)
+    assert not mock_get_origin_visits.called
 
 
 @given(origin())
@@ -601,9 +556,10 @@ def test_browse_origin_directory_unknown_visit(client, mocker, origin):
         "browse-origin-directory",
         query_params={"origin_url": origin["url"], "visit_id": 2},
     )
-    resp = client.get(url)
-    assert resp.status_code == 404
-    assert_template_used(resp, "error.html")
+
+    resp = check_html_get_response(
+        client, url, status_code=404, template_used="error.html"
+    )
     assert re.search("Visit.*not found", resp.content.decode("utf-8"))
     assert mock_get_origin_visits.called
 
@@ -614,9 +570,10 @@ def test_browse_origin_directory_not_found(client, origin):
         "browse-origin-directory",
         query_params={"origin_url": origin["url"], "path": "/invalid/dir/path/"},
     )
-    resp = client.get(url)
-    assert resp.status_code == 404
-    assert_template_used(resp, "error.html")
+
+    resp = check_html_get_response(
+        client, url, status_code=404, template_used="error.html"
+    )
     assert re.search("Directory.*not found", resp.content.decode("utf-8"))
 
 
@@ -626,15 +583,18 @@ def test_browse_origin_content_no_visit(client, mocker, origin):
         "swh.web.common.origin_visits.get_origin_visits"
     )
     mock_get_origin_visits.return_value = []
+    mock_archive = mocker.patch("swh.web.common.origin_visits.archive")
+    mock_archive.lookup_origin_visit_latest.return_value = None
     url = reverse(
         "browse-origin-content",
         query_params={"origin_url": origin["url"], "path": "foo"},
     )
-    resp = client.get(url)
-    assert resp.status_code == 404
-    assert_template_used(resp, "error.html")
-    assert_contains(resp, "No visit", status_code=404)
-    assert mock_get_origin_visits.called
+
+    resp = check_html_get_response(
+        client, url, status_code=404, template_used="error.html"
+    )
+    assert_contains(resp, "No valid visit", status_code=404)
+    assert not mock_get_origin_visits.called
 
 
 @given(origin())
@@ -648,39 +608,41 @@ def test_browse_origin_content_unknown_visit(client, mocker, origin):
         "browse-origin-content",
         query_params={"origin_url": origin["url"], "path": "foo", "visit_id": 2},
     )
-    resp = client.get(url)
-    assert resp.status_code == 404
-    assert_template_used(resp, "error.html")
+
+    resp = check_html_get_response(
+        client, url, status_code=404, template_used="error.html"
+    )
     assert re.search("Visit.*not found", resp.content.decode("utf-8"))
     assert mock_get_origin_visits.called
 
 
 @given(origin())
 def test_browse_origin_content_directory_empty_snapshot(client, mocker, origin):
-    mock_snapshot_service = mocker.patch("swh.web.browse.snapshot_context.service")
+    mock_snapshot_archive = mocker.patch("swh.web.browse.snapshot_context.archive")
     mock_get_origin_visit_snapshot = mocker.patch(
         "swh.web.browse.snapshot_context.get_origin_visit_snapshot"
     )
-    mock_get_origin_visit_snapshot.return_value = ([], [])
-    mock_snapshot_service.lookup_origin.return_value = origin
-    mock_snapshot_service.lookup_snapshot_sizes.return_value = {
+    mock_get_origin_visit_snapshot.return_value = ([], [], {})
+    mock_snapshot_archive.lookup_origin.return_value = origin
+    mock_snapshot_archive.lookup_snapshot_sizes.return_value = {
+        "alias": 0,
         "revision": 0,
         "release": 0,
     }
 
     for browse_context in ("content", "directory"):
-
         url = reverse(
             f"browse-origin-{browse_context}",
             query_params={"origin_url": origin["url"], "path": "baz"},
         )
-        resp = client.get(url)
-        assert resp.status_code == 200
-        assert_template_used(resp, f"browse/{browse_context}.html")
+
+        resp = check_html_get_response(
+            client, url, status_code=200, template_used=f"browse/{browse_context}.html"
+        )
         assert re.search("snapshot.*is empty", resp.content.decode("utf-8"))
         assert mock_get_origin_visit_snapshot.called
-        assert mock_snapshot_service.lookup_origin.called
-        assert mock_snapshot_service.lookup_snapshot_sizes.called
+        assert mock_snapshot_archive.lookup_origin.called
+        assert mock_snapshot_archive.lookup_snapshot_sizes.called
 
 
 @given(origin())
@@ -689,9 +651,10 @@ def test_browse_origin_content_not_found(client, origin):
         "browse-origin-content",
         query_params={"origin_url": origin["url"], "path": "/invalid/file/path"},
     )
-    resp = client.get(url)
-    assert resp.status_code == 404
-    assert_template_used(resp, "error.html")
+
+    resp = check_html_get_response(
+        client, url, status_code=404, template_used="error.html"
+    )
     assert re.search("Directory entry.*not found", resp.content.decode("utf-8"))
 
 
@@ -702,34 +665,37 @@ def test_browse_directory_snapshot_not_found(client, mocker, origin):
     )
     mock_get_snapshot_context.side_effect = NotFoundExc("Snapshot not found")
     url = reverse("browse-origin-directory", query_params={"origin_url": origin["url"]})
-    resp = client.get(url)
-    assert resp.status_code == 404
-    assert_template_used(resp, "error.html")
+
+    resp = check_html_get_response(
+        client, url, status_code=404, template_used="error.html"
+    )
     assert_contains(resp, "Snapshot not found", status_code=404)
     assert mock_get_snapshot_context.called
 
 
 @given(origin())
 def test_origin_empty_snapshot(client, mocker, origin):
-    mock_service = mocker.patch("swh.web.browse.snapshot_context.service")
+    mock_archive = mocker.patch("swh.web.browse.snapshot_context.archive")
     mock_get_origin_visit_snapshot = mocker.patch(
         "swh.web.browse.snapshot_context.get_origin_visit_snapshot"
     )
-    mock_get_origin_visit_snapshot.return_value = ([], [])
-    mock_service.lookup_snapshot_sizes.return_value = {
+    mock_get_origin_visit_snapshot.return_value = ([], [], {})
+    mock_archive.lookup_snapshot_sizes.return_value = {
+        "alias": 0,
         "revision": 0,
         "release": 0,
     }
-    mock_service.lookup_origin.return_value = origin
+    mock_archive.lookup_origin.return_value = origin
     url = reverse("browse-origin-directory", query_params={"origin_url": origin["url"]})
-    resp = client.get(url)
-    assert resp.status_code == 200
-    assert_template_used(resp, "browse/directory.html")
+
+    resp = check_html_get_response(
+        client, url, status_code=200, template_used="browse/directory.html"
+    )
     resp_content = resp.content.decode("utf-8")
     assert re.search("snapshot.*is empty", resp_content)
     assert not re.search("swh-tr-link", resp_content)
     assert mock_get_origin_visit_snapshot.called
-    assert mock_service.lookup_snapshot_sizes.called
+    assert mock_archive.lookup_snapshot_sizes.called
 
 
 @given(new_origin())
@@ -759,9 +725,10 @@ def test_origin_empty_snapshot_null_revision(client, archive_data, new_origin):
     url = reverse(
         "browse-origin-directory", query_params={"origin_url": new_origin.url},
     )
-    resp = client.get(url)
-    assert resp.status_code == 200
-    assert_template_used(resp, "browse/directory.html")
+
+    resp = check_html_get_response(
+        client, url, status_code=200, template_used="browse/directory.html"
+    )
     resp_content = resp.content.decode("utf-8")
     assert re.search("snapshot.*is empty", resp_content)
     assert not re.search("swh-tr-link", resp_content)
@@ -780,22 +747,22 @@ def test_origin_release_browse(client, archive_data, origin):
         query_params={"origin_url": origin["url"], "release": release_data["name"]},
     )
 
-    resp = client.get(url)
-    assert resp.status_code == 200
+    resp = check_html_get_response(
+        client, url, status_code=200, template_used="browse/directory.html"
+    )
     assert_contains(resp, release_data["name"])
     assert_contains(resp, release["target"])
 
     swhid_context = {
         "origin": origin["url"],
-        "visit": get_swh_persistent_id(SNAPSHOT, snapshot["id"]),
-        "anchor": get_swh_persistent_id(RELEASE, release_data["id"]),
-        "path": "/",
+        "visit": gen_swhid(SNAPSHOT, snapshot["id"]),
+        "anchor": gen_swhid(RELEASE, release_data["id"]),
     }
 
-    swh_dir_id = get_swh_persistent_id(
+    swh_dir_id = gen_swhid(
         DIRECTORY, revision_data["directory"], metadata=swhid_context
     )
-    swh_dir_id_url = reverse("browse-swh-id", url_args={"swh_id": swh_dir_id})
+    swh_dir_id_url = reverse("browse-swhid", url_args={"swhid": swh_dir_id})
     assert_contains(resp, swh_dir_id)
     assert_contains(resp, swh_dir_id_url)
 
@@ -809,8 +776,9 @@ def test_origin_release_browse_not_found(client, origin):
         query_params={"origin_url": origin["url"], "release": invalid_release_name},
     )
 
-    resp = client.get(url)
-    assert resp.status_code == 404
+    resp = check_html_get_response(
+        client, url, status_code=404, template_used="error.html"
+    )
     assert re.search(
         f"Release {invalid_release_name}.*not found", resp.content.decode("utf-8")
     )
@@ -847,9 +815,9 @@ def test_origin_browse_directory_branch_with_non_resolvable_revision(
         query_params={"origin_url": new_origin.url, "branch": branch_name},
     )
 
-    resp = client.get(url)
-
-    assert resp.status_code == 200
+    resp = check_html_get_response(
+        client, url, status_code=200, template_used="browse/directory.html"
+    )
     assert_contains(
         resp, f"Revision {unknown_revision } could not be found in the archive."
     )
@@ -859,9 +827,9 @@ def test_origin_browse_directory_branch_with_non_resolvable_revision(
 def test_origin_content_no_path(client, origin):
     url = reverse("browse-origin-content", query_params={"origin_url": origin["url"]})
 
-    resp = client.get(url)
-
-    assert resp.status_code == 400
+    resp = check_html_get_response(
+        client, url, status_code=400, template_used="error.html"
+    )
     assert_contains(
         resp, "The path of a content must be given as query parameter.", status_code=400
     )
@@ -877,8 +845,10 @@ def test_origin_views_no_url_query_parameter(client):
         "visits",
     ):
         url = reverse(f"browse-origin-{browse_context}")
-        resp = client.get(url)
-        assert resp.status_code == 400
+
+        resp = check_html_get_response(
+            client, url, status_code=400, template_used="error.html"
+        )
         assert_contains(
             resp, "An origin URL must be provided as query parameter.", status_code=400
         )
@@ -889,6 +859,7 @@ def _origin_content_view_test_helper(
     archive_data,
     origin_info,
     origin_visit,
+    snapshot_sizes,
     origin_branches,
     origin_releases,
     root_dir_sha1,
@@ -914,10 +885,9 @@ def _origin_content_view_test_helper(
 
     url = reverse("browse-origin-content", query_params=query_params)
 
-    resp = client.get(url)
-
-    assert resp.status_code == 200
-    assert_template_used(resp, "browse/content.html")
+    resp = check_html_get_response(
+        client, url, status_code=200, template_used="browse/content.html"
+    )
 
     assert type(content["data"]) == str
 
@@ -935,7 +905,7 @@ def _origin_content_view_test_helper(
 
     if timestamp:
         query_params["timestamp"] = format_utc_iso_date(
-            parse_timestamp(timestamp).isoformat(), "%Y-%m-%dT%H:%M:%SZ"
+            parse_iso8601_date_to_utc(timestamp).isoformat(), "%Y-%m-%dT%H:%M:%SZ"
         )
 
     root_dir_url = reverse("browse-origin-directory", query_params=query_params)
@@ -966,12 +936,12 @@ def _origin_content_view_test_helper(
     origin_branches_url = reverse("browse-origin-branches", query_params=query_params)
 
     assert_contains(resp, f'href="{escape(origin_branches_url)}"')
-    assert_contains(resp, f"Branches ({len(origin_branches)})")
+    assert_contains(resp, f"Branches ({snapshot_sizes['revision']})")
 
     origin_releases_url = reverse("browse-origin-releases", query_params=query_params)
 
     assert_contains(resp, f'href="{escape(origin_releases_url)}">')
-    assert_contains(resp, f"Releases ({len(origin_releases)})")
+    assert_contains(resp, f"Releases ({snapshot_sizes['release']})")
 
     assert_contains(resp, '<li class="swh-branch">', count=len(origin_branches))
 
@@ -998,24 +968,22 @@ def _origin_content_view_test_helper(
 
     url = reverse("browse-origin-content", query_params=query_params)
 
-    resp = client.get(url)
-    assert resp.status_code == 200
-    assert_template_used(resp, "browse/content.html")
+    resp = check_html_get_response(
+        client, url, status_code=200, template_used="browse/content.html"
+    )
 
     snapshot = archive_data.snapshot_get(origin_visit["snapshot"])
     head_rev_id = archive_data.snapshot_get_head(snapshot)
 
     swhid_context = {
         "origin": origin_info["url"],
-        "visit": get_swh_persistent_id(SNAPSHOT, snapshot["id"]),
-        "anchor": get_swh_persistent_id(REVISION, head_rev_id),
+        "visit": gen_swhid(SNAPSHOT, snapshot["id"]),
+        "anchor": gen_swhid(REVISION, head_rev_id),
         "path": f"/{content_path}",
     }
 
-    swh_cnt_id = get_swh_persistent_id(
-        CONTENT, content["sha1_git"], metadata=swhid_context
-    )
-    swh_cnt_id_url = reverse("browse-swh-id", url_args={"swh_id": swh_cnt_id})
+    swh_cnt_id = gen_swhid(CONTENT, content["sha1_git"], metadata=swhid_context)
+    swh_cnt_id_url = reverse("browse-swhid", url_args={"swhid": swh_cnt_id})
     assert_contains(resp, swh_cnt_id)
     assert_contains(resp, swh_cnt_id_url)
 
@@ -1029,6 +997,7 @@ def _origin_directory_view_test_helper(
     archive_data,
     origin_info,
     origin_visit,
+    snapshot_sizes,
     origin_branches,
     origin_releases,
     root_directory_sha1,
@@ -1058,20 +1027,15 @@ def _origin_directory_view_test_helper(
 
     url = reverse("browse-origin-directory", query_params=query_params)
 
-    resp = client.get(url)
-
-    assert resp.status_code == 200
-    assert_template_used(resp, "browse/directory.html")
-
-    assert resp.status_code == 200
-    assert_template_used(resp, "browse/directory.html")
-
+    resp = check_html_get_response(
+        client, url, status_code=200, template_used="browse/directory.html"
+    )
     assert_contains(resp, '<td class="swh-directory">', count=len(dirs))
     assert_contains(resp, '<td class="swh-content">', count=len(files))
 
     if timestamp:
         query_params["timestamp"] = format_utc_iso_date(
-            parse_timestamp(timestamp).isoformat(), "%Y-%m-%dT%H:%M:%SZ"
+            parse_iso8601_date_to_utc(timestamp).isoformat(), "%Y-%m-%dT%H:%M:%SZ"
         )
 
     for d in dirs:
@@ -1110,14 +1074,14 @@ def _origin_directory_view_test_helper(
     origin_branches_url = reverse("browse-origin-branches", query_params=query_params)
 
     assert_contains(resp, f'href="{escape(origin_branches_url)}"')
-    assert_contains(resp, f"Branches ({len(origin_branches)})")
+    assert_contains(resp, f"Branches ({snapshot_sizes['revision']})")
 
     origin_releases_url = reverse("browse-origin-releases", query_params=query_params)
 
     nb_releases = len(origin_releases)
     if nb_releases > 0:
         assert_contains(resp, f'href="{escape(origin_releases_url)}"')
-        assert_contains(resp, f"Releases ({nb_releases})")
+        assert_contains(resp, f"Releases ({snapshot_sizes['release']})")
 
     if path:
         query_params["path"] = path
@@ -1151,15 +1115,15 @@ def _origin_directory_view_test_helper(
 
     swhid_context = {
         "origin": origin_info["url"],
-        "visit": get_swh_persistent_id(SNAPSHOT, snapshot["id"]),
-        "anchor": get_swh_persistent_id(REVISION, head_rev_id),
-        "path": f"/{path}" if path else "/",
+        "visit": gen_swhid(SNAPSHOT, snapshot["id"]),
+        "anchor": gen_swhid(REVISION, head_rev_id),
+        "path": f"/{path}" if path else None,
     }
 
-    swh_dir_id = get_swh_persistent_id(
+    swh_dir_id = gen_swhid(
         DIRECTORY, directory_entries[0]["dir_id"], metadata=swhid_context
     )
-    swh_dir_id_url = reverse("browse-swh-id", url_args={"swh_id": swh_dir_id})
+    swh_dir_id_url = reverse("browse-swhid", url_args={"swhid": swh_dir_id})
     assert_contains(resp, swh_dir_id)
     assert_contains(resp, swh_dir_id_url)
 
@@ -1169,16 +1133,15 @@ def _origin_directory_view_test_helper(
 
 
 def _origin_branches_test_helper(
-    client, origin_info, origin_snapshot, snapshot_id=None
+    client, origin_info, origin_snapshot, snapshot_sizes, snapshot_id=None
 ):
     query_params = {"origin_url": origin_info["url"], "snapshot": snapshot_id}
 
     url = reverse("browse-origin-branches", query_params=query_params)
 
-    resp = client.get(url)
-
-    assert resp.status_code == 200
-    assert_template_used(resp, "browse/branches.html")
+    resp = check_html_get_response(
+        client, url, status_code=200, template_used="browse/branches.html"
+    )
 
     origin_branches = origin_snapshot[0]
     origin_releases = origin_snapshot[1]
@@ -1186,14 +1149,14 @@ def _origin_branches_test_helper(
     origin_branches_url = reverse("browse-origin-branches", query_params=query_params)
 
     assert_contains(resp, f'href="{escape(origin_branches_url)}"')
-    assert_contains(resp, f"Branches ({len(origin_branches)})")
+    assert_contains(resp, f"Branches ({snapshot_sizes['revision']})")
 
     origin_releases_url = reverse("browse-origin-releases", query_params=query_params)
 
     nb_releases = len(origin_releases)
     if nb_releases > 0:
         assert_contains(resp, f'href="{escape(origin_releases_url)}">')
-        assert_contains(resp, f"Releases ({nb_releases})")
+        assert_contains(resp, f"Releases ({snapshot_sizes['release']})")
 
     assert_contains(resp, '<tr class="swh-branch-entry', count=len(origin_branches))
 
@@ -1215,30 +1178,29 @@ def _origin_branches_test_helper(
 
 
 def _origin_releases_test_helper(
-    client, origin_info, origin_snapshot, snapshot_id=None
+    client, origin_info, origin_snapshot, snapshot_sizes, snapshot_id=None
 ):
     query_params = {"origin_url": origin_info["url"], "snapshot": snapshot_id}
 
     url = reverse("browse-origin-releases", query_params=query_params)
 
-    resp = client.get(url)
-    assert resp.status_code == 200
-    assert_template_used(resp, "browse/releases.html")
+    resp = check_html_get_response(
+        client, url, status_code=200, template_used="browse/releases.html"
+    )
 
-    origin_branches = origin_snapshot[0]
     origin_releases = origin_snapshot[1]
 
     origin_branches_url = reverse("browse-origin-branches", query_params=query_params)
 
     assert_contains(resp, f'href="{escape(origin_branches_url)}"')
-    assert_contains(resp, f"Branches ({len(origin_branches)})")
+    assert_contains(resp, f"Branches ({snapshot_sizes['revision']})")
 
     origin_releases_url = reverse("browse-origin-releases", query_params=query_params)
 
     nb_releases = len(origin_releases)
     if nb_releases > 0:
         assert_contains(resp, f'href="{escape(origin_releases_url)}"')
-        assert_contains(resp, f"Releases ({nb_releases})")
+        assert_contains(resp, f"Releases ({snapshot_sizes['release']}")
 
     assert_contains(resp, '<tr class="swh-release-entry', count=nb_releases)
 
@@ -1302,9 +1264,10 @@ def test_origin_branches_pagination_with_alias(
     archive_data.origin_visit_status_add([visit_status])
 
     url = reverse("browse-origin-branches", query_params={"origin_url": new_origin.url})
-    resp = client.get(url)
-    assert resp.status_code == 200
-    assert_template_used(resp, "browse/branches.html")
+
+    resp = check_html_get_response(
+        client, url, status_code=200, template_used="browse/branches.html"
+    )
     assert_contains(resp, '<ul class="pagination')
 
 
