@@ -5,14 +5,16 @@
 
 import random
 
-from django.utils.html import escape
 from hypothesis import given
 
+from django.utils.html import escape
+
 from swh.model.identifiers import DIRECTORY, REVISION, SNAPSHOT
-from swh.web.common.identifiers import get_swh_persistent_id
-from swh.web.common.utils import reverse, format_utc_iso_date, parse_timestamp
-from swh.web.tests.django_asserts import assert_contains, assert_template_used
-from swh.web.tests.strategies import origin, revision, unknown_revision, new_origin
+from swh.web.common.identifiers import gen_swhid
+from swh.web.common.utils import format_utc_iso_date, parse_iso8601_date_to_utc, reverse
+from swh.web.tests.django_asserts import assert_contains
+from swh.web.tests.strategies import new_origin, origin, revision, unknown_revision
+from swh.web.tests.utils import check_html_get_response
 
 
 @given(revision())
@@ -43,7 +45,7 @@ def test_revision_log_browse(client, archive_data, revision):
 
     revision_log_sorted = sorted(
         revision_log,
-        key=lambda rev: -parse_timestamp(rev["committer_date"]).timestamp(),
+        key=lambda rev: -parse_iso8601_date_to_utc(rev["committer_date"]).timestamp(),
     )
 
     url = reverse(
@@ -52,20 +54,19 @@ def test_revision_log_browse(client, archive_data, revision):
         query_params={"per_page": per_page},
     )
 
-    resp = client.get(url)
-
     next_page_url = reverse(
         "browse-revision-log",
         url_args={"sha1_git": revision},
-        query_params={"offset": per_page, "per_page": per_page},
+        query_params={"offset": per_page, "per_page": per_page,},
     )
 
     nb_log_entries = per_page
     if len(revision_log_sorted) < per_page:
         nb_log_entries = len(revision_log_sorted)
 
-    assert resp.status_code == 200
-    assert_template_used(resp, "browse/revision-log.html")
+    resp = check_html_get_response(
+        client, url, status_code=200, template_used="browse/revision-log.html"
+    )
     assert_contains(resp, '<tr class="swh-revision-log-entry', count=nb_log_entries)
     assert_contains(resp, '<a class="page-link">Newer</a>')
 
@@ -86,12 +87,14 @@ def test_revision_log_browse(client, archive_data, revision):
     if len(revision_log_sorted) <= per_page:
         return
 
-    resp = client.get(next_page_url)
+    resp = check_html_get_response(
+        client, next_page_url, status_code=200, template_used="browse/revision-log.html"
+    )
 
     prev_page_url = reverse(
         "browse-revision-log",
         url_args={"sha1_git": revision},
-        query_params={"per_page": per_page},
+        query_params={"offset": 0, "per_page": per_page},
     )
     next_page_url = reverse(
         "browse-revision-log",
@@ -103,8 +106,6 @@ def test_revision_log_browse(client, archive_data, revision):
     if nb_log_entries > per_page:
         nb_log_entries = per_page
 
-    assert resp.status_code == 200
-    assert_template_used(resp, "browse/revision-log.html")
     assert_contains(resp, '<tr class="swh-revision-log-entry', count=nb_log_entries)
 
     assert_contains(
@@ -119,7 +120,9 @@ def test_revision_log_browse(client, archive_data, revision):
     if len(revision_log_sorted) <= 2 * per_page:
         return
 
-    resp = client.get(next_page_url)
+    resp = check_html_get_response(
+        client, next_page_url, status_code=200, template_used="browse/revision-log.html"
+    )
 
     prev_page_url = reverse(
         "browse-revision-log",
@@ -136,8 +139,6 @@ def test_revision_log_browse(client, archive_data, revision):
     if nb_log_entries > per_page:
         nb_log_entries = per_page
 
-    assert resp.status_code == 200
-    assert_template_used(resp, "browse/revision-log.html")
     assert_contains(resp, '<tr class="swh-revision-log-entry', count=nb_log_entries)
     assert_contains(
         resp, '<a class="page-link" href="%s">Newer</a>' % escape(prev_page_url)
@@ -152,9 +153,10 @@ def test_revision_log_browse(client, archive_data, revision):
 @given(revision(), unknown_revision(), new_origin())
 def test_revision_request_errors(client, revision, unknown_revision, new_origin):
     url = reverse("browse-revision", url_args={"sha1_git": unknown_revision})
-    resp = client.get(url)
-    assert resp.status_code == 404
-    assert_template_used(resp, "error.html")
+
+    resp = check_html_get_response(
+        client, url, status_code=404, template_used="error.html"
+    )
     assert_contains(
         resp, "Revision with sha1_git %s not found" % unknown_revision, status_code=404
     )
@@ -165,9 +167,9 @@ def test_revision_request_errors(client, revision, unknown_revision, new_origin)
         query_params={"origin_url": new_origin.url},
     )
 
-    resp = client.get(url)
-    assert resp.status_code == 404
-    assert_template_used(resp, "error.html")
+    resp = check_html_get_response(
+        client, url, status_code=404, template_used="error.html"
+    )
     assert_contains(
         resp, "the origin mentioned in your request" " appears broken", status_code=404
     )
@@ -179,8 +181,7 @@ def test_revision_uppercase(client, revision):
         "browse-revision-uppercase-checksum", url_args={"sha1_git": revision.upper()}
     )
 
-    resp = client.get(url)
-    assert resp.status_code == 302
+    resp = check_html_get_response(client, url, status_code=302)
 
     redirect_url = reverse("browse-revision", url_args={"sha1_git": revision})
 
@@ -221,10 +222,9 @@ def _revision_browse_checks(
     else:
         history_url = reverse("browse-revision-log", url_args={"sha1_git": revision})
 
-    resp = client.get(url)
-
-    assert resp.status_code == 200
-    assert_template_used(resp, "browse/revision.html")
+    resp = check_html_get_response(
+        client, url, status_code=200, template_used="browse/revision.html"
+    )
     assert_contains(resp, author_name)
     assert_contains(resp, committer_name)
     assert_contains(resp, history_url)
@@ -248,21 +248,21 @@ def _revision_browse_checks(
     assert_contains(resp, "vault-cook-directory")
     assert_contains(resp, "vault-cook-revision")
 
-    swh_rev_id = get_swh_persistent_id("revision", revision)
-    swh_rev_id_url = reverse("browse-swh-id", url_args={"swh_id": swh_rev_id})
+    swh_rev_id = gen_swhid("revision", revision)
+    swh_rev_id_url = reverse("browse-swhid", url_args={"swhid": swh_rev_id})
     assert_contains(resp, swh_rev_id)
     assert_contains(resp, swh_rev_id_url)
 
-    swh_dir_id = get_swh_persistent_id("directory", dir_id)
-    swh_dir_id_url = reverse("browse-swh-id", url_args={"swh_id": swh_dir_id})
+    swh_dir_id = gen_swhid("directory", dir_id)
+    swh_dir_id_url = reverse("browse-swhid", url_args={"swhid": swh_dir_id})
     assert_contains(resp, swh_dir_id)
     assert_contains(resp, swh_dir_id_url)
 
     if origin_url:
         assert_contains(resp, "swh-take-new-snapshot")
 
-    swh_rev_id = get_swh_persistent_id(REVISION, revision)
-    swh_rev_id_url = reverse("browse-swh-id", url_args={"swh_id": swh_rev_id})
+    swh_rev_id = gen_swhid(REVISION, revision)
+    swh_rev_id_url = reverse("browse-swhid", url_args={"swhid": swh_rev_id})
 
     if origin_url:
         browse_origin_url = reverse(
@@ -270,25 +270,24 @@ def _revision_browse_checks(
         )
         assert_contains(resp, f'href="{browse_origin_url}"')
     elif snapshot:
-        swh_snp_id = get_swh_persistent_id("snapshot", snapshot["id"])
-        swh_snp_id_url = reverse("browse-swh-id", url_args={"swh_id": swh_snp_id})
+        swh_snp_id = gen_swhid("snapshot", snapshot["id"])
+        swh_snp_id_url = reverse("browse-swhid", url_args={"swhid": swh_snp_id})
         assert_contains(resp, f'href="{swh_snp_id_url}"')
 
     swhid_context = {}
     if origin_url:
         swhid_context["origin"] = origin_url
     if snapshot:
-        swhid_context["visit"] = get_swh_persistent_id(SNAPSHOT, snapshot["id"])
+        swhid_context["visit"] = gen_swhid(SNAPSHOT, snapshot["id"])
 
-    swh_rev_id = get_swh_persistent_id(REVISION, revision, metadata=swhid_context)
-    swh_rev_id_url = reverse("browse-swh-id", url_args={"swh_id": swh_rev_id})
+    swh_rev_id = gen_swhid(REVISION, revision, metadata=swhid_context)
+    swh_rev_id_url = reverse("browse-swhid", url_args={"swhid": swh_rev_id})
     assert_contains(resp, swh_rev_id)
     assert_contains(resp, swh_rev_id_url)
 
-    swhid_context["anchor"] = get_swh_persistent_id(REVISION, revision)
-    swhid_context["path"] = "/"
+    swhid_context["anchor"] = gen_swhid(REVISION, revision)
 
-    swh_dir_id = get_swh_persistent_id(DIRECTORY, dir_id, metadata=swhid_context)
-    swh_dir_id_url = reverse("browse-swh-id", url_args={"swh_id": swh_dir_id})
+    swh_dir_id = gen_swhid(DIRECTORY, dir_id, metadata=swhid_context)
+    swh_dir_id_url = reverse("browse-swhid", url_args={"swhid": swh_dir_id})
     assert_contains(resp, swh_dir_id)
     assert_contains(resp, swh_dir_id_url)
