@@ -3,25 +3,28 @@
 # License: GNU Affero General Public License version 3, or any later version
 # See top-level LICENSE file for more information
 
-import re
-
 from datetime import datetime, timedelta, timezone
 from functools import partial
+import re
 
 import pytest
 import requests
 
 from swh.core.pytest_plugin import get_response_cb
-
-from swh.web.common.models import SaveOriginRequest
+from swh.web.common.models import (
+    SAVE_REQUEST_ACCEPTED,
+    SAVE_TASK_FAILED,
+    SAVE_TASK_RUNNING,
+    SAVE_TASK_SUCCEEDED,
+    SaveOriginRequest,
+)
 from swh.web.common.origin_save import (
-    get_save_origin_task_info,
     get_save_origin_requests,
+    get_save_origin_task_info,
 )
 from swh.web.common.typing import OriginVisitInfo
 from swh.web.config import get_config
 
-
 _es_url = "http://esnode1.internal.softwareheritage.org:9200"
 _es_workers_index_url = "%s/swh_workers-*" % _es_url
 
@@ -32,9 +35,7 @@ _task_id = 203525448
 
 @pytest.fixture(autouse=True)
 def requests_mock_datadir(datadir, requests_mock_datadir):
-    """Override default behavior to deal with post method
-
-    """
+    """Override default behavior to deal with post method"""
     cb = partial(get_response_cb, datadir=datadir)
     requests_mock_datadir.post(re.compile("https?://"), body=cb)
     return requests_mock_datadir
@@ -60,24 +61,22 @@ def test_get_save_origin_task_info_without_es(mocker):
     _get_save_origin_task_info_test(mocker, es_available=False)
 
 
-def _mock_scheduler(mocker, task_status="succeed", task_archived=False):
+def _mock_scheduler(
+    mocker, task_status="completed", task_run_status="eventful", task_archived=False
+):
     mock_scheduler = mocker.patch("swh.web.common.origin_save.scheduler")
-    task = (
-        {
-            "arguments": {"args": [], "kwargs": {"repo_url": _origin_url},},
-            "current_interval": timedelta(days=64),
-            "id": _task_id,
-            "next_run": datetime.now(tz=timezone.utc) + timedelta(days=64),
-            "policy": "oneshot",
-            "priority": "high",
-            "retries_left": 0,
-            "status": "disabled",
-            "type": "load-git",
-        }
-        if not task_archived
-        else None
-    )
-    mock_scheduler.get_tasks.return_value = [dict(task) if task else None]
+    task = {
+        "arguments": {"args": [], "kwargs": {"repo_url": _origin_url},},
+        "current_interval": timedelta(days=64),
+        "id": _task_id,
+        "next_run": datetime.now(tz=timezone.utc) + timedelta(days=64),
+        "policy": "oneshot",
+        "priority": "high",
+        "retries_left": 0,
+        "status": task_status,
+        "type": "load-git",
+    }
+    mock_scheduler.get_tasks.return_value = [dict(task) if not task_archived else None]
 
     task_run = {
         "backend_id": "f00c712c-e820-41ce-a07c-9bf8df914205",
@@ -86,10 +85,12 @@ def _mock_scheduler(mocker, task_status="succeed", task_archived=False):
         "metadata": {},
         "scheduled": datetime.now(tz=timezone.utc),
         "started": None,
-        "status": task_status,
+        "status": task_run_status,
         "task": _task_id,
     }
-    mock_scheduler.get_task_runs.return_value = [dict(task_run)]
+    mock_scheduler.get_task_runs.return_value = [
+        dict(task_run) if not task_archived else None
+    ]
     return task, task_run
 
 
@@ -107,7 +108,7 @@ def _get_save_origin_task_info_test(
         request_date=datetime.now(tz=timezone.utc),
         visit_type=_visit_type,
         origin_url="https://gitlab.com/inkscape/inkscape",
-        status="accepted",
+        status=SAVE_REQUEST_ACCEPTED,
         visit_date=datetime.now(tz=timezone.utc) + timedelta(hours=1),
         loading_task_id=_task_id,
     )
@@ -168,15 +169,15 @@ def test_get_save_origin_requests_find_visit_date(mocker):
         request_date=datetime.now(tz=timezone.utc),
         visit_type=_visit_type,
         origin_url=_origin_url,
-        status="accepted",
+        status=SAVE_REQUEST_ACCEPTED,
         visit_date=None,
         loading_task_id=_task_id,
     )
 
-    # mock scheduler and services
+    # mock scheduler and archive
     _mock_scheduler(mocker)
-    mock_service = mocker.patch("swh.web.common.origin_save.service")
-    mock_service.lookup_origin.return_value = {"url": _origin_url}
+    mock_archive = mocker.patch("swh.web.common.origin_save.archive")
+    mock_archive.lookup_origin.return_value = {"url": _origin_url}
     mock_get_origin_visits = mocker.patch(
         "swh.web.common.origin_save.get_origin_visits"
     )
@@ -198,6 +199,7 @@ def test_get_save_origin_requests_find_visit_date(mocker):
     # check visit date has been correctly found
     sors = get_save_origin_requests(_visit_type, _origin_url)
     assert len(sors) == 1
+    assert sors[0]["save_task_status"] == SAVE_TASK_SUCCEEDED
     assert sors[0]["visit_date"] == visit_date
     mock_get_origin_visits.assert_called_once()
 
@@ -210,17 +212,62 @@ def test_get_save_origin_requests_find_visit_date(mocker):
     sor = SaveOriginRequest.objects.create(
         visit_type=_visit_type,
         origin_url=_origin_url,
-        status="accepted",
+        status=SAVE_REQUEST_ACCEPTED,
         loading_task_id=_task_id,
         visit_date=None,
     )
     sor.request_date = datetime.now(tz=timezone.utc) - timedelta(days=31)
     sor.save()
 
-    _mock_scheduler(mocker, task_status="failed")
+    _mock_scheduler(mocker, task_status="disabled", task_run_status="failed")
 
     sors = get_save_origin_requests(_visit_type, _origin_url)
 
     assert len(sors) == 2
+    assert sors[0]["save_task_status"] == SAVE_TASK_FAILED
+    assert sors[0]["visit_date"] is None
+    mock_get_origin_visits.assert_called_once()
+
+
+@pytest.mark.django_db
+def test_get_save_origin_requests_no_visit_date_found(mocker):
+    # create a save request
+    SaveOriginRequest.objects.create(
+        request_date=datetime.now(tz=timezone.utc),
+        visit_type=_visit_type,
+        origin_url=_origin_url,
+        status=SAVE_REQUEST_ACCEPTED,
+        visit_date=None,
+        loading_task_id=_task_id,
+    )
+
+    # mock scheduler and archives
+    _mock_scheduler(
+        mocker, task_status="next_run_scheduled", task_run_status="scheduled"
+    )
+    mock_archive = mocker.patch("swh.web.common.origin_save.archive")
+    mock_archive.lookup_origin.return_value = {"url": _origin_url}
+    mock_get_origin_visits = mocker.patch(
+        "swh.web.common.origin_save.get_origin_visits"
+    )
+    # create a visit for the save request with status created
+    visit_date = datetime.now(tz=timezone.utc).isoformat()
+    visit_info = OriginVisitInfo(
+        date=visit_date,
+        formatted_date="",
+        metadata={},
+        origin=_origin_url,
+        snapshot=None,
+        status="created",
+        type=_visit_type,
+        url="",
+        visit=34,
+    )
+    mock_get_origin_visits.return_value = [visit_info]
+
+    # check no visit date has been found
+    sors = get_save_origin_requests(_visit_type, _origin_url)
+    assert len(sors) == 1
+    assert sors[0]["save_task_status"] == SAVE_TASK_RUNNING
     assert sors[0]["visit_date"] is None
     mock_get_origin_visits.assert_called_once()
