@@ -7,34 +7,35 @@ from corsheaders.middleware import ACCESS_CONTROL_ALLOW_ORIGIN
 from hypothesis import given
 
 from swh.model.identifiers import (
-    persistent_identifier,
     CONTENT,
     DIRECTORY,
     ORIGIN,
     RELEASE,
     REVISION,
     SNAPSHOT,
+    swhid,
 )
-from swh.web.common import service
-from swh.web.common.identifiers import resolve_swh_persistent_id
+from swh.web.common import archive
+from swh.web.common.identifiers import resolve_swhid
 from swh.web.common.utils import reverse
 from swh.web.misc.badges import _badge_config, _get_logo_data
 from swh.web.tests.django_asserts import assert_contains
 from swh.web.tests.strategies import (
     content,
     directory,
+    invalid_sha1,
+    new_origin,
     origin,
     release,
     revision,
     snapshot,
     unknown_content,
     unknown_directory,
-    new_origin,
     unknown_release,
     unknown_revision,
     unknown_snapshot,
-    invalid_sha1,
 )
+from swh.web.tests.utils import check_http_get_response
 
 
 @given(content())
@@ -96,13 +97,17 @@ def test_badge_errors(
     ):
         url_args = {"object_type": object_type, "object_id": object_id}
         url = reverse("swh-badge", url_args=url_args)
-        resp = client.get(url)
+        resp = check_http_get_response(
+            client, url, status_code=200, content_type="image/svg+xml"
+        )
         _check_generated_badge(resp, **url_args, error="not found")
 
         if object_type != ORIGIN:
-            object_pid = persistent_identifier(object_type, object_id)
-            url = reverse("swh-badge-pid", url_args={"object_pid": object_pid})
-            resp = client.get(url)
+            object_swhid = swhid(object_type, object_id)
+            url = reverse("swh-badge-swhid", url_args={"object_swhid": object_swhid})
+            resp = check_http_get_response(
+                client, url, status_code=200, content_type="image/svg+xml"
+            )
             _check_generated_badge(resp, **url_args, error="not found")
 
     for object_type, object_id in (
@@ -114,12 +119,17 @@ def test_badge_errors(
     ):
         url_args = {"object_type": object_type, "object_id": object_id}
         url = reverse("swh-badge", url_args=url_args)
-        resp = client.get(url)
+
+        resp = check_http_get_response(
+            client, url, status_code=200, content_type="image/svg+xml"
+        )
         _check_generated_badge(resp, **url_args, error="invalid id")
 
-        object_pid = f"swh:1:{object_type[:3]}:{object_id}"
-        url = reverse("swh-badge-pid", url_args={"object_pid": object_pid})
-        resp = client.get(url)
+        object_swhid = f"swh:1:{object_type[:3]}:{object_id}"
+        url = reverse("swh-badge-swhid", url_args={"object_swhid": object_swhid})
+        resp = check_http_get_response(
+            client, url, status_code=200, content_type="image/svg+xml"
+        )
         _check_generated_badge(resp, "", "", error="invalid id")
 
 
@@ -128,26 +138,41 @@ def test_badge_endpoints_have_cors_header(client, origin, release):
     url = reverse(
         "swh-badge", url_args={"object_type": ORIGIN, "object_id": origin["url"]}
     )
-    resp = client.get(url, HTTP_ORIGIN="https://example.org")
-    assert resp.status_code == 200, resp.content
+
+    resp = check_http_get_response(
+        client,
+        url,
+        status_code=200,
+        content_type="image/svg+xml",
+        http_origin="https://example.org",
+    )
     assert ACCESS_CONTROL_ALLOW_ORIGIN in resp
 
-    release_pid = persistent_identifier(RELEASE, release)
-    url = reverse("swh-badge-pid", url_args={"object_pid": release_pid})
-    resp = client.get(url, HTTP_ORIGIN="https://example.org")
-    assert resp.status_code == 200, resp.content
+    release_swhid = swhid(RELEASE, release)
+    url = reverse("swh-badge-swhid", url_args={"object_swhid": release_swhid})
+    resp = check_http_get_response(
+        client,
+        url,
+        status_code=200,
+        content_type="image/svg+xml",
+        http_origin="https://example.org",
+    )
     assert ACCESS_CONTROL_ALLOW_ORIGIN in resp
 
 
 def _test_badge_endpoints(client, object_type, object_id):
     url_args = {"object_type": object_type, "object_id": object_id}
     url = reverse("swh-badge", url_args=url_args)
-    resp = client.get(url)
+    resp = check_http_get_response(
+        client, url, status_code=200, content_type="image/svg+xml"
+    )
     _check_generated_badge(resp, **url_args)
     if object_type != ORIGIN:
-        pid = persistent_identifier(object_type, object_id)
-        url = reverse("swh-badge-pid", url_args={"object_pid": pid})
-        resp = client.get(url)
+        obj_swhid = swhid(object_type, object_id)
+        url = reverse("swh-badge-swhid", url_args={"object_swhid": obj_swhid})
+        resp = check_http_get_response(
+            client, url, status_code=200, content_type="image/svg+xml"
+        )
         _check_generated_badge(resp, **url_args)
 
 
@@ -162,10 +187,10 @@ def _check_generated_badge(response, object_type, object_id, error=None):
         link = reverse("browse-origin", query_params={"origin_url": object_id})
         text = "repository"
     elif error is None:
-        text = persistent_identifier(object_type, object_id)
-        link = resolve_swh_persistent_id(text)["browse_url"]
+        text = swhid(object_type, object_id)
+        link = resolve_swhid(text)["browse_url"]
         if object_type == RELEASE:
-            release = service.lookup_release(object_id)
+            release = archive.lookup_release(object_id)
             text = release["name"]
     elif error == "invalid id":
         text = "error"
