@@ -3,33 +3,36 @@
 # License: GNU Affero General Public License version 3, or any later version
 # See top-level LICENSE file for more information
 
-import random
-
 from collections import defaultdict
 from datetime import datetime
+import random
 
-from hypothesis import settings, assume
+from hypothesis import assume, settings
 from hypothesis.extra.dateutil import timezones
 from hypothesis.strategies import (
-    just,
-    sampled_from,
-    lists,
+    binary,
+    characters,
     composite,
     datetimes,
-    binary,
+    just,
+    lists,
+    sampled_from,
     text,
-    characters,
 )
 
-from swh.model.hashutil import hash_to_hex, hash_to_bytes
-from swh.model.identifiers import directory_identifier
-from swh.model.model import Person, Revision, RevisionType, TimestampWithTimezone
+from swh.model.hashutil import DEFAULT_ALGORITHMS, hash_to_bytes, hash_to_hex
+from swh.model.hypothesis_strategies import origins as new_origin_strategy
+from swh.model.hypothesis_strategies import snapshots as new_snapshot
+from swh.model.model import (
+    Content,
+    Directory,
+    Person,
+    Revision,
+    RevisionType,
+    TimestampWithTimezone,
+)
 from swh.storage.algos.revisions_walker import get_revisions_walker
 from swh.storage.algos.snapshot import snapshot_get_latest
-from swh.model.hypothesis_strategies import (
-    origins as new_origin_strategy,
-    snapshots as new_snapshot,
-)
 from swh.web.common.utils import browsers_supported_image_mimes
 from swh.web.tests.data import get_tests_data
 
@@ -96,6 +99,17 @@ def contents():
     return lists(content(), min_size=2, max_size=8)
 
 
+def empty_content():
+    """
+    Hypothesis strategy returning the empty content ingested
+    into the test archive.
+    """
+    empty_content = Content.from_data(data=b"").to_dict()
+    for algo in DEFAULT_ALGORITHMS:
+        empty_content[algo] = hash_to_hex(empty_content[algo])
+    return just(empty_content)
+
+
 def content_text():
     """
     Hypothesis strategy returning random textual contents ingested
@@ -188,9 +202,7 @@ def unknown_content():
     into the test archive.
     """
     return new_content().filter(
-        lambda c: next(
-            get_tests_data()["storage"].content_get([hash_to_bytes(c["sha1"])])
-        )
+        lambda c: get_tests_data()["storage"].content_get_data(hash_to_bytes(c["sha1"]))
         is None
     )
 
@@ -233,7 +245,7 @@ def empty_directory():
     Hypothesis strategy returning the empty directory ingested
     into the test archive.
     """
-    return just(directory_identifier({"entries": []}))
+    return just(Directory(entries=()).id.hex())
 
 
 def unknown_directory():
@@ -264,9 +276,10 @@ def origin_with_multiple_visits():
     """
     ret = []
     tests_data = get_tests_data()
+    storage = tests_data["storage"]
     for origin in tests_data["origins"]:
-        visits = list(tests_data["storage"].origin_visit_get(origin["url"]))
-        if len(visits) > 1:
+        visit_page = storage.origin_visit_get(origin["url"])
+        if len(visit_page.results) > 1:
             ret.append(origin)
     return sampled_from(ret)
 
@@ -291,8 +304,7 @@ def new_origin():
     into the test archive.
     """
     return new_origin_strategy().filter(
-        lambda origin: get_tests_data()["storage"].origin_get([origin.to_dict()])[0]
-        is None
+        lambda origin: get_tests_data()["storage"].origin_get([origin.url])[0] is None
     )
 
 
@@ -338,13 +350,21 @@ def release():
     return _known_swh_object("releases")
 
 
+def releases(min_size=2, max_size=8):
+    """
+    Hypothesis strategy returning random releases ingested
+    into the test archive.
+    """
+    return lists(release(), min_size=min_size, max_size=max_size)
+
+
 def unknown_release():
     """
     Hypothesis strategy returning a random revision not ingested
     into the test archive.
     """
     return sha1().filter(
-        lambda s: next(get_tests_data()["storage"].release_get([s])) is None
+        lambda s: get_tests_data()["storage"].release_get([s])[0] is None
     )
 
 
@@ -362,7 +382,7 @@ def unknown_revision():
     into the test archive.
     """
     return sha1().filter(
-        lambda s: next(get_tests_data()["storage"].revision_get([hash_to_bytes(s)]))
+        lambda s: get_tests_data()["storage"].revision_get([hash_to_bytes(s)])[0]
         is None
     )
 
@@ -462,7 +482,8 @@ def unknown_snapshot():
     into the test archive.
     """
     return sha1().filter(
-        lambda s: get_tests_data()["storage"].snapshot_get(hash_to_bytes(s)) is None
+        lambda s: get_tests_data()["storage"].snapshot_get_branches(hash_to_bytes(s))
+        is None
     )
 
 
